@@ -19,6 +19,7 @@ import (
 
 	"github.com/fatih/color"
 	"github.com/go-kit/log"
+	"github.com/grafana/alloy/internal/util"
 	"github.com/grafana/ckit/advertise"
 	"github.com/grafana/ckit/peer"
 	"github.com/prometheus/client_golang/prometheus"
@@ -53,7 +54,7 @@ import (
 	_ "github.com/grafana/alloy/internal/component/all"
 )
 
-func runCommand() *cobra.Command {
+func RunCommand() *cobra.Command {
 	r := &alloyRun{
 		inMemoryAddr:          "alloy.internal:12345",
 		httpListenAddr:        "127.0.0.1:12345",
@@ -73,7 +74,7 @@ func runCommand() *cobra.Command {
 
 	cmd := &cobra.Command{
 		Use:   "run [flags] path",
-		Short: "Run Grafana Alloy",
+		Short: "Run Grafana Alloy with Default Engine",
 		Long: `The run subcommand runs Grafana Alloy in the foreground until an interrupt
 is received.
 
@@ -210,7 +211,7 @@ func (fr *alloyRun) Run(cmd *cobra.Command, configPath string) error {
 	var wg sync.WaitGroup
 	defer wg.Wait()
 
-	ctx, cancel := interruptContext()
+	ctx, cancel := interruptContext(cmd.Context())
 	defer cancel()
 
 	if configPath == "" {
@@ -278,7 +279,7 @@ func (fr *alloyRun) Run(cmd *cobra.Command, configPath string) error {
 	// registry that we want to keep can be given a custom registry so desired
 	// metrics are still exposed.
 	reg := prometheus.DefaultRegisterer
-	reg.MustRegister(newResourcesCollector(l))
+	_ = util.MustRegisterOrGet(reg, newResourcesCollector(l))
 
 	// There's a cyclic dependency between the definition of the Alloy controller,
 	// the reload/ready functions, and the HTTP service.
@@ -588,8 +589,8 @@ func addDeprecatedFlags(cmd *cobra.Command) {
 	deprecateFlagByName(cmd, "feature.prometheus.metric-validation-scheme")
 }
 
-func interruptContext() (context.Context, context.CancelFunc) {
-	ctx, cancel := context.WithCancel(context.Background())
+func interruptContext(parent context.Context) (context.Context, context.CancelFunc) {
+	ctx, cancel := context.WithCancel(parent)
 
 	go func() {
 		defer cancel()
