@@ -10,31 +10,34 @@ import (
 
 // Config describes configuration for an HTTP pusher client.
 type Config struct {
-	Name      string `yaml:"name,omitempty"`
+	Name      string
 	URL       flagext.URLValue
-	BatchWait time.Duration `yaml:"batchwait"`
-	BatchSize int           `yaml:"batchsize"`
+	BatchWait time.Duration
+	BatchSize int
 
-	Client  config.HTTPClientConfig `yaml:",inline"`
-	Headers map[string]string       `yaml:"headers,omitempty"`
+	Client  config.HTTPClientConfig
+	Headers map[string]string
 
-	BackoffConfig backoff.Config `yaml:"backoff_config"`
-	Timeout       time.Duration  `yaml:"timeout"`
+	BackoffConfig backoff.Config
+	Timeout       time.Duration
 
 	// The tenant ID to use when pushing logs to Loki (empty string means
 	// single tenant mode)
-	TenantID string `yaml:"tenant_id"`
+	TenantID string
+
+	// Max number of streams that can be added to a batch.
+	MaxStreams int
 
 	// When enabled, Promtail will not retry batches that get a
 	// 429 'Too Many Requests' response from the distributor. Helps
 	// prevent HOL blocking in multitenant deployments.
-	DropRateLimitedBatches bool `yaml:"drop_rate_limited_batches"`
+	DropRateLimitedBatches bool
 
-	// Queue controls configuration parameters specific to the queue client
-	Queue QueueConfig
+	// QueueConfig controls how shards and queues are configured for endpoint.
+	QueueConfig QueueConfig
 }
 
-// QueueConfig holds configurations for the queue-based remote-write client.
+// QueueConfig controls how shards and queues are configured for endpoints.
 type QueueConfig struct {
 	// Capacity is the worst case size in bytes desired for the send queue. This value is used to calculate the size of
 	// the buffered channel used underneath. The worst case scenario assumed is that every batch buffered in full, hence
@@ -44,6 +47,9 @@ type QueueConfig struct {
 	// is the 1 MiB default, and a capacity of 100 MiB, the underlying buffered channel would buffer up to 100 batches.
 	Capacity int
 
-	// DrainTimeout controls the maximum time that draining the send queue can take.
+	// MinShards is the minimum number of concurrent shards sending batches to the endpoint.
+	MinShards int
+
+	// DrainTimeout controls the maximum time that draining the queue can take.
 	DrainTimeout time.Duration
 }
