@@ -3,7 +3,6 @@ package collector
 import (
 	"context"
 	"net"
-	"regexp"
 	"strings"
 
 	"github.com/go-sql-driver/mysql"
@@ -14,11 +13,6 @@ import (
 
 const ConnectionInfoName = "connection_info"
 
-var (
-	rdsRegex   = regexp.MustCompile(`(?P<identifier>[^\.]+)\.([^\.]+)\.(?P<region>[^\.]+)\.rds\.amazonaws\.com`)
-	azureRegex = regexp.MustCompile(`(?P<identifier>[^\.]+)\.mysql\.database\.azure\.com`)
-)
-
 type ConnectionInfoArguments struct {
 	DSN           string
 	Registry      *prometheus.Registry
@@ -79,6 +73,12 @@ func (c *ConnectionInfo) Start(ctx context.Context) error {
 				dbInstanceIdentifier = strings.TrimPrefix(resource, "db:")
 			}
 		}
+		if c.CloudProvider.Azure != nil {
+			providerName = "azure"
+			dbInstanceIdentifier = c.CloudProvider.Azure.ServerName
+			providerRegion = c.CloudProvider.Azure.ResourceGroup
+			providerAccount = c.CloudProvider.Azure.SubscriptionID
+		}
 	} else {
 		cfg, err := mysql.ParseDSN(c.DSN)
 		if err != nil {
@@ -89,14 +89,14 @@ func (c *ConnectionInfo) Start(ctx context.Context) error {
 		if err == nil && host != "" {
 			if strings.HasSuffix(host, "rds.amazonaws.com") {
 				providerName = "aws"
-				matches := rdsRegex.FindStringSubmatch(host)
+				matches := database_observability.RdsRegex.FindStringSubmatch(host)
 				if len(matches) > 3 {
 					dbInstanceIdentifier = matches[1]
 					providerRegion = matches[3]
 				}
 			} else if strings.HasSuffix(host, "mysql.database.azure.com") {
 				providerName = "azure"
-				matches := azureRegex.FindStringSubmatch(host)
+				matches := database_observability.AzureMySQLRegex.FindStringSubmatch(host)
 				if len(matches) > 1 {
 					dbInstanceIdentifier = matches[1]
 				}
