@@ -26,8 +26,15 @@ type Target struct {
 var (
 	seps = []byte{'\xff'}
 	// used in tests to simulate hash conflicts
-	labelSetEqualsFn = func(l1, l2 commonlabels.LabelSet) bool { return &l1 == &l2 || l1.Equal(l2) }
-	stringSlicesPool = sync.Pool{New: func() interface{} { return make([]string, 0, 20) }}
+	labelSetEqualsFn  = func(l1, l2 commonlabels.LabelSet) bool { return &l1 == &l2 || l1.Equal(l2) }
+	stringSlicesPool  = sync.Pool{New: func() any { return make([]string, 0, 20) }}
+	borrowLabelsSlice = func() []string {
+		return stringSlicesPool.Get().([]string)
+	}
+	releaseLabelsSlice = func(labels []string) {
+		// We can ignore linter warning here, because slice headers are small and the underlying array will be reused.
+		stringSlicesPool.Put(labels[:0]) //nolint:staticcheck // SA6002
+	}
 
 	_ syntax.Capsule                = Target{}
 	_ syntax.ConvertibleIntoCapsule = Target{}
@@ -284,8 +291,8 @@ func (t Target) SpecificLabelsHash(labelNames []string) uint64 {
 
 func (t Target) HashLabelsWithPredicate(pred func(key string) bool) uint64 {
 	// For hash to be deterministic, we need labels order to be deterministic too. Figure this out first.
-	labelsInOrder := stringSlicesPool.Get().([]string)
-	defer stringSlicesPool.Put(labelsInOrder[:]) //nolint:staticcheck //TODO(@piotr) take a look at this optimization SA6002
+	labelsInOrder := borrowLabelsSlice()
+	defer releaseLabelsSlice(labelsInOrder)
 	t.ForEachLabel(func(key string, value string) bool {
 		if pred(key) {
 			labelsInOrder = append(labelsInOrder, key)
@@ -298,8 +305,8 @@ func (t Target) HashLabelsWithPredicate(pred func(key string) bool) uint64 {
 
 func (t Target) groupLabelsHash() uint64 {
 	// For hash to be deterministic, we need labels order to be deterministic too. Figure this out first.
-	labelsInOrder := stringSlicesPool.Get().([]string)
-	defer stringSlicesPool.Put(labelsInOrder[:]) //nolint:staticcheck //TODO(@piotr) take a look at this optimization SA6002
+	labelsInOrder := borrowLabelsSlice()
+	defer releaseLabelsSlice(labelsInOrder)
 
 	for name := range t.group {
 		labelsInOrder = append(labelsInOrder, string(name))
@@ -308,10 +315,9 @@ func (t Target) groupLabelsHash() uint64 {
 	return t.hashLabelsInOrder(labelsInOrder)
 }
 
-// NOTE 1: This function is copied from Prometheus codebase and adapted to work correctly with Alloy types.
-// NOTE 2: It is important to keep the hashing function consistent between Alloy versions in order to have
-//
-//	smooth rollouts without duplicated or missing data. There are tests to verify this behaviour. Do not change it.
+// NOTE 1: This function is copied from Prometheus codebase (labels.StableHash()) and adapted to work correctly with Alloy types.
+// NOTE 2: It is important to keep the hashing function consistent between Alloy versions in order to have smooth clustering
+// rollouts without duplicated or missing scraping of targets. There are tests to verify this behaviour. Do not change it.
 func (t Target) hashLabelsInOrder(order []string) uint64 {
 	// This optimisation is adapted from prometheus/model/labels.
 	// Use xxhash.Sum64(b) for fast path as it's faster.
