@@ -3,6 +3,7 @@ package process
 import (
 	"github.com/grafana/alloy/internal/component"
 	"github.com/grafana/alloy/internal/component/prometheus/exporter"
+	"github.com/grafana/alloy/internal/component/prometheus/exporter/common"
 	"github.com/grafana/alloy/internal/featuregate"
 	"github.com/grafana/alloy/internal/static/integrations"
 	"github.com/grafana/alloy/internal/static/integrations/process_exporter"
@@ -20,8 +21,10 @@ func init() {
 	})
 }
 
-func createIntegration(opts component.Options, args component.Arguments, defaultInstanceKey string) (integrations.Integration, string, error) {
+func createIntegration(opts component.Options, args component.Arguments) (integrations.Integration, string, error) {
+	common.WarningIfUsedInCluster(opts)
 	a := args.(Arguments)
+	defaultInstanceKey := common.HostNameInstanceKey() // if cannot resolve instance key, use the host name for process exporter
 	return integrations.NewIntegrationWithInstanceKey(opts.Logger, a.Convert(), defaultInstanceKey)
 }
 
@@ -63,12 +66,13 @@ func (a *Arguments) SetToDefault() {
 
 func (a *Arguments) Convert() *process_exporter.Config {
 	return &process_exporter.Config{
-		ProcessExporter: convertMatcherGroups(a.ProcessExporter),
-		ProcFSPath:      a.ProcFSPath,
-		Children:        a.Children,
-		Threads:         a.Threads,
-		SMaps:           a.SMaps,
-		Recheck:         a.Recheck,
+		ProcessExporter:   convertMatcherGroups(a.ProcessExporter),
+		ProcFSPath:        a.ProcFSPath,
+		Children:          a.Children,
+		Threads:           a.Threads,
+		SMaps:             a.SMaps,
+		Recheck:           a.Recheck,
+		RemoveEmptyGroups: a.RemoveEmptyGroups,
 	}
 }
 
