@@ -190,6 +190,14 @@ func (cg *ConfigGenerator) generateDefaultScrapeConfig() *config.ScrapeConfig {
 		c.ScrapeTimeout = model.Duration(opt.DefaultScrapeTimeout)
 	}
 
+	if opt.DefaultSampleLimit != 0 {
+		c.SampleLimit = opt.DefaultSampleLimit
+	}
+
+	if opt.ScrapeNativeHistograms {
+		c.ScrapeProtocols = config.DefaultProtoFirstScrapeProtocols
+	}
+
 	return &c
 }
 
