@@ -38,7 +38,8 @@ func (datadogExporterConverter) ConvertAndAppend(state *State, id componentstatu
 	overrideHook := func(val interface{}) interface{} {
 		switch val.(type) {
 		case extension.ExtensionHandler:
-			ext := state.LookupExtension(*cfg.(*datadogOtelconfig.Config).QueueSettings.StorageID)
+			queue := cfg.(*datadogOtelconfig.Config).QueueSettings.GetOrInsertDefault()
+			ext := state.LookupExtension(*queue.StorageID)
 			return common.CustomTokenizer{Expr: fmt.Sprintf("%s.%s.handler", strings.Join(ext.Name, "."), ext.Label)}
 		}
 		return common.GetAlloyTypesOverrideHook()(val)
