@@ -5,6 +5,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/prometheus/common/model"
 	"golang.org/x/exp/maps"
 
 	prom_config "github.com/prometheus/prometheus/config"
@@ -48,13 +49,14 @@ func toScrapeArguments(scrapeConfig *prom_config.ScrapeConfig, forwardTo []stora
 	}
 
 	histogramsToNHCB := scrapeConfig.ConvertClassicHistogramsToNHCB != nil && *scrapeConfig.ConvertClassicHistogramsToNHCB
+	scrapeClassicHistograms := scrapeConfig.AlwaysScrapeClassicHistograms != nil && *scrapeConfig.AlwaysScrapeClassicHistograms
 	fallbackProtocol := string(scrapeConfig.ScrapeFallbackProtocol)
 	if fallbackProtocol == "" {
 		fallbackProtocol = string(prom_config.PrometheusText0_0_4)
 	}
 
 	// Set the escaping and validation scheme to default values in Alloy for maximum compatibility with backends.
-	scrapeConfig.MetricNameValidationScheme = prom_config.LegacyValidationConfig
+	scrapeConfig.MetricNameValidationScheme = model.LegacyValidation
 	scrapeConfig.MetricNameEscapingScheme = "" // this will default to underscores given the legacy validation scheme
 
 	alloyArgs := &scrape.Arguments{
@@ -65,7 +67,7 @@ func toScrapeArguments(scrapeConfig *prom_config.ScrapeConfig, forwardTo []stora
 		HonorTimestamps:                scrapeConfig.HonorTimestamps,
 		TrackTimestampsStaleness:       scrapeConfig.TrackTimestampsStaleness,
 		Params:                         scrapeConfig.Params,
-		ScrapeClassicHistograms:        scrapeConfig.AlwaysScrapeClassicHistograms,
+		ScrapeClassicHistograms:        scrapeClassicHistograms,
 		ScrapeNativeHistograms:         false, // this is controlled by a Prometheus feature, not the config file
 		ScrapeInterval:                 time.Duration(scrapeConfig.ScrapeInterval),
 		ScrapeTimeout:                  time.Duration(scrapeConfig.ScrapeTimeout),
@@ -86,7 +88,7 @@ func toScrapeArguments(scrapeConfig *prom_config.ScrapeConfig, forwardTo []stora
 		EnableCompression:              scrapeConfig.EnableCompression,
 		NativeHistogramBucketLimit:     scrapeConfig.NativeHistogramBucketLimit,
 		NativeHistogramMinBucketFactor: scrapeConfig.NativeHistogramMinBucketFactor,
-		MetricNameValidationScheme:     scrapeConfig.MetricNameValidationScheme,
+		MetricNameValidationScheme:     scrapeConfig.MetricNameValidationScheme.String(),
 		MetricNameEscapingScheme:       scrapeConfig.MetricNameEscapingScheme,
 		ScrapeFallbackProtocol:         fallbackProtocol,
 		Clustering:                     cluster.ComponentBlock{Enabled: false},
