@@ -4,6 +4,7 @@ import (
 	"bytes"
 	"flag"
 	"fmt"
+	"strings"
 
 	promtailcfg "github.com/grafana/alloy/internal/loki/promtail/config"
 	"github.com/grafana/alloy/internal/loki/promtail/file"
@@ -84,11 +85,19 @@ func Convert(in []byte, extraArgs []string) ([]byte, diag.Diagnostics) {
 		return nil, diags
 	}
 
-	prettyByte, newDiags := common.PrettyPrint(buf.Bytes())
+	prettyByte, newDiags := common.PrettyPrint([]byte(fixFunctionUse(buf.String())))
 	diags.AddAll(newDiags)
 	return prettyByte, diags
 }
 
+// There is not a way to express a function call in a struct to encode back into Alloy config, so we need to fix it
+func fixFunctionUse(buf string) string {
+	return strings.ReplaceAll(buf,
+		`"\"spec.nodeName=\" + coalesce(sys.env(\"HOSTNAME\"), constants.hostname)"`,
+		`"spec.nodeName=" + coalesce(sys.env("HOSTNAME"), constants.hostname)`,
+	)
+}
+
 // AppendAll analyzes the entire promtail config in memory and transforms it
 // into Alloy components. It then appends each argument to the file builder.
 func AppendAll(f *builder.File, cfg *promtailcfg.Config, labelPrefix string, diags diag.Diagnostics) diag.Diagnostics {
