@@ -9,6 +9,7 @@ import (
 
 	"github.com/prometheus/prometheus/model/exemplar"
 	"github.com/prometheus/prometheus/model/labels"
+	"github.com/prometheus/prometheus/model/metadata"
 	"github.com/prometheus/prometheus/tsdb/chunks"
 )
 
@@ -21,6 +22,9 @@ type memSeries struct {
 	ref  chunks.HeadSeriesRef
 	lset labels.Labels
 
+	// TODO: Intern the type and unit values using the unique pkg: https://go.dev/blog/unique
+	meta *metadata.Metadata
+
 	// Last recorded timestamp. Used by gc to determine if a series is stale.
 	lastTs int64
 }
