@@ -21,8 +21,6 @@ import (
 	"github.com/prometheus/prometheus/model/histogram"
 	"github.com/prometheus/prometheus/model/labels"
 	"github.com/prometheus/prometheus/model/metadata"
-	"github.com/prometheus/prometheus/model/timestamp"
-	"github.com/prometheus/prometheus/model/value"
 	"github.com/prometheus/prometheus/storage"
 	"github.com/prometheus/prometheus/tsdb"
 	"github.com/prometheus/prometheus/tsdb/chunks"
@@ -52,6 +50,7 @@ type storageMetrics struct {
 	totalRemovedSeries     prometheus.Counter
 	totalAppendedSamples   prometheus.Counter
 	totalAppendedExemplars prometheus.Counter
+	totalAppendedMetadata  prometheus.Counter
 }
 
 func newStorageMetrics(r prometheus.Registerer) *storageMetrics {
@@ -91,6 +90,11 @@ func newStorageMetrics(r prometheus.Registerer) *storageMetrics {
 		Help: "Total number of exemplars appended to the WAL",
 	})
 
+	m.totalAppendedMetadata = prometheus.NewCounter(prometheus.CounterOpts{
+		Name: "prometheus_remote_write_wal_metadata_updates_total",
+		Help: "Total number of metadata updates sent through the WAL",
+	})
+
 	if r != nil {
 		m.numActiveSeries = util.MustRegisterOrGet(r, m.numActiveSeries).(prometheus.Gauge)
 		m.numDeletedSeries = util.MustRegisterOrGet(r, m.numDeletedSeries).(prometheus.Gauge)
@@ -99,6 +103,7 @@ func newStorageMetrics(r prometheus.Registerer) *storageMetrics {
 		m.totalRemovedSeries = util.MustRegisterOrGet(r, m.totalRemovedSeries).(prometheus.Counter)
 		m.totalAppendedSamples = util.MustRegisterOrGet(r, m.totalAppendedSamples).(prometheus.Counter)
 		m.totalAppendedExemplars = util.MustRegisterOrGet(r, m.totalAppendedExemplars).(prometheus.Counter)
+		m.totalAppendedMetadata = util.MustRegisterOrGet(r, m.totalAppendedMetadata).(prometheus.Counter)
 	}
 
 	return &m
@@ -116,6 +121,7 @@ func (m *storageMetrics) Unregister() {
 		m.totalRemovedSeries,
 		m.totalAppendedSamples,
 		m.totalAppendedExemplars,
+		m.totalAppendedMetadata,
 	}
 	for _, c := range cs {
 		m.r.Unregister(c)
@@ -191,6 +197,7 @@ func NewStorage(logger log.Logger, registerer prometheus.Registerer, path string
 			pendingHistograms:      make([]record.RefHistogramSample, 0, 100),
 			pendingFloatHistograms: make([]record.RefFloatHistogramSample, 0, 100),
 			pendingExamplars:       make([]record.RefExemplar, 0, 10),
+			pendingMetadata:        make([]record.RefMetadata, 0, 10),
 		}
 	}
 
@@ -317,6 +324,9 @@ func (w *Storage) loadWAL(r *wlog.Reader, duplicateRefToValidRef map[chunks.Head
 		defer close(decoded)
 		for r.Next() {
 			rec := r.Record()
+			// TODO: Also decode metadata. This could be particularly useful when
+			// calling UpdateMetadata on the first Commit after startup -
+			// right now each call will be logged as if the metadata changed.
 			switch dec.Type(rec) {
 			case record.Series:
 				series := seriesPool.Get().([]record.RefSeries)[:0]
@@ -610,66 +620,6 @@ func (w *Storage) gc(mint int64) {
 	w.metrics.numDeletedSeries.Set(float64(len(w.deleted)))
 }
 
-// WriteStalenessMarkers appends a staleness sample for all active series.
-func (w *Storage) WriteStalenessMarkers(remoteTsFunc func() int64) error {
-	var lastErr error
-	var lastTs int64
-
-	app := w.Appender(context.Background())
-	it := w.series.iterator()
-	for series := range it.Channel() {
-		var (
-			ref  = series.ref
-			lset = series.lset
-		)
-
-		ts := timestamp.FromTime(time.Now())
-		_, err := app.Append(storage.SeriesRef(ref), lset, ts, math.Float64frombits(value.StaleNaN))
-		if err != nil {
-			lastErr = err
-		}
-
-		// Remove millisecond precision; the remote write timestamp we get
-		// only has second precision.
-		lastTs = (ts / 1000) * 1000
-	}
-
-	if lastErr == nil {
-		if err := app.Commit(); err != nil {
-			return fmt.Errorf("failed to commit staleness markers: %w", err)
-		}
-
-		// Wait for remote write to write the lastTs, but give up after 1m
-		level.Info(w.logger).Log("msg", "waiting for remote write to write staleness markers...")
-
-		stopCh := time.After(1 * time.Minute)
-		start := time.Now()
-
-	Outer:
-		for {
-			select {
-			case <-stopCh:
-				level.Error(w.logger).Log("msg", "timed out waiting for staleness markers to be written")
-				break Outer
-			default:
-				writtenTs := remoteTsFunc()
-				if writtenTs >= lastTs {
-					duration := time.Since(start)
-					level.Info(w.logger).Log("msg", "remote write wrote staleness markers", "duration", duration)
-					break Outer
-				}
-
-				level.Info(w.logger).Log("msg", "remote write hasn't written staleness markers yet", "remoteTs", writtenTs, "lastTs", lastTs)
-
-				// Wait a bit before reading again
-				time.Sleep(5 * time.Second)
-			}
-		}
-	}
-
-	return lastErr
-}
-
 // Close closes the storage and all its underlying resources.
 func (w *Storage) Close() error {
 	w.walMtx.Lock()
@@ -693,6 +643,7 @@ type appender struct {
 	pendingExamplars       []record.RefExemplar
 	pendingHistograms      []record.RefHistogramSample
 	pendingFloatHistograms []record.RefFloatHistogramSample
+	pendingMetadata        []record.RefMetadata
 
 	// Pointers to the series referenced by each element of pendingSamples.
 	// Series lock is not held on elements.
@@ -705,6 +656,10 @@ type appender struct {
 	// Pointers to the series referenced by each element of pendingFloatHistograms.
 	// Series lock is not held on elements.
 	floatHistogramSeries []*memSeries
+
+	// Pointers to the series referenced by each element of pendingMetadata.
+	// Series lock is not held on elements.
+	metadataSeries []*memSeries
 }
 
 var _ storage.Appender = (*appender)(nil)
@@ -893,9 +848,38 @@ func (a *appender) AppendCTZeroSample(_ storage.SeriesRef, _ labels.Labels, _ in
 	return 0, nil
 }
 
-func (a *appender) UpdateMetadata(ref storage.SeriesRef, _ labels.Labels, m metadata.Metadata) (storage.SeriesRef, error) {
-	// TODO(rfratto): implement pushing metadata to WAL
-	return 0, nil
+func (a *appender) UpdateMetadata(ref storage.SeriesRef, labels labels.Labels, meta metadata.Metadata) (storage.SeriesRef, error) {
+	// Ensure the series exists by id or by labels before we try to update metadata.
+	series := a.w.series.GetByID(chunks.HeadSeriesRef(ref))
+	if series == nil {
+		series = a.w.series.GetByHash(labels.Hash(), labels)
+		if series != nil {
+			ref = storage.SeriesRef(series.ref)
+		}
+	}
+	if series == nil {
+		return 0, fmt.Errorf("unknown series when trying to add metadata with SeriesRef: %d and labels: %s", ref, labels)
+	}
+
+	series.Lock()
+	// TODO: If the WAL is empty, then on the very first commit
+	// hasNewMetadata will always be true repeatedly for the same metadata.
+	// This is because series.meta is still nil - it's only set after the first commit.
+	// Fix this here and in the upstream Prometheus WAL.
+	hasNewMetadata := series.meta == nil || *series.meta != meta
+	series.Unlock()
+
+	if hasNewMetadata {
+		a.pendingMetadata = append(a.pendingMetadata, record.RefMetadata{
+			Ref:  chunks.HeadSeriesRef(ref),
+			Type: record.GetMetricType(meta.Type),
+			Unit: meta.Unit,
+			Help: meta.Help,
+		})
+		a.metadataSeries = append(a.metadataSeries, series)
+		a.w.metrics.totalAppendedMetadata.Inc()
+	}
+	return ref, nil
 }
 
 func (a *appender) SetOptions(_ *storage.AppendOptions) {
@@ -945,6 +929,16 @@ func (a *appender) log() error {
 		buf = buf[:0]
 	}
 
+	// Metadata needs to be written after series but before samples so we have a valid series ref for the metadata data
+	// and that series ref can be associated to samples for metadata.
+	if len(a.pendingMetadata) > 0 {
+		buf = encoder.Metadata(a.pendingMetadata, buf)
+		if err := a.w.wal.Log(buf); err != nil {
+			return err
+		}
+		buf = buf[:0]
+	}
+
 	if len(a.pendingSamples) > 0 {
 		buf = encoder.Samples(a.pendingSamples, buf)
 		if err := a.w.wal.Log(buf); err != nil {
@@ -1016,6 +1010,12 @@ func (a *appender) log() error {
 			a.w.metrics.totalOutOfOrderSamples.Inc()
 		}
 	}
+	for i, m := range a.pendingMetadata {
+		series = a.metadataSeries[i]
+		series.Lock()
+		series.meta = &metadata.Metadata{Type: record.ToMetricType(m.Type), Unit: m.Unit, Help: m.Help}
+		series.Unlock()
+	}
 
 	return nil
 }
@@ -1027,9 +1027,11 @@ func (a *appender) clearData() {
 	a.pendingHistograms = a.pendingHistograms[:0]
 	a.pendingFloatHistograms = a.pendingFloatHistograms[:0]
 	a.pendingExamplars = a.pendingExamplars[:0]
+	a.pendingMetadata = a.pendingMetadata[:0]
 	a.sampleSeries = a.sampleSeries[:0]
 	a.histogramSeries = a.histogramSeries[:0]
 	a.floatHistogramSeries = a.floatHistogramSeries[:0]
+	a.metadataSeries = a.metadataSeries[:0]
 }
 
 func (a *appender) Rollback() error {
