@@ -7,8 +7,11 @@ package defaultforwarder
 
 import (
 	"fmt"
+	"maps"
 	"net/http"
+	"net/url"
 	"path"
+	"slices"
 	"strconv"
 	"strings"
 	"sync"
@@ -18,11 +21,13 @@ import (
 
 	"github.com/DataDog/datadog-agent/comp/core/config"
 	log "github.com/DataDog/datadog-agent/comp/core/log/def"
+	secrets "github.com/DataDog/datadog-agent/comp/core/secrets/def"
 	"github.com/DataDog/datadog-agent/comp/forwarder/defaultforwarder/endpoints"
 	"github.com/DataDog/datadog-agent/comp/forwarder/defaultforwarder/internal/retry"
 	pkgresolver "github.com/DataDog/datadog-agent/comp/forwarder/defaultforwarder/resolver"
 	"github.com/DataDog/datadog-agent/comp/forwarder/defaultforwarder/transaction"
 	"github.com/DataDog/datadog-agent/pkg/api/security"
+	pkgconfigmodel "github.com/DataDog/datadog-agent/pkg/config/model"
 	pkgconfigsetup "github.com/DataDog/datadog-agent/pkg/config/setup"
 	"github.com/DataDog/datadog-agent/pkg/config/utils"
 	"github.com/DataDog/datadog-agent/pkg/telemetry"
@@ -63,20 +68,25 @@ type Forwarder interface {
 	SubmitV1Series(payload transaction.BytesPayloads, extra http.Header) error
 	SubmitV1Intake(payload transaction.BytesPayloads, kind transaction.Kind, extra http.Header) error
 	SubmitV1CheckRuns(payload transaction.BytesPayloads, extra http.Header) error
-	SubmitSeries(payload transaction.BytesPayloads, extra http.Header) error
-	SubmitSketchSeries(payload transaction.BytesPayloads, extra http.Header) error
 	SubmitHostMetadata(payload transaction.BytesPayloads, extra http.Header) error
 	SubmitAgentChecksMetadata(payload transaction.BytesPayloads, extra http.Header) error
 	SubmitMetadata(payload transaction.BytesPayloads, extra http.Header) error
 	SubmitProcessChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
 	SubmitProcessDiscoveryChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
-	SubmitProcessEventChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
 	SubmitRTProcessChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
 	SubmitContainerChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
 	SubmitRTContainerChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
 	SubmitConnectionChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
-	SubmitOrchestratorChecks(payload transaction.BytesPayloads, extra http.Header, payloadType int) (chan Response, error)
-	SubmitOrchestratorManifests(payload transaction.BytesPayloads, extra http.Header) (chan Response, error)
+	SubmitOrchestratorChecks(payload transaction.BytesPayloads, extra http.Header, payloadType int) error
+	SubmitOrchestratorManifests(payload transaction.BytesPayloads, extra http.Header) error
+
+	ForwarderV2
+}
+
+// ForwarderV2 is a minimalist forwarder interface that is product agnostic.
+type ForwarderV2 interface {
+	GetDomainResolvers() []pkgresolver.DomainResolver
+	SubmitTransaction(*transaction.HTTPTransaction) error
 }
 
 // Compile-time check to ensure that DefaultForwarder implements the Forwarder interface
@@ -105,7 +115,7 @@ type Options struct {
 	APIKeyValidationInterval       time.Duration
 	DomainResolvers                map[string]pkgresolver.DomainResolver
 	ConnectionResetInterval        time.Duration
-	CompletionHandler              transaction.HTTPCompletionHandler
+	Secrets                        secrets.Component
 }
 
 // SetFeature sets forwarder features in a feature set
@@ -120,15 +130,49 @@ func ToggleFeature(features, flag Features) Features { return features ^ flag }
 // HasFeature lets you know if a specific feature flag is set in a feature set
 func HasFeature(features, flag Features) bool { return features&flag != 0 }
 
-// NewOptions creates new Options with default values
+// getObsPipelineURL returns the URL under the 'observability_pipelines_worker.' prefix for the given datatype
+func getObsPipelineURL(log log.Component, datatype string, config pkgconfigmodel.Reader) (string, error) {
+	if config.GetBool(fmt.Sprintf("observability_pipelines_worker.%s.enabled", datatype)) {
+		return getObsPipelineURLForPrefix(log, datatype, "observability_pipelines_worker", config)
+	} else if config.GetBool(fmt.Sprintf("vector.%s.enabled", datatype)) {
+		// Fallback to the `vector` config if observability_pipelines_worker is not set.
+		return getObsPipelineURLForPrefix(log, datatype, "vector", config)
+	}
+	return "", nil
+}
+
+func getObsPipelineURLForPrefix(log log.Component, datatype string, prefix string, config pkgconfigmodel.Reader) (string, error) {
+	if config.GetBool(fmt.Sprintf("%s.%s.enabled", prefix, datatype)) {
+		pipelineURL := config.GetString(fmt.Sprintf("%s.%s.url", prefix, datatype))
+		if pipelineURL == "" {
+			log.Errorf("%s.%s.enabled is set to true, but %s.%s.url is empty", prefix, datatype, prefix, datatype)
+			return "", nil
+		}
+		_, err := url.Parse(pipelineURL)
+		if err != nil {
+			return "", fmt.Errorf("could not parse %s %s endpoint: %s", prefix, datatype, err)
+		}
+		return pipelineURL, nil
+	}
+	return "", nil
+}
+
+// NewOptions creates a configuration for the forwarder with OPW enabled.
+//
+// Deprecated, use NewOptionsWithOPW instead.
 func NewOptions(config config.Component, log log.Component, keysPerDomain map[string][]utils.APIKeys) (*Options, error) {
 
-	resolvers, err := pkgresolver.NewSingleDomainResolvers(keysPerDomain)
+	return NewOptionsWithOPW(config, log, utils.EndpointDescriptorSetFromKeysPerDomain(keysPerDomain))
+}
+
+// NewOptionsWithOPW creates a configuration for the forwarder with OPW enabled.
+func NewOptionsWithOPW(config config.Component, log log.Component, eds utils.EndpointDescriptorSet) (*Options, error) {
+	resolvers, err := pkgresolver.NewSingleDomainResolvers2(eds)
 	if err != nil {
 		return nil, err
 	}
 
-	vectorMetricsURL, err := pkgconfigsetup.GetObsPipelineURL(pkgconfigsetup.Metrics, config)
+	vectorMetricsURL, err := getObsPipelineURL(log, pkgconfigsetup.Metrics, config)
 	if err != nil {
 		log.Error("Misconfiguration of agent observability_pipelines_worker endpoint for metrics: ", err)
 	}
@@ -244,8 +288,6 @@ type DefaultForwarder struct {
 	internalState    *atomic.Uint32
 	m                sync.Mutex // To control Start/Stop races
 
-	completionHandler transaction.HTTPCompletionHandler
-
 	agentName                       string
 	queueDurationCapacity           *retry.QueueDurationCapacity
 	retryQueueDurationCapacityMutex sync.Mutex
@@ -265,13 +307,13 @@ func NewDefaultForwarder(config config.Component, log log.Component, options *Op
 		healthChecker: &forwarderHealth{
 			log:                   log,
 			config:                config,
+			secrets:               options.Secrets,
 			domainResolvers:       options.DomainResolvers,
 			disableAPIKeyChecking: options.DisableAPIKeyChecking,
 			validationInterval:    options.APIKeyValidationInterval,
 		},
-		completionHandler: options.CompletionHandler,
-		agentName:         agentName,
-		localForwarder:    nil,
+		agentName:      agentName,
+		localForwarder: nil,
 	}
 	var optionalRemovalPolicy *retry.FileRemovalPolicy
 	storageMaxSize := config.GetInt64("forwarder_storage_max_size_in_bytes")
@@ -312,24 +354,10 @@ func NewDefaultForwarder(config config.Component, log log.Component, options *Op
 	transactionContainerSort := transaction.SortByCreatedTimeAndPriority{HighPriorityFirst: false}
 
 	for domain, resolver := range options.DomainResolvers {
-		isMRF := false
-		if config.GetBool("multi_region_failover.enabled") {
-			log.Infof("MRF is enabled, checking site: %v ", domain)
-			siteURL, err := utils.GetMRFInfraEndpoint(config)
-			if err != nil {
-				log.Error("Error building MRF infra endpoint: ", err)
-			}
-			if domain == siteURL {
-				log.Infof("MRF domain '%s', configured ", domain)
-				isMRF = true
-			}
-
-		}
 		domain, _ := utils.AddAgentVersionToDomain(domain, "app")
 		resolver.SetBaseDomain(domain)
 
-		_, isLocal := resolver.(*pkgresolver.LocalDomainResolver)
-		if !isLocal && (resolver.GetAPIKeys() == nil || len(resolver.GetAPIKeys()) == 0) {
+		if !resolver.IsUsable() {
 			log.Errorf("No API keys for domain '%s', dropping domain ", domain)
 		} else {
 			var domainFolderPath string
@@ -353,15 +381,16 @@ func NewDefaultForwarder(config config.Component, log log.Component, options *Op
 				pointCountTelemetry)
 			f.domainResolvers[domain] = resolver
 			numberOfWorkers := options.NumberOfWorkers
-			if isLocal {
+			if resolver.IsLocal() {
 				numberOfWorkers = 1 // Local domain resolver should only have one worker
 			}
 			fwd := newDomainForwarder(
 				config,
 				log,
+				options.Secrets,
 				domain,
-				isMRF,
-				isLocal,
+				resolver.IsMRF(),
+				resolver.IsLocal(),
 				transactionContainer,
 				numberOfWorkers,
 				options.ConnectionResetInterval,
@@ -501,59 +530,42 @@ func (f *DefaultForwarder) createAdvancedHTTPTransactions(endpoint transaction.E
 
 	for _, payload := range payloads {
 		for domain, dr := range f.domainResolvers {
-			drDomain, destinationType := dr.Resolve(endpoint) // drDomain is the domain with agent version if not local
-			if payload.Destination == transaction.LocalOnly {
-				// if it is local payload, we should not send it to the remote endpoint
-				if destinationType == pkgresolver.Local && endpoint == endpoints.SeriesEndpoint {
-					t := transaction.NewHTTPTransaction()
-					t.Domain = drDomain
-					t.Endpoint = endpoint
-					t.Payload = payload
-					t.Priority = priority
-					t.Kind = kind
-					t.StorableOnDisk = storableOnDisk
-					t.Destination = payload.Destination
-					t.Headers.Set("Authorization", fmt.Sprintf("Bearer %s", dr.GetBearerAuthToken()))
-					for key := range extra {
-						t.Headers.Set(key, extra.Get(key))
-					}
-					tlmTxInputCount.Inc(drDomain, endpoint.Name)
-					tlmTxInputBytes.Add(float64(t.GetPayloadSize()), domain, endpoint.Name)
-					transactionsInputCountByEndpoint.Add(endpoint.Name, 1)
-					transactionsInputBytesByEndpoint.Add(endpoint.Name, int64(t.GetPayloadSize()))
-					transactions = append(transactions, t)
+			drDomain := dr.Resolve(endpoint) // drDomain is the domain with agent version if not local
+
+			// Autoscaling failover payloads, and only them, should go to the local resolver.
+			if (payload.Destination == transaction.LocalOnly) != dr.IsLocal() {
+				continue
+			}
+			// Autoscaling failover endpoint can only receive series payloads.
+			if dr.IsLocal() && endpoint != endpoints.SeriesEndpoint {
+				continue
+			}
+
+			for _, auth := range dr.GetAuthorizers() {
+				t := transaction.NewHTTPTransaction()
+				t.Domain = drDomain
+				t.Endpoint = endpoint
+				t.Payload = payload
+				t.Priority = priority
+				t.Kind = kind
+				t.StorableOnDisk = storableOnDisk
+				t.Destination = payload.Destination
+				auth.Authorize(t)
+				t.Headers.Set(versionHTTPHeaderKey, version.AgentVersion)
+				t.Headers.Set(useragentHTTPHeaderKey, fmt.Sprintf("datadog-agent/%s", version.AgentVersion))
+				if allowArbitraryTags {
+					t.Headers.Set(arbitraryTagHTTPHeaderKey, "true")
 				}
-			} else {
-				for _, apiKey := range dr.GetAPIKeys() {
-					t := transaction.NewHTTPTransaction()
-					t.Domain = drDomain
-					t.Endpoint = endpoint
-					t.Payload = payload
-					t.Priority = priority
-					t.Kind = kind
-					t.StorableOnDisk = storableOnDisk
-					t.Destination = payload.Destination
-					t.Headers.Set(apiHTTPHeaderKey, apiKey)
-					t.Headers.Set(versionHTTPHeaderKey, version.AgentVersion)
-					t.Headers.Set(useragentHTTPHeaderKey, fmt.Sprintf("datadog-agent/%s", version.AgentVersion))
-					if allowArbitraryTags {
-						t.Headers.Set(arbitraryTagHTTPHeaderKey, "true")
-					}
 
-					if f.completionHandler != nil {
-						t.CompletionHandler = f.completionHandler
-					}
+				tlmTxInputCount.Inc(domain, endpoint.Name)
+				tlmTxInputBytes.Add(float64(t.GetPayloadSize()), domain, endpoint.Name)
+				transactionsInputCountByEndpoint.Add(endpoint.Name, 1)
+				transactionsInputBytesByEndpoint.Add(endpoint.Name, int64(t.GetPayloadSize()))
 
-					tlmTxInputCount.Inc(domain, endpoint.Name)
-					tlmTxInputBytes.Add(float64(t.GetPayloadSize()), domain, endpoint.Name)
-					transactionsInputCountByEndpoint.Add(endpoint.Name, 1)
-					transactionsInputBytesByEndpoint.Add(endpoint.Name, int64(t.GetPayloadSize()))
-
-					for key := range extra {
-						t.Headers.Set(key, extra.Get(key))
-					}
-					transactions = append(transactions, t)
+				for key := range extra {
+					t.Headers.Set(key, extra.Get(key))
 				}
+				transactions = append(transactions, t)
 			}
 		}
 	}
@@ -685,11 +697,6 @@ func (f *DefaultForwarder) SubmitProcessDiscoveryChecks(payload transaction.Byte
 	return f.submitProcessLikePayload(endpoints.ProcessDiscoveryEndpoint, payload, extra, true)
 }
 
-// SubmitProcessEventChecks sends process events checks
-func (f *DefaultForwarder) SubmitProcessEventChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error) {
-	return f.submitProcessLikePayload(endpoints.ProcessLifecycleEndpoint, payload, extra, true)
-}
-
 // SubmitRTProcessChecks sends real time process checks
 func (f *DefaultForwarder) SubmitRTProcessChecks(payload transaction.BytesPayloads, extra http.Header) (chan Response, error) {
 	return f.submitProcessLikePayload(endpoints.RtProcessesEndpoint, payload, extra, false)
@@ -711,21 +718,22 @@ func (f *DefaultForwarder) SubmitConnectionChecks(payload transaction.BytesPaylo
 }
 
 // SubmitOrchestratorChecks sends orchestrator checks
-func (f *DefaultForwarder) SubmitOrchestratorChecks(payload transaction.BytesPayloads, extra http.Header, payloadType int) (chan Response, error) {
+func (f *DefaultForwarder) SubmitOrchestratorChecks(payload transaction.BytesPayloads, extra http.Header, payloadType int) error {
 	bumpOrchestratorPayload(f.log, payloadType)
 
 	endpoint := endpoints.OrchestratorEndpoint
 	if f.config.IsSet("orchestrator_explorer.use_legacy_endpoint") {
 		endpoint = endpoints.LegacyOrchestratorEndpoint
 	}
-
-	return f.submitProcessLikePayload(endpoint, payload, extra, true)
+	transactions := f.createHTTPTransactions(endpoint, payload, transaction.Process, extra)
+	return f.sendHTTPTransactions(transactions)
 }
 
 // SubmitOrchestratorManifests sends orchestrator manifests
-func (f *DefaultForwarder) SubmitOrchestratorManifests(payload transaction.BytesPayloads, extra http.Header) (chan Response, error) {
+func (f *DefaultForwarder) SubmitOrchestratorManifests(payload transaction.BytesPayloads, extra http.Header) error {
 	transactionsOrchestratorManifest.Add(1)
-	return f.submitProcessLikePayload(endpoints.OrchestratorManifestEndpoint, payload, extra, true)
+	transactions := f.createHTTPTransactions(endpoints.OrchestratorManifestEndpoint, payload, transaction.Process, extra)
+	return f.sendHTTPTransactions(transactions)
 }
 
 func (f *DefaultForwarder) submitProcessLikePayload(ep transaction.Endpoint, payload transaction.BytesPayloads, extra http.Header, retryable bool) (chan Response, error) {
@@ -776,3 +784,25 @@ func (f *DefaultForwarder) submitProcessLikePayload(ep transaction.Endpoint, pay
 
 	return results, f.sendHTTPTransactions(transactions)
 }
+
+// GetDomainResolvers returns the list of resolvers used by this forwarder.
+func (f *DefaultForwarder) GetDomainResolvers() []pkgresolver.DomainResolver {
+	return slices.Collect(maps.Values(f.domainResolvers))
+}
+
+// SubmitTransaction adds a transaction to the queue for sending.
+func (f *DefaultForwarder) SubmitTransaction(t *transaction.HTTPTransaction) error {
+	t.Headers.Set(versionHTTPHeaderKey, version.AgentVersion)
+	t.Headers.Set(useragentHTTPHeaderKey, fmt.Sprintf("datadog-agent/%s", version.AgentVersion))
+
+	if f.config.GetBool("allow_arbitrary_tags") {
+		t.Headers.Set(arbitraryTagHTTPHeaderKey, "true")
+	}
+
+	tlmTxInputCount.Inc(t.Domain, t.Endpoint.Name)
+	tlmTxInputBytes.Add(float64(t.GetPayloadSize()), t.Domain, t.Endpoint.Name)
+	transactionsInputCountByEndpoint.Add(t.Endpoint.Name, 1)
+	transactionsInputBytesByEndpoint.Add(t.Endpoint.Name, int64(t.GetPayloadSize()))
+
+	return f.sendHTTPTransactions([]*transaction.HTTPTransaction{t})
+}
