@@ -15,14 +15,14 @@ import (
 	"path/filepath"
 	"reflect"
 	"slices"
+	"sort"
 	"strings"
 	"sync"
 
 	"go.uber.org/atomic"
 
-	"github.com/mitchellh/mapstructure"
-
 	"github.com/DataDog/datadog-agent/pkg/config/model"
+	"github.com/DataDog/datadog-agent/pkg/config/viperconfig"
 	"github.com/DataDog/datadog-agent/pkg/util/log"
 )
 
@@ -71,6 +71,9 @@ type ntmConfig struct {
 	// - it's okay to modify the config schema after it gets built
 	// - unknown keys can be assigned and retrieved
 	allowDynamicSchema *atomic.Bool
+	// state of env vars, only used by tests to decide when to rebuild the env var layer. Necessary because
+	// viper would lookup env vars at runtime, instead of storing them, and many many tests rely on this behavior
+	lastEnvVarState string
 
 	// tree debugger is used by the Stringify method, useful for debugging and test assertions
 	td *treeDebugger
@@ -103,7 +106,6 @@ type ntmConfig struct {
 	envTransform   map[string]func(string) interface{}
 
 	notificationReceivers []model.NotificationReceiver
-	notificationChannel   chan model.ConfigChangeNotification
 	sequenceID            uint64
 
 	// Proxy settings
@@ -142,15 +144,6 @@ type NodeTreeConfig interface {
 	GetNode(string) (Node, error)
 }
 
-func (c *ntmConfig) processNotifications() {
-	for notification := range c.notificationChannel {
-		// notifying all receivers about the updated setting
-		for _, receiver := range notification.Receivers {
-			receiver(notification.Key, notification.PreviousValue, notification.NewValue, notification.SequenceID)
-		}
-	}
-}
-
 // OnUpdate adds a callback to the list of receivers to be called each time a value is changed in the configuration
 // by a call to the 'Set' method.
 // Callbacks are only called if the value is effectively changed.
@@ -160,31 +153,16 @@ func (c *ntmConfig) OnUpdate(callback model.NotificationReceiver) {
 	c.notificationReceivers = append(c.notificationReceivers, callback)
 }
 
-func (c *ntmConfig) sendNotification(key string, oldValue, newValue interface{}, sequenceID uint64) {
-	if len(c.notificationReceivers) == 0 {
-		return
-	}
-
-	notification := model.ConfigChangeNotification{
-		Key:           key,
-		PreviousValue: oldValue,
-		NewValue:      newValue,
-		SequenceID:    sequenceID,
-		Receivers:     slices.Clone(c.notificationReceivers),
-	}
-
-	c.notificationChannel <- notification
-}
-
 func (c *ntmConfig) addToSchema(key string, source model.Source) {
 	parts := splitKey(key)
-	_, _ = c.schema.SetAt(parts, nil, source)
-
+	_ = c.schema.SetAt(parts, nil, source)
 	c.addToKnownKeys(key)
 }
 
 func (c *ntmConfig) getTreeBySource(source model.Source) (InnerNode, error) {
 	switch source {
+	case "root":
+		return c.root, nil
 	case model.SourceDefault:
 		return c.defaults, nil
 	case model.SourceUnknown:
@@ -204,7 +182,7 @@ func (c *ntmConfig) getTreeBySource(source model.Source) (InnerNode, error) {
 	case model.SourceCLI:
 		return c.cli, nil
 	}
-	return nil, fmt.Errorf("invalid source tree: %s", source)
+	return nil, fmt.Errorf("invalid source: %s", source)
 }
 
 // SetTestOnlyDynamicSchema allows more flexible usage of the config, should only be used by tests
@@ -212,68 +190,94 @@ func (c *ntmConfig) SetTestOnlyDynamicSchema(allow bool) {
 	c.allowDynamicSchema.Store(allow)
 }
 
+// RevertFinishedBackToBuilder returns an interface that can build more on the current
+// config, instead of treating it as sealed
+// NOTE: Only used by OTel, no new uses please!
+func (c *ntmConfig) RevertFinishedBackToBuilder() model.BuildableConfig {
+	c.ready.Store(false)
+	return c
+}
+
 // Set assigns the newValue to the given key and marks it as originating from the given source
 func (c *ntmConfig) Set(key string, newValue interface{}, source model.Source) {
-	c.maybeRebuild()
-
-	tree, err := c.getTreeBySource(source)
-	if err != nil {
-		log.Errorf("Set invalid source: %s", source)
-		return
+	if source == model.SourceEnvVar {
+		panicInTest("Writing to env var layers is not allowed, use SourceAgentRuntime instead.")
 	}
 
-	if !c.IsKnown(key) {
+	c.maybeRebuild()
+
+	c.Lock()
+
+	if !c.isKnownKey(key) {
 		if c.allowDynamicSchema.Load() {
 			log.Errorf("set value for unknown key '%s'", key)
 		} else {
 			log.Errorf("could not set '%s' unknown key", key)
+			c.Unlock()
 			return
 		}
 	}
+	schemaNode := c.nodeAtPathFromNode(key, c.schema)
+	if _, ok := schemaNode.(LeafNode); schemaNode != missingLeaf && !ok {
+		panicInTest("Key '%s' is partial path of a setting. 'Set' does not allow configuring multiple settings at once using maps", key)
+		c.Unlock()
+		return
+	}
+
 	// convert the key to lower case for the logs line and the notification
 	key = strings.ToLower(key)
 
-	c.Lock()
-	defer c.Unlock()
 	previousValue := c.leafAtPathFromNode(key, c.root).Get()
 
-	parts := splitKey(key)
-
-	_, err = tree.SetAt(parts, newValue, source)
+	newTree, err := c.insertValueIntoTree(key, newValue, source)
 	if err != nil {
-		log.Errorf("could not set '%s' invalid key: %s", key, err)
+		log.Errorf("could not insert value: %s", err)
+		c.Unlock()
+		return
+	} else if newTree != nil {
+		// a new node was allocated, merge it into root
+		c.root, _ = c.root.Merge(newTree.(InnerNode))
 	}
 
-	updated, err := c.root.SetAt(parts, newValue, source)
-	if err != nil {
-		log.Errorf("could not set '%s' invalid key: %s", key, err)
-	}
+	receivers := slices.Clone(c.notificationReceivers)
 
 	// if no value has changed we don't notify
-	if !updated || reflect.DeepEqual(previousValue, newValue) {
+	if reflect.DeepEqual(previousValue, newValue) {
+		c.Unlock()
 		return
 	}
 
 	c.sequenceID++
-	c.sendNotification(key, previousValue, newValue, c.sequenceID)
+	c.Unlock()
 
+	// notifying all receiver about the updated setting
+	for _, receiver := range receivers {
+		receiver(key, source, previousValue, newValue, c.sequenceID)
+	}
 }
 
-// SetWithoutSource assigns the value to the given key using source Unknown
+func (c *ntmConfig) insertValueIntoTree(key string, value interface{}, source model.Source) (Node, error) {
+	tree, err := c.getTreeBySource(source)
+	if err != nil {
+		return nil, log.Errorf("Set invalid source: %s", source)
+	}
+
+	parts := splitKey(key)
+	err = tree.SetAt(parts, value, source)
+	return tree, err
+}
+
+// SetWithoutSource assigns the value to the given key using source Unknown, may only be called from tests
 func (c *ntmConfig) SetWithoutSource(key string, value interface{}) {
-	v := reflect.ValueOf(value)
-	if v.Kind() == reflect.Struct {
-		panic("You cannot set a struct as a value")
+	c.assertIsTest("SetWithoutSource")
+	if !viperconfig.ValidateBasicTypes(value) {
+		panic(fmt.Errorf("SetWithoutSource can only be called with basic types (int, string, slice, map, etc), got %v", value))
 	}
 	c.Set(key, value, model.SourceUnknown)
-	keySet := make(map[string]struct{}, len(c.allSettings))
-	for _, k := range c.allSettings {
-		keySet[k] = struct{}{}
-	}
-	keySet[key] = struct{}{}
-	allKeys := slices.Collect(maps.Keys(keySet))
-	slices.Sort(allKeys)
-	c.allSettings = allKeys
+
+	c.Lock()
+	defer c.Unlock()
+	c.computeAllSettings()
 }
 
 // SetDefault assigns the value to the given key using source Default
@@ -290,7 +294,7 @@ func (c *ntmConfig) SetDefault(key string, value interface{}) {
 	parts := splitKey(key)
 	// TODO: Ensure that for default tree, setting nil to a node will not override
 	// an existing value
-	_, _ = c.defaults.SetAt(parts, value, model.SourceDefault)
+	_ = c.defaults.SetAt(parts, value, model.SourceDefault)
 }
 
 func (c *ntmConfig) findPreviousSourceNode(key string, source model.Source) (Node, error) {
@@ -368,8 +372,12 @@ func (c *ntmConfig) UnsetForSource(key string, source model.Source) {
 	}
 
 	c.sequenceID++
-	c.sendNotification(key, previousValue, newValue, c.sequenceID)
+	receivers := slices.Clone(c.notificationReceivers)
 
+	// notifying all receiver about the updated setting
+	for _, receiver := range receivers {
+		receiver(key, source, previousValue, newValue, c.sequenceID)
+	}
 }
 
 func (c *ntmConfig) parentOfNode(node Node, key string) (InnerNode, string, error) {
@@ -430,10 +438,24 @@ func (c *ntmConfig) isKnownKey(key string) bool {
 
 func (c *ntmConfig) maybeRebuild() {
 	if c.allowDynamicSchema.Load() {
+		// Write-lock because the root will be written to in order to rebuild the state
+		c.Lock()
+		defer c.Unlock()
+
+		// Only need to rebuild if env vars have different state than last rebuild
+		envs := os.Environ()
+		sort.Strings(envs)
+		envVarState := strings.Join(envs, "$")
+		if c.lastEnvVarState == envVarState {
+			return
+		}
+		c.lastEnvVarState = envVarState
+
 		// building the schema may access data from the config, disable the dynamic schema
 		// flag to prevent recursive rebuilds
 		c.allowDynamicSchema.Store(false)
 		defer func() { c.allowDynamicSchema.Store(true) }()
+
 		c.buildSchema()
 	}
 }
@@ -443,8 +465,6 @@ func (c *ntmConfig) maybeRebuild() {
 //
 // Must be called with the lock read-locked.
 func (c *ntmConfig) checkKnownKey(key string) {
-	c.maybeRebuild()
-
 	if c.isKnownKey(key) {
 		return
 	}
@@ -472,37 +492,33 @@ func (c *ntmConfig) mergeAllLayers() error {
 		c.cli,
 	}
 
-	root := newInnerNode(nil)
+	var merged InnerNode = newInnerNode(nil)
 	for _, tree := range treeList {
-		err := root.Merge(tree)
+		next, err := merged.Merge(tree)
 		if err != nil {
 			return err
 		}
+		merged = next
 	}
 
-	c.root = root
+	c.root = merged
 	// recompile allSettings now that we have the full config
-	c.allSettings = c.computeAllSettings("")
+	c.computeAllSettings()
 	return nil
 }
 
-func (c *ntmConfig) computeAllSettings(path string) []string {
-	c.maybeRebuild()
-
+func (c *ntmConfig) computeAllSettings() {
 	keySet := make(map[string]struct{})
 
 	// 1. Collect all known keys from schema
-	c.collectKeysFromNode(c.schema, path, keySet, true)
+	c.collectKeysFromNode(c.schema, "", keySet, true)
 
 	// 2. Collect all keys from merged tree (only ones with values)
 	c.collectKeysFromNode(c.root, "", keySet, false)
 
-	// 3. Collect all unknown keys, even if they have no value set
-	c.collectKeysFromNode(c.unknown, "", keySet, true)
-
 	allKeys := slices.Collect(maps.Keys(keySet))
 	slices.Sort(allKeys)
-	return allKeys
+	c.allSettings = allKeys
 }
 
 func (c *ntmConfig) collectKeysFromNode(node InnerNode, path string, keySet map[string]struct{}, includeAllKeys bool) {
@@ -536,7 +552,7 @@ func (c *ntmConfig) buildSchema() {
 	if err := c.mergeAllLayers(); err != nil {
 		c.warnings = append(c.warnings, err)
 	}
-	c.allSettings = c.computeAllSettings("")
+	c.computeAllSettings()
 }
 
 // Stringify stringifies the config, but only with the test build tag
@@ -577,20 +593,22 @@ func (c *ntmConfig) buildEnvVars() {
 
 func (c *ntmConfig) insertNodeFromString(curr InnerNode, key string, envval string) error {
 	var actualValue interface{} = envval
-	// TODO: When the nodetreemodel config is further along, we should get the default[key] node
-	// and use its type to convert the envval into something appropriate.
+	// TODO: When nodetreemodel has a schema with type information, we should
+	// use this type to convert the value, instead of requiring a transformer
 	if transformer, found := c.envTransform[key]; found {
 		actualValue = transformer(envval)
 	}
 	parts := splitKeyFunc(key)
-	_, err := curr.SetAt(parts, actualValue, model.SourceEnvVar)
-	return err
+	return curr.SetAt(parts, actualValue, model.SourceEnvVar)
 }
 
 // ParseEnvAsStringSlice registers a transform function to parse an environment variable as a []string.
 func (c *ntmConfig) ParseEnvAsStringSlice(key string, fn func(string) []string) {
 	c.Lock()
 	defer c.Unlock()
+	if _, exists := c.envTransform[strings.ToLower(key)]; exists {
+		panic(fmt.Sprintf("env transform for %s already exists", key))
+	}
 	c.envTransform[strings.ToLower(key)] = func(k string) interface{} { return fn(k) }
 }
 
@@ -598,6 +616,9 @@ func (c *ntmConfig) ParseEnvAsStringSlice(key string, fn func(string) []string)
 func (c *ntmConfig) ParseEnvAsMapStringInterface(key string, fn func(string) map[string]interface{}) {
 	c.Lock()
 	defer c.Unlock()
+	if _, exists := c.envTransform[strings.ToLower(key)]; exists {
+		panic(fmt.Sprintf("env transform for %s already exists", key))
+	}
 	c.envTransform[strings.ToLower(key)] = func(k string) interface{} { return fn(k) }
 }
 
@@ -605,6 +626,9 @@ func (c *ntmConfig) ParseEnvAsMapStringInterface(key string, fn func(string) map
 func (c *ntmConfig) ParseEnvAsSliceMapString(key string, fn func(string) []map[string]string) {
 	c.Lock()
 	defer c.Unlock()
+	if _, exists := c.envTransform[strings.ToLower(key)]; exists {
+		panic(fmt.Sprintf("env transform for %s already exists", key))
+	}
 	c.envTransform[strings.ToLower(key)] = func(k string) interface{} { return fn(k) }
 }
 
@@ -612,6 +636,9 @@ func (c *ntmConfig) ParseEnvAsSliceMapString(key string, fn func(string) []map[s
 func (c *ntmConfig) ParseEnvAsSlice(key string, fn func(string) []interface{}) {
 	c.Lock()
 	defer c.Unlock()
+	if _, exists := c.envTransform[strings.ToLower(key)]; exists {
+		panic(fmt.Sprintf("env transform for %s already exists", key))
+	}
 	c.envTransform[strings.ToLower(key)] = func(k string) interface{} { return fn(k) }
 }
 
@@ -639,17 +666,18 @@ func (c *ntmConfig) IsSet(key string) bool {
 	return true
 }
 
-func hasNoneDefaultsLeaf(node InnerNode) bool {
+func hasNonDefaultLeaf(node InnerNode) bool {
 	// We're on an InnerNode, we need to check if any child leaf are not defaults
 	for _, name := range node.ChildrenKeys() {
 		child, _ := node.GetChild(name)
 		if leaf, ok := child.(LeafNode); ok {
-			if leaf.Source().IsGreaterThan(model.SourceDefault) {
+			// Leaf has to be on a non-default layer and have a non-nil value
+			if leaf.Source().IsGreaterThan(model.SourceDefault) && leaf.Get() != nil {
 				return true
 			}
 			continue
 		}
-		if hasNoneDefaultsLeaf(child.(InnerNode)) {
+		if hasNonDefaultLeaf(child.(InnerNode)) {
 			return true
 		}
 	}
@@ -677,11 +705,42 @@ func (c *ntmConfig) IsConfigured(key string) bool {
 	}
 	// if key is a leaf, we just check the source
 	if leaf, ok := curr.(LeafNode); ok {
-		return leaf.Source().IsGreaterThan(model.SourceDefault)
+		return leaf.Source().IsGreaterThan(model.SourceDefault) && leaf.Get() != nil
 	}
 
 	// if the key was an InnerNode we need to check all the inner leaf node to check if one was set by the user
-	return hasNoneDefaultsLeaf(curr.(InnerNode))
+	return hasNonDefaultLeaf(curr.(InnerNode))
+}
+
+func isInnerOrLeafWithNilValue(node Node) bool {
+	if node == missingLeaf {
+		return false
+	}
+	if _, isInner := node.(InnerNode); isInner {
+		return true
+	}
+	if leaf, isLeaf := node.(LeafNode); isLeaf {
+		return leaf.Get() == nil
+	}
+	return false
+}
+
+// HasSection returns true if the setting is either an inner node,
+// or a leaf node with a nil value
+func (c *ntmConfig) HasSection(key string) bool {
+	c.RLock()
+	defer c.RUnlock()
+
+	for _, src := range model.Sources {
+		if src == model.SourceDefault {
+			continue
+		}
+		tree, _ := c.getTreeBySource(src)
+		if isInnerOrLeafWithNilValue(c.nodeAtPathFromNode(key, tree)) {
+			return true
+		}
+	}
+	return false
 }
 
 // AllKeysLowercased returns all keys lower-cased from the default tree, including keys that are merely marked as known
@@ -733,6 +792,7 @@ func (c *ntmConfig) GetNode(key string) (Node, error) {
 func (c *ntmConfig) SetEnvPrefix(in string) {
 	c.Lock()
 	defer c.Unlock()
+	c.envTransform = make(map[string]func(string) interface{})
 	c.envPrefix = in
 }
 
@@ -777,15 +837,6 @@ func (c *ntmConfig) SetEnvKeyReplacer(r *strings.Replacer) {
 	c.envKeyReplacer = r
 }
 
-// UnmarshalKey unmarshals the data for the given key
-// DEPRECATED: use pkg/config/structure.UnmarshalKey instead
-func (c *ntmConfig) UnmarshalKey(key string, _rawVal interface{}, _opts ...func(*mapstructure.DecoderConfig)) error {
-	c.RLock()
-	defer c.RUnlock()
-	c.checkKnownKey(key)
-	return fmt.Errorf("nodetreemodel.UnmarshalKey not available, use pkg/config/structure.UnmarshalKey instead")
-}
-
 // MergeConfig merges in another config
 func (c *ntmConfig) MergeConfig(in io.Reader) error {
 	c.Lock()
@@ -805,7 +856,12 @@ func (c *ntmConfig) MergeConfig(in io.Reader) error {
 		return err
 	}
 
-	return c.root.Merge(other)
+	merged, err := c.root.Merge(other)
+	if err != nil {
+		return err
+	}
+	c.root = merged
+	return nil
 }
 
 // MergeFleetPolicy merges the configuration from the reader given with an existing config
@@ -840,23 +896,30 @@ func (c *ntmConfig) MergeFleetPolicy(configPath string) error {
 		return err
 	}
 
-	return c.root.Merge(other)
+	merged, err := c.root.Merge(other)
+	if err != nil {
+		return err
+	}
+	c.root = merged
+	return nil
 }
 
 // AllSettings returns all settings from the config
 func (c *ntmConfig) AllSettings() map[string]interface{} {
+	c.maybeRebuild()
+
 	c.RLock()
 	defer c.RUnlock()
-	c.maybeRebuild()
 
 	return c.root.DumpSettings(func(model.Source) bool { return true })
 }
 
 // AllSettingsWithoutDefault returns a copy of the all the settings in the configuration without defaults
 func (c *ntmConfig) AllSettingsWithoutDefault() map[string]interface{} {
+	c.maybeRebuild()
+
 	c.RLock()
 	defer c.RUnlock()
-	c.maybeRebuild()
 
 	// We only want to include leaf with a source higher than SourceDefault
 	return c.root.DumpSettings(func(source model.Source) bool { return source.IsGreaterThan(model.SourceDefault) })
@@ -864,6 +927,8 @@ func (c *ntmConfig) AllSettingsWithoutDefault() map[string]interface{} {
 
 // AllSettingsBySource returns the settings from each source (file, env vars, ...)
 func (c *ntmConfig) AllSettingsBySource() map[model.Source]interface{} {
+	c.maybeRebuild()
+
 	c.RLock()
 	defer c.RUnlock()
 
@@ -878,14 +943,16 @@ func (c *ntmConfig) AllSettingsBySource() map[model.Source]interface{} {
 		model.SourceLocalConfigProcess: c.localConfigProcess.DumpSettings(func(model.Source) bool { return true }),
 		model.SourceRC:                 c.remoteConfig.DumpSettings(func(model.Source) bool { return true }),
 		model.SourceCLI:                c.cli.DumpSettings(func(model.Source) bool { return true }),
+		model.SourceProvided:           c.root.DumpSettings(func(src model.Source) bool { return src != model.SourceDefault }),
 	}
 }
 
 // AllSettingsWithSequenceID returns the settings and the sequence ID.
 func (c *ntmConfig) AllSettingsWithSequenceID() (map[string]interface{}, uint64) {
+	c.maybeRebuild()
+
 	c.RLock()
 	defer c.RUnlock()
-	c.maybeRebuild()
 	return c.root.DumpSettings(func(model.Source) bool { return true }), c.sequenceID
 }
 
@@ -967,9 +1034,21 @@ func (c *ntmConfig) ConfigFileUsed() string {
 	return c.configFile
 }
 
+// GetSubfields returns the names of child fields of this setting
+func (c *ntmConfig) GetSubfields(key string) []string {
+	n, err := c.GetNode(key)
+	if err != nil {
+		return nil
+	}
+	if inner, ok := n.(*innerNode); ok {
+		return inner.ChildrenKeys()
+	}
+	return nil
+}
+
 // BindEnvAndSetDefault binds an environment variable and sets a default for the given key
 func (c *ntmConfig) BindEnvAndSetDefault(key string, val interface{}, envvars ...string) {
-	c.BindEnv(key, envvars...) //nolint:errcheck
+	c.BindEnv(key, envvars...) //nolint:forbidigo // TODO: replace by 'SetDefaultAndBindEnv' //nolint:errcheck
 	c.SetDefault(key, val)
 }
 
@@ -984,36 +1063,34 @@ func (c *ntmConfig) Object() model.Reader {
 }
 
 // NewNodeTreeConfig returns a new Config object.
-func NewNodeTreeConfig(name string, envPrefix string, envKeyReplacer *strings.Replacer) model.Config {
+func NewNodeTreeConfig(name string, envPrefix string, envKeyReplacer *strings.Replacer) model.BuildableConfig {
 	config := ntmConfig{
-		ready:               atomic.NewBool(false),
-		allowDynamicSchema:  atomic.NewBool(false),
-		sequenceID:          0,
-		configEnvVars:       map[string][]string{},
-		knownKeys:           map[string]struct{}{},
-		allSettings:         []string{},
-		unknownKeys:         map[string]struct{}{},
-		schema:              newInnerNode(nil),
-		defaults:            newInnerNode(nil),
-		file:                newInnerNode(nil),
-		unknown:             newInnerNode(nil),
-		envs:                newInnerNode(nil),
-		runtime:             newInnerNode(nil),
-		localConfigProcess:  newInnerNode(nil),
-		remoteConfig:        newInnerNode(nil),
-		fleetPolicies:       newInnerNode(nil),
-		cli:                 newInnerNode(nil),
-		envTransform:        make(map[string]func(string) interface{}),
-		configName:          "datadog",
-		notificationChannel: make(chan model.ConfigChangeNotification, 1000),
+		ready:              atomic.NewBool(false),
+		allowDynamicSchema: atomic.NewBool(false),
+		sequenceID:         0,
+		configEnvVars:      map[string][]string{},
+		knownKeys:          map[string]struct{}{},
+		allSettings:        []string{},
+		unknownKeys:        map[string]struct{}{},
+		schema:             newInnerNode(nil),
+		defaults:           newInnerNode(nil),
+		file:               newInnerNode(nil),
+		unknown:            newInnerNode(nil),
+		envs:               newInnerNode(nil),
+		runtime:            newInnerNode(nil),
+		localConfigProcess: newInnerNode(nil),
+		remoteConfig:       newInnerNode(nil),
+		fleetPolicies:      newInnerNode(nil),
+		cli:                newInnerNode(nil),
+		root:               newInnerNode(nil),
+		envTransform:       make(map[string]func(string) interface{}),
+		configName:         "datadog",
 	}
 
 	config.SetConfigName(name)
 	config.SetEnvPrefix(envPrefix)
 	config.SetEnvKeyReplacer(envKeyReplacer)
 
-	go config.processNotifications()
-
 	return &config
 }
 
