@@ -8,8 +8,8 @@ package nodetreemodel
 import (
 	"fmt"
 	"reflect"
-	"slices"
 
+	"github.com/DataDog/datadog-agent/pkg/config/helper"
 	"github.com/DataDog/datadog-agent/pkg/config/model"
 )
 
@@ -38,25 +38,9 @@ func mapToMapString(m reflect.Value) map[string]interface{} {
 	return res
 }
 
-// valid kinds to call IsNil on
-var nillableKinds = []reflect.Kind{reflect.Chan, reflect.Func, reflect.Map, reflect.Ptr, reflect.Interface, reflect.Slice}
-
-// IsNilValue returns true if a is nil, or a is an interface with nil data
-func IsNilValue(a interface{}) bool {
-	if a == nil {
-		return true
-	}
-	rv := reflect.ValueOf(a)
-	// check if IsNil may be called in order to avoid a panic
-	if slices.Contains(nillableKinds, rv.Kind()) {
-		return reflect.ValueOf(a).IsNil()
-	}
-	return false
-}
-
 // NewNodeTree will recursively create nodes from the input value to construct a tree
 func NewNodeTree(v interface{}, source model.Source) (Node, error) {
-	if IsNilValue(v) {
+	if helper.IsNilValue(v) {
 		// nil as a value acts as the zero value, and the cast library will correctly
 		// convert it to zero values for the types we handle
 		return newLeafNode(nil, source), nil
@@ -122,8 +106,8 @@ type InnerNode interface {
 	Node
 	HasChild(string) bool
 	ChildrenKeys() []string
-	Merge(InnerNode) error
-	SetAt([]string, interface{}, model.Source) (bool, error)
+	Merge(InnerNode) (InnerNode, error)
+	SetAt([]string, interface{}, model.Source) error
 	InsertChildNode(string, Node)
 	RemoveChild(string)
 	DumpSettings(func(model.Source) bool) map[string]interface{}
@@ -133,6 +117,7 @@ type InnerNode interface {
 type LeafNode interface {
 	Node
 	Get() interface{}
+	ReplaceValue(v interface{}) error
 	Source() model.Source
 	SourceGreaterThan(model.Source) bool
 }
