@@ -13,7 +13,8 @@ import (
 	pkgconfigmodel "github.com/DataDog/datadog-agent/pkg/config/model"
 )
 
-func platformCWSConfig(cfg pkgconfigmodel.Config) {
+func platformCWSConfig(cfg pkgconfigmodel.Setup) {
 	cfg.BindEnvAndSetDefault("runtime_security_config.policies.dir", DefaultRuntimePoliciesDir)
 	cfg.BindEnvAndSetDefault("runtime_security_config.socket", filepath.Join(InstallPath, "run/runtime-security.sock"))
+	cfg.BindEnvAndSetDefault("runtime_security_config.cmd_socket", "")
 }
