@@ -15,16 +15,14 @@ import (
 	"strings"
 	"time"
 
-	"github.com/mitchellh/mapstructure"
-
 	"github.com/DataDog/datadog-agent/pkg/config/model"
 	"github.com/DataDog/datadog-agent/pkg/util/log"
 )
 
 // teeConfig is a combination of two configs, both get written to but only baseline is read
 type teeConfig struct {
-	baseline model.Config
-	compare  model.Config
+	baseline model.BuildableConfig
+	compare  model.BuildableConfig
 }
 
 func getLocation(nbStack int) string {
@@ -34,10 +32,19 @@ func getLocation(nbStack int) string {
 }
 
 // NewTeeConfig constructs a new teeConfig
-func NewTeeConfig(baseline, compare model.Config) model.Config {
+func NewTeeConfig(baseline, compare model.BuildableConfig) model.BuildableConfig {
 	return &teeConfig{baseline: baseline, compare: compare}
 }
 
+// RevertFinishedBackToBuilder returns an interface that can build more on the
+// current config, instead of treating it as sealed
+// NOTE: Only used by OTel, no new uses please!
+func (t *teeConfig) RevertFinishedBackToBuilder() model.BuildableConfig {
+	t.baseline.RevertFinishedBackToBuilder() //nolint:forbidigo // legitimate use within interface implementation
+	t.compare.RevertFinishedBackToBuilder()  //nolint:forbidigo // legitimate use within interface implementation
+	return t
+}
+
 // OnUpdate adds a callback to the list receivers to be called each time a value is changed in the configuration
 // by a call to the 'Set' method.
 // Callbacks are only called if the value is effectively changed.
@@ -78,8 +85,8 @@ func (t *teeConfig) UnsetForSource(key string, source model.Source) {
 
 // SetKnown adds a key to the set of known valid config keys
 func (t *teeConfig) SetKnown(key string) {
-	t.baseline.SetKnown(key)
-	t.compare.SetKnown(key)
+	t.baseline.SetKnown(key) //nolint:forbidigo // TODO: replace by 'SetDefaultAndBindEnv'
+	t.compare.SetKnown(key)  //nolint:forbidigo // TODO: replace by 'SetDefaultAndBindEnv'
 }
 
 // IsKnown returns whether a key is known
@@ -152,6 +159,14 @@ func (t *teeConfig) IsConfigured(key string) bool {
 	return base
 }
 
+// HasSection returns true if the section exists in the config
+func (t *teeConfig) HasSection(key string) bool {
+	base := t.baseline.HasSection(key)
+	compare := t.compare.HasSection(key)
+	t.compareResult(key, "HasSection", base, compare)
+	return base
+}
+
 func (t *teeConfig) AllKeysLowercased() []string {
 	base := t.baseline.AllKeysLowercased()
 	compare := t.compare.AllKeysLowercased()
@@ -336,8 +351,8 @@ func (t *teeConfig) SetEnvPrefix(in string) {
 
 // BindEnv wraps Viper for concurrent access, and adds tracking of the configurable env vars
 func (t *teeConfig) BindEnv(key string, envvars ...string) {
-	t.baseline.BindEnv(key, envvars...)
-	t.compare.BindEnv(key, envvars...)
+	t.baseline.BindEnv(key, envvars...) //nolint:forbidigo // TODO: replace by 'SetDefaultAndBindEnv'
+	t.compare.BindEnv(key, envvars...)  //nolint:forbidigo // TODO: replace by 'SetDefaultAndBindEnv'
 }
 
 // SetEnvKeyReplacer wraps Viper for concurrent access
@@ -346,11 +361,6 @@ func (t *teeConfig) SetEnvKeyReplacer(r *strings.Replacer) {
 	t.compare.SetEnvKeyReplacer(r)
 }
 
-// UnmarshalKey wraps Viper for concurrent access
-func (t *teeConfig) UnmarshalKey(key string, rawVal interface{}, opts ...func(*mapstructure.DecoderConfig)) error {
-	return t.baseline.UnmarshalKey(key, rawVal, opts...)
-}
-
 // ReadInConfig wraps Viper for concurrent access
 func (t *teeConfig) ReadInConfig() error {
 	err1 := t.baseline.ReadInConfig()
@@ -489,6 +499,14 @@ func (t *teeConfig) ConfigFileUsed() string {
 
 }
 
+// GetSubfields returns the subfields from viper
+func (t *teeConfig) GetSubfields(key string) []string {
+	base := t.baseline.GetSubfields(key)
+	compare := t.compare.GetSubfields(key)
+	t.compareResult("", "GetSubfields", base, compare)
+	return base
+}
+
 // GetEnvVars implements the Config interface
 func (t *teeConfig) GetEnvVars() []string {
 	base := t.baseline.GetEnvVars()
