@@ -9,6 +9,7 @@ package api
 import (
 	"bytes"
 	"context"
+	"encoding/base64"
 	"encoding/json"
 	"fmt"
 	"io"
@@ -25,12 +26,15 @@ import (
 	"sync"
 	"time"
 
+	"github.com/DataDog/datadog-go/v5/statsd"
 	"github.com/tinylib/msgp/msgp"
 	"go.uber.org/atomic"
 
 	pb "github.com/DataDog/datadog-agent/pkg/proto/pbgo/trace"
+	"github.com/DataDog/datadog-agent/pkg/proto/pbgo/trace/idx"
 	"github.com/DataDog/datadog-agent/pkg/trace/api/apiutil"
 	"github.com/DataDog/datadog-agent/pkg/trace/api/internal/header"
+	"github.com/DataDog/datadog-agent/pkg/trace/api/loader"
 	"github.com/DataDog/datadog-agent/pkg/trace/config"
 	"github.com/DataDog/datadog-agent/pkg/trace/info"
 	"github.com/DataDog/datadog-agent/pkg/trace/log"
@@ -38,7 +42,6 @@ import (
 	"github.com/DataDog/datadog-agent/pkg/trace/telemetry"
 	"github.com/DataDog/datadog-agent/pkg/trace/timing"
 	"github.com/DataDog/datadog-agent/pkg/trace/watchdog"
-	"github.com/DataDog/datadog-go/v5/statsd"
 )
 
 // defaultReceiverBufferSize is used as a default for the initial size of http body buffer
@@ -65,12 +68,15 @@ func putBuffer(buffer *bytes.Buffer) {
 	bufferPool.Put(buffer)
 }
 
-func copyRequestBody(buf *bytes.Buffer, req *http.Request) (written int64, err error) {
-	reserveBodySize(buf, req)
+func (r *HTTPReceiver) copyRequestBody(buf *bytes.Buffer, req *http.Request) (written int64, err error) {
+	err = r.reserveBodySize(buf, req)
+	if err != nil {
+		return 0, err
+	}
 	return io.Copy(buf, req.Body)
 }
 
-func reserveBodySize(buf *bytes.Buffer, req *http.Request) {
+func (r *HTTPReceiver) reserveBodySize(buf *bytes.Buffer, req *http.Request) error {
 	var err error
 	bufferSize := 0
 	if contentSize := req.Header.Get("Content-Length"); contentSize != "" {
@@ -78,11 +84,16 @@ func reserveBodySize(buf *bytes.Buffer, req *http.Request) {
 		if err != nil {
 			log.Debugf("could not parse Content-Length header value as integer: %v", err)
 		}
+		if int64(bufferSize) > r.conf.MaxRequestBytes {
+			// We use this error to identify that the request body size exceeds the maximum allowed size so the metrics are the same as for the limited reader.
+			return apiutil.ErrLimitedReaderLimitReached
+		}
 	}
 	if bufferSize == 0 {
 		bufferSize = defaultReceiverBufferSize
 	}
 	buf.Grow(bufferSize)
+	return nil
 }
 
 // HTTPReceiver is a collector that uses HTTP protocol and just holds
@@ -91,6 +102,7 @@ type HTTPReceiver struct {
 	Stats *info.ReceiverStats
 
 	out                 chan *Payload
+	outV1               chan *PayloadV1
 	conf                *config.AgentConfig
 	dynConf             *sampler.DynamicConfig
 	server              *http.Server
@@ -126,6 +138,7 @@ func NewHTTPReceiver(
 	conf *config.AgentConfig,
 	dynConf *sampler.DynamicConfig,
 	out chan *Payload,
+	outV1 chan *PayloadV1,
 	statsProcessor StatsProcessor,
 	telemetryCollector telemetry.TelemetryCollector,
 	statsd statsd.ClientInterface,
@@ -145,9 +158,10 @@ func NewHTTPReceiver(
 	containerIDProvider := NewIDProvider(conf.ContainerProcRoot, conf.ContainerIDFromOriginInfo)
 	telemetryForwarder := NewTelemetryForwarder(conf, containerIDProvider, statsd)
 	return &HTTPReceiver{
-		Stats: info.NewReceiverStats(),
+		Stats: info.NewReceiverStats(conf.SendAllInternalStats),
 
 		out:                 out,
+		outV1:               outV1,
 		statsProcessor:      statsProcessor,
 		conf:                conf,
 		dynConf:             dynConf,
@@ -238,6 +252,14 @@ func getConfiguredEVPRequestTimeoutDuration(conf *config.AgentConfig) time.Durat
 	return timeout
 }
 
+func getConfiguredProfilingRequestTimeoutDuration(conf *config.AgentConfig) time.Duration {
+	timeout := 5 * time.Second
+	if conf.ProfilingProxy.ReceiverTimeout > 0 {
+		timeout = time.Duration(conf.ProfilingProxy.ReceiverTimeout) * time.Second
+	}
+	return timeout
+}
+
 // Start starts doing the HTTP server and is ready to receive traces
 func (r *HTTPReceiver) Start() {
 	r.telemetryForwarder.start()
@@ -265,7 +287,27 @@ func (r *HTTPReceiver) Start() {
 
 	if r.conf.ReceiverPort > 0 {
 		addr := net.JoinHostPort(r.conf.ReceiverHost, strconv.Itoa(r.conf.ReceiverPort))
-		ln, err := r.listenTCP(addr)
+
+		var ln net.Listener
+		var err error
+		// When using the trace-loader, the TCP listener might be provided as an already opened file descriptor
+		// so we try to get a listener from it, and fallback to listening on the given address if it fails
+		if tcpFDStr, ok := os.LookupEnv("DD_APM_NET_RECEIVER_FD"); ok {
+			ln, err = loader.GetListenerFromFD(tcpFDStr, "tcp_conn")
+			if err == nil {
+				log.Debugf("Using TCP listener from file descriptor %s", tcpFDStr)
+			} else {
+				log.Errorf("Error creating TCP listener from file descriptor %s: %v", tcpFDStr, err)
+			}
+		}
+		if ln == nil {
+			// if the fd was not provided, or we failed to get a listener from it, listen on the given address
+			ln, err = loader.GetTCPListener(addr)
+		}
+		if err == nil {
+			ln, err = r.listenTCPListener(ln)
+		}
+
 		if err != nil {
 			r.telemetryCollector.SendStartupError(telemetry.CantStartHttpServer, err)
 			killProcess("Error creating tcp listener: %v", err)
@@ -283,12 +325,31 @@ func (r *HTTPReceiver) Start() {
 	}
 
 	if path := r.conf.ReceiverSocket; path != "" {
+		log.Infof("Using UDS listener at %s", path)
+		// When using the trace-loader, the UDS listener might be provided as an already opened file descriptor
+		// so we try to get a listener from it, and fallback to listening on the given path if it fails
 		if _, err := os.Stat(filepath.Dir(path)); !os.IsNotExist(err) {
-			ln, err := r.listenUnix(path)
+			var ln net.Listener
+			var err error
+			if unixFDStr, ok := os.LookupEnv("DD_APM_UNIX_RECEIVER_FD"); ok {
+				ln, err = loader.GetListenerFromFD(unixFDStr, "unix_conn")
+				if err == nil {
+					log.Debugf("Using UDS listener from file descriptor %s", unixFDStr)
+				} else {
+					log.Errorf("Error creating UDS listener from file descriptor %s: %v", unixFDStr, err)
+				}
+			}
+			if ln == nil {
+				// if the fd was not provided, or we failed to get a listener from it, listen on the given path
+				ln, err = loader.GetUnixListener(path)
+			}
+
 			if err != nil {
 				log.Errorf("Error creating UDS listener: %v", err)
 				r.telemetryCollector.SendStartupError(telemetry.CantStartUdsServer, err)
 			} else {
+				ln = NewMeasuredListener(ln, "uds_connections", r.conf.MaxConnections, r.statsd)
+
 				go func() {
 					defer watchdog.LogOnPanic(r.statsd)
 					if err := r.server.Serve(ln); err != nil && err != http.ErrServerClosed {
@@ -328,34 +389,8 @@ func (r *HTTPReceiver) Start() {
 	}()
 }
 
-// listenUnix returns a net.Listener listening on the given "unix" socket path.
-func (r *HTTPReceiver) listenUnix(path string) (net.Listener, error) {
-	fi, err := os.Stat(path)
-	if err == nil {
-		// already exists
-		if fi.Mode()&os.ModeSocket == 0 {
-			return nil, fmt.Errorf("cannot reuse %q; not a unix socket", path)
-		}
-		if err := os.Remove(path); err != nil {
-			return nil, fmt.Errorf("unable to remove stale socket: %v", err)
-		}
-	}
-	ln, err := net.Listen("unix", path)
-	if err != nil {
-		return nil, err
-	}
-	if err := os.Chmod(path, 0o722); err != nil {
-		return nil, fmt.Errorf("error setting socket permissions: %v", err)
-	}
-	return NewMeasuredListener(ln, "uds_connections", r.conf.MaxConnections, r.statsd), err
-}
-
 // listenTCP creates a new net.Listener on the provided TCP address.
-func (r *HTTPReceiver) listenTCP(addr string) (net.Listener, error) {
-	tcpln, err := net.Listen("tcp", addr)
-	if err != nil {
-		return nil, err
-	}
+func (r *HTTPReceiver) listenTCPListener(tcpln net.Listener) (net.Listener, error) {
 	if climit := r.conf.ConnectionLimit; climit > 0 {
 		ln, err := newRateLimitedListener(tcpln, climit, r.statsd)
 		go func() {
@@ -364,12 +399,12 @@ func (r *HTTPReceiver) listenTCP(addr string) (net.Listener, error) {
 		}()
 		return ln, err
 	}
-	return NewMeasuredListener(tcpln, "tcp_connections", r.conf.MaxConnections, r.statsd), err
+	return NewMeasuredListener(tcpln, "tcp_connections", r.conf.MaxConnections, r.statsd), nil
 }
 
 // Stop stops the receiver and shuts down the HTTP server.
 func (r *HTTPReceiver) Stop() error {
-	if !r.conf.ReceiverEnabled || r.conf.ReceiverPort == 0 {
+	if !r.conf.ReceiverEnabled || (r.conf.ReceiverPort == 0 && r.conf.ReceiverSocket == "" && r.conf.WindowsPipeName == "") {
 		return nil
 	}
 	r.exit <- struct{}{}
@@ -379,10 +414,10 @@ func (r *HTTPReceiver) Stop() error {
 	ctx, cancel := context.WithDeadline(context.Background(), expiry)
 	defer cancel()
 	if err := r.server.Shutdown(ctx); err != nil {
+		log.Warnf("Error shutting down HTTPReceiver: %v", err)
 		return err
 	}
 	r.wg.Wait()
-	close(r.out)
 	r.telemetryForwarder.Stop()
 	return nil
 }
@@ -465,7 +500,7 @@ func (r *HTTPReceiver) tagStats(v Version, httpHeader http.Header, service strin
 // - tp is the decoded payload
 // - ranHook reports whether the decoder was able to run the pb.MetaHook
 // - err is the first error encountered
-func decodeTracerPayload(v Version, req *http.Request, cIDProvider IDProvider, lang, langVersion, tracerVersion string) (tp *pb.TracerPayload, err error) {
+func (r *HTTPReceiver) decodeTracerPayload(v Version, req *http.Request, cIDProvider IDProvider, lang, langVersion, tracerVersion string) (tp *pb.TracerPayload, err error) {
 	switch v {
 	case v01:
 		var spans []*pb.Span
@@ -482,11 +517,13 @@ func decodeTracerPayload(v Version, req *http.Request, cIDProvider IDProvider, l
 	case v05:
 		buf := getBuffer()
 		defer putBuffer(buf)
-		if _, err = copyRequestBody(buf, req); err != nil {
+		if _, err = r.copyRequestBody(buf, req); err != nil {
 			return nil, err
 		}
 		var traces pb.Traces
-		err = traces.UnmarshalMsgDictionary(buf.Bytes())
+		if err = traces.UnmarshalMsgDictionary(buf.Bytes()); err != nil {
+			return nil, err
+		}
 		return &pb.TracerPayload{
 			LanguageName:    lang,
 			LanguageVersion: langVersion,
@@ -497,7 +534,7 @@ func decodeTracerPayload(v Version, req *http.Request, cIDProvider IDProvider, l
 	case V07:
 		buf := getBuffer()
 		defer putBuffer(buf)
-		if _, err = copyRequestBody(buf, req); err != nil {
+		if _, err = r.copyRequestBody(buf, req); err != nil {
 			return nil, err
 		}
 		var tracerPayload pb.TracerPayload
@@ -505,7 +542,7 @@ func decodeTracerPayload(v Version, req *http.Request, cIDProvider IDProvider, l
 		return &tracerPayload, err
 	default:
 		var traces pb.Traces
-		if err = decodeRequest(req, &traces); err != nil {
+		if err = r.decodeRequest(req, &traces); err != nil {
 			return nil, err
 		}
 		return &pb.TracerPayload{
@@ -518,6 +555,28 @@ func decodeTracerPayload(v Version, req *http.Request, cIDProvider IDProvider, l
 	}
 }
 
+func (r *HTTPReceiver) decodeTracerPayloadV1(req *http.Request, cIDProvider IDProvider, conf *config.AgentConfig) (tp *idx.InternalTracerPayload, err error) {
+	buf := getBuffer()
+	defer putBuffer(buf)
+	if _, err = r.copyRequestBody(buf, req); err != nil {
+		return nil, err
+	}
+	var tracerPayload idx.InternalTracerPayload
+	_, err = tracerPayload.UnmarshalMsg(buf.Bytes())
+	if err != nil {
+		if conf.DebugV1Payloads {
+			encoded := base64.StdEncoding.EncodeToString(buf.Bytes())
+			log.Errorf("decodeTracerPayloadV1: failed to unmarshal payload, base64 received: %s", encoded)
+		}
+		return nil, err
+	}
+	if tracerPayload.ContainerID() == "" {
+		cid := cIDProvider.GetContainerID(req.Context(), req.Header)
+		tracerPayload.SetContainerID(cid)
+	}
+	return &tracerPayload, err
+}
+
 // replyOK replies to the given http.ResponseWriter w based on the endpoint version, with either status 200/OK
 // or with a list of rates by service. It returns the number of bytes written along with reporting if the operation
 // was successful.
@@ -533,9 +592,9 @@ func (r *HTTPReceiver) replyOK(req *http.Request, v Version, w http.ResponseWrit
 
 // StatsProcessor implementations are able to process incoming client stats.
 type StatsProcessor interface {
-	// ProcessStats takes a stats payload and consumes it. It is considered to be originating
-	// from the given lang.
-	ProcessStats(p *pb.ClientStatsPayload, lang, tracerVersion, containerID, obfuscationVersion string)
+	// ProcessStats takes a stats payload and consumes it. It is considered to be originating from the given lang.
+	// Context should be used to control processing timeouts, allowing the receiver to return the error response.
+	ProcessStats(ctx context.Context, p *pb.ClientStatsPayload, lang, tracerVersion, containerID, obfuscationVersion string) error
 }
 
 // handleStats handles incoming stats payloads.
@@ -547,6 +606,8 @@ func (r *HTTPReceiver) handleStats(w http.ResponseWriter, req *http.Request) {
 	in := &pb.ClientStatsPayload{}
 	if err := msgp.Decode(rd, in); err != nil {
 		log.Errorf("Error decoding pb.ClientStatsPayload: %v", err)
+		tags := append(r.tagStats(V06, req.Header, "").AsTags(), "reason:decode")
+		_ = r.statsd.Count("datadog.trace_agent.receiver.stats_payload_rejected", 1, tags, 1)
 		httpDecodingError(err, []string{"handler:stats", "codec:msgpack", "v:v0.6"}, w, r.statsd)
 		return
 	}
@@ -568,11 +629,112 @@ func (r *HTTPReceiver) handleStats(w http.ResponseWriter, req *http.Request) {
 	tracerVersion := req.Header.Get(header.TracerVersion)
 	obfuscationVersion := req.Header.Get(header.TracerObfuscationVersion)
 	containerID := r.containerIDProvider.GetContainerID(req.Context(), req.Header)
-	r.statsProcessor.ProcessStats(in, lang, tracerVersion, containerID, obfuscationVersion)
+
+	timeout := getConfiguredRequestTimeoutDuration(r.conf)
+	ctx, cancel := context.WithTimeout(req.Context(), timeout)
+	defer cancel()
+	if err := r.statsProcessor.ProcessStats(ctx, in, lang, tracerVersion, containerID, obfuscationVersion); err != nil {
+		log.Errorf("Error processing pb.ClientStatsPayload: %v", err)
+		tags := append(ts.AsTags(), "reason:timeout")
+		_ = r.statsd.Count("datadog.trace_agent.receiver.stats_payload_rejected", 1, tags, 1)
+		httpDecodingError(err, []string{"handler:stats", "codec:msgpack", "v:v0.6"}, w, r.statsd)
+	}
+}
+
+// handleTraces knows how to handle a bunch of traces
+func (r *HTTPReceiver) handleTracesV1(w http.ResponseWriter, req *http.Request) {
+	tracen, err := traceCount(req)
+	if err == errInvalidHeaderTraceCountValue {
+		log.Errorf("Failed to count traces: %s", err)
+	}
+	defer req.Body.Close()
+	select {
+	// Wait for the semaphore to become available, allowing the handler to
+	// decode its payload.
+	// After the configured timeout, respond without ingesting the payload,
+	// and sending the configured status.
+	case r.recvsem <- struct{}{}:
+	case <-time.After(time.Duration(r.conf.DecoderTimeout) * time.Millisecond):
+		log.Debugf("trace-agent is overwhelmed, a payload has been rejected")
+		// this payload can not be accepted
+		io.Copy(io.Discard, req.Body) //nolint:errcheck
+		w.WriteHeader(http.StatusTooManyRequests)
+		r.replyOK(req, V10, w)
+		r.tagStats(V10, req.Header, "").PayloadRefused.Inc()
+		return
+	}
+	defer func() {
+		// Signal the semaphore that we are done decoding, so another handler
+		// routine can take a turn decoding a payload.
+		<-r.recvsem
+	}()
+
+	firstService := func(tp *idx.InternalTracerPayload) string {
+		if tp == nil || len(tp.Chunks) == 0 || len(tp.Chunks[0].Spans) == 0 {
+			return ""
+		}
+		return tp.Chunks[0].Spans[0].Service()
+	}
+
+	start := time.Now()
+	tp, err := r.decodeTracerPayloadV1(req, r.containerIDProvider, r.conf)
+	ts := r.tagStats(V10, req.Header, firstService(tp))
+	defer func(err error) {
+		tags := append(ts.AsTags(), fmt.Sprintf("success:%v", err == nil))
+		_ = r.statsd.Histogram("datadog.trace_agent.receiver.serve_traces_ms", float64(time.Since(start))/float64(time.Millisecond), tags, 1)
+	}(err)
+	if err != nil {
+		httpDecodingError(err, []string{"handler:traces", fmt.Sprintf("v:%s", V10)}, w, r.statsd)
+		switch err {
+		case apiutil.ErrLimitedReaderLimitReached:
+			ts.TracesDropped.PayloadTooLarge.Add(tracen)
+		case io.EOF, io.ErrUnexpectedEOF:
+			ts.TracesDropped.EOF.Add(tracen)
+		case msgp.ErrShortBytes:
+			ts.TracesDropped.MSGPShortBytes.Add(tracen)
+		default:
+			if err, ok := err.(net.Error); ok && err.Timeout() {
+				ts.TracesDropped.Timeout.Add(tracen)
+			} else {
+				ts.TracesDropped.DecodingError.Add(tracen)
+			}
+		}
+		log.Errorf("Cannot decode %s traces payload: %v", V10, err)
+		return
+	}
+	if n, ok := r.replyOK(req, V10, w); ok {
+		tags := append(ts.AsTags(), "endpoint:traces_"+string(V10))
+		_ = r.statsd.Histogram("datadog.trace_agent.receiver.rate_response_bytes", float64(n), tags, 1)
+	}
+
+	ts.TracesReceived.Add(int64(len(tp.Chunks)))
+	ts.TracesBytes.Add(req.Body.(*apiutil.LimitedReader).Count)
+	ts.PayloadAccepted.Inc()
+
+	ctags := getContainerTagsList(r.conf.ContainerTags, tp.ContainerID())
+	if len(ctags) > 0 {
+		tp.SetStringAttribute(tagContainersTags, strings.Join(ctags, ","))
+	}
+
+	payload := &PayloadV1{
+		Source:                 ts,
+		TracerPayload:          tp,
+		ClientComputedTopLevel: isHeaderTrue(header.ComputedTopLevel, req.Header.Get(header.ComputedTopLevel)),
+		ClientComputedStats:    isHeaderTrue(header.ComputedStats, req.Header.Get(header.ComputedStats)),
+		ClientDroppedP0s:       droppedTracesFromHeader(req.Header, ts),
+		ContainerTags:          ctags,
+	}
+	r.outV1 <- payload
 }
 
 // handleTraces knows how to handle a bunch of traces
 func (r *HTTPReceiver) handleTraces(v Version, w http.ResponseWriter, req *http.Request) {
+	r.wg.Add(1)
+	defer r.wg.Done()
+	if v == V10 {
+		r.handleTracesV1(w, req)
+		return
+	}
 	tracen, err := traceCount(req)
 	if err == errInvalidHeaderTraceCountValue {
 		log.Errorf("Failed to count traces: %s", err)
@@ -618,7 +780,7 @@ func (r *HTTPReceiver) handleTraces(v Version, w http.ResponseWriter, req *http.
 	}
 
 	start := time.Now()
-	tp, err := decodeTracerPayload(v, req, r.containerIDProvider, req.Header.Get(header.Lang), req.Header.Get(header.LangVersion), req.Header.Get(header.TracerVersion))
+	tp, err := r.decodeTracerPayload(v, req, r.containerIDProvider, req.Header.Get(header.Lang), req.Header.Get(header.LangVersion), req.Header.Get(header.TracerVersion))
 	ts := r.tagStats(v, req.Header, firstService(tp))
 	defer func(err error) {
 		tags := append(ts.AsTags(), fmt.Sprintf("success:%v", err == nil))
@@ -651,12 +813,12 @@ func (r *HTTPReceiver) handleTraces(v Version, w http.ResponseWriter, req *http.
 	ts.TracesReceived.Add(int64(len(tp.Chunks)))
 	ts.TracesBytes.Add(req.Body.(*apiutil.LimitedReader).Count)
 	ts.PayloadAccepted.Inc()
-
-	if ctags := getContainerTags(r.conf.ContainerTags, tp.ContainerID); ctags != "" {
+	ctags := getContainerTagsList(r.conf.ContainerTags, tp.ContainerID)
+	if len(ctags) > 0 {
 		if tp.Tags == nil {
 			tp.Tags = make(map[string]string)
 		}
-		tp.Tags[tagContainersTags] = ctags
+		tp.Tags[tagContainersTags] = strings.Join(ctags, ",")
 	}
 	ptags := getProcessTags(req.Header, tp)
 	if ptags != "" {
@@ -672,6 +834,7 @@ func (r *HTTPReceiver) handleTraces(v Version, w http.ResponseWriter, req *http.
 		ClientComputedStats:    isHeaderTrue(header.ComputedStats, req.Header.Get(header.ComputedStats)),
 		ClientDroppedP0s:       droppedTracesFromHeader(req.Header, ts),
 		ProcessTags:            ptags,
+		ContainerTags:          ctags,
 	}
 	r.out <- payload
 }
@@ -757,7 +920,7 @@ func (r *HTTPReceiver) loop() {
 	defer close(r.exit)
 
 	var lastLog time.Time
-	accStats := info.NewReceiverStats()
+	accStats := info.NewReceiverStats(r.conf.SendAllInternalStats)
 
 	t := time.NewTicker(5 * time.Second)
 	defer t.Stop()
@@ -855,12 +1018,12 @@ func (r *HTTPReceiver) Languages() string {
 // It handles only v02, v03, v04 requests.
 // - ranHook reports whether the decoder was able to run the pb.MetaHook
 // - err is the first error encountered
-func decodeRequest(req *http.Request, dest *pb.Traces) error {
+func (r *HTTPReceiver) decodeRequest(req *http.Request, dest *pb.Traces) error {
 	switch mediaType := getMediaType(req); mediaType {
 	case "application/msgpack":
 		buf := getBuffer()
 		defer putBuffer(buf)
-		_, err := copyRequestBody(buf, req)
+		_, err := r.copyRequestBody(buf, req)
 		if err != nil {
 			return err
 		}
@@ -877,7 +1040,7 @@ func decodeRequest(req *http.Request, dest *pb.Traces) error {
 		if err1 := json.NewDecoder(req.Body).Decode(&dest); err1 != nil {
 			buf := getBuffer()
 			defer putBuffer(buf)
-			_, err2 := copyRequestBody(buf, req)
+			_, err2 := r.copyRequestBody(buf, req)
 			if err2 != nil {
 				return err2
 			}
@@ -917,23 +1080,28 @@ func traceChunksFromTraces(traces pb.Traces) []*pb.TraceChunk {
 	return traceChunks
 }
 
-// getContainerTag returns container and orchestrator tags belonging to containerID. If containerID
-// is empty or no tags are found, an empty string is returned.
-func getContainerTags(fn func(string) ([]string, error), containerID string) string {
+func getContainerTagsList(fn func(string) ([]string, error), containerID string) []string {
 	if containerID == "" {
-		return ""
+		return nil
 	}
 	if fn == nil {
 		log.Warn("ContainerTags not configured")
-		return ""
+		return nil
 	}
 	list, err := fn(containerID)
 	if err != nil {
 		log.Tracef("Getting container tags for ID %q: %v", containerID, err)
-		return ""
+		return nil
 	}
 	log.Tracef("Getting container tags for ID %q: %v", containerID, list)
-	return strings.Join(list, ",")
+	return list
+}
+
+// getContainerTag returns container and orchestrator tags belonging to containerID. If containerID
+// is empty or no tags are found, an empty string is returned.
+func getContainerTags(fn func(string) ([]string, error), containerID string) string {
+	ctags := getContainerTagsList(fn, containerID)
+	return strings.Join(ctags, ",")
 }
 
 // getMediaType attempts to return the media type from the Content-Type MIME header. If it fails
