@@ -6,20 +6,19 @@
 package traceutil
 
 import (
-	"context"
 	"encoding/binary"
 	"strings"
 
-	"github.com/DataDog/opentelemetry-mapping-go/pkg/otlp/attributes"
-	"github.com/DataDog/opentelemetry-mapping-go/pkg/otlp/attributes/source"
 	"go.opentelemetry.io/collector/pdata/pcommon"
 	"go.opentelemetry.io/collector/pdata/ptrace"
-	semconv117 "go.opentelemetry.io/collector/semconv/v1.17.0"
-	semconv126 "go.opentelemetry.io/collector/semconv/v1.26.0"
-	semconv "go.opentelemetry.io/collector/semconv/v1.6.1"
 	"go.opentelemetry.io/otel/attribute"
+	semconv117 "go.opentelemetry.io/otel/semconv/v1.17.0"
+	semconv126 "go.opentelemetry.io/otel/semconv/v1.26.0"
+	semconv "go.opentelemetry.io/otel/semconv/v1.6.1"
 
+	"github.com/DataDog/datadog-agent/pkg/opentelemetry-mapping-go/otlp/attributes"
 	"github.com/DataDog/datadog-agent/pkg/trace/log"
+	normalizeutil "github.com/DataDog/datadog-agent/pkg/trace/traceutil/normalize"
 )
 
 // Util functions for converting OTel semantics to DD semantics.
@@ -34,94 +33,17 @@ const (
 	TagStatusCode = "http.status_code"
 )
 
-// span.Type constants for db systems
-const (
-	spanTypeSQL           = "sql"
-	spanTypeCassandra     = "cassandra"
-	spanTypeRedis         = "redis"
-	spanTypeMemcached     = "memcached"
-	spanTypeMongoDB       = "mongodb"
-	spanTypeElasticsearch = "elasticsearch"
-	spanTypeOpenSearch    = "opensearch"
-	spanTypeDB            = "db"
-)
-
-// DBTypes are semconv types that should map to span.Type values given in the mapping
-var dbTypes = map[string]string{
-	// SQL db types
-	semconv.AttributeDBSystemOtherSQL:      spanTypeSQL,
-	semconv.AttributeDBSystemMSSQL:         spanTypeSQL,
-	semconv.AttributeDBSystemMySQL:         spanTypeSQL,
-	semconv.AttributeDBSystemOracle:        spanTypeSQL,
-	semconv.AttributeDBSystemDB2:           spanTypeSQL,
-	semconv.AttributeDBSystemPostgreSQL:    spanTypeSQL,
-	semconv.AttributeDBSystemRedshift:      spanTypeSQL,
-	semconv.AttributeDBSystemCloudscape:    spanTypeSQL,
-	semconv.AttributeDBSystemHSQLDB:        spanTypeSQL,
-	semconv.AttributeDBSystemMaxDB:         spanTypeSQL,
-	semconv.AttributeDBSystemIngres:        spanTypeSQL,
-	semconv.AttributeDBSystemFirstSQL:      spanTypeSQL,
-	semconv.AttributeDBSystemEDB:           spanTypeSQL,
-	semconv.AttributeDBSystemCache:         spanTypeSQL,
-	semconv.AttributeDBSystemFirebird:      spanTypeSQL,
-	semconv.AttributeDBSystemDerby:         spanTypeSQL,
-	semconv.AttributeDBSystemInformix:      spanTypeSQL,
-	semconv.AttributeDBSystemMariaDB:       spanTypeSQL,
-	semconv.AttributeDBSystemSqlite:        spanTypeSQL,
-	semconv.AttributeDBSystemSybase:        spanTypeSQL,
-	semconv.AttributeDBSystemTeradata:      spanTypeSQL,
-	semconv.AttributeDBSystemVertica:       spanTypeSQL,
-	semconv.AttributeDBSystemH2:            spanTypeSQL,
-	semconv.AttributeDBSystemColdfusion:    spanTypeSQL,
-	semconv.AttributeDBSystemCockroachdb:   spanTypeSQL,
-	semconv.AttributeDBSystemProgress:      spanTypeSQL,
-	semconv.AttributeDBSystemHanaDB:        spanTypeSQL,
-	semconv.AttributeDBSystemAdabas:        spanTypeSQL,
-	semconv.AttributeDBSystemFilemaker:     spanTypeSQL,
-	semconv.AttributeDBSystemInstantDB:     spanTypeSQL,
-	semconv.AttributeDBSystemInterbase:     spanTypeSQL,
-	semconv.AttributeDBSystemNetezza:       spanTypeSQL,
-	semconv.AttributeDBSystemPervasive:     spanTypeSQL,
-	semconv.AttributeDBSystemPointbase:     spanTypeSQL,
-	semconv117.AttributeDBSystemClickhouse: spanTypeSQL, // not in semconv 1.6.1
-
-	// Cassandra db types
-	semconv.AttributeDBSystemCassandra: spanTypeCassandra,
-
-	// Redis db types
-	semconv.AttributeDBSystemRedis: spanTypeRedis,
-
-	// Memcached db types
-	semconv.AttributeDBSystemMemcached: spanTypeMemcached,
-
-	// Mongodb db types
-	semconv.AttributeDBSystemMongoDB: spanTypeMongoDB,
-
-	// Elasticsearch db types
-	semconv.AttributeDBSystemElasticsearch: spanTypeElasticsearch,
-
-	// Opensearch db types, not in semconv 1.6.1
-	semconv117.AttributeDBSystemOpensearch: spanTypeOpenSearch,
-
-	// Generic db types
-	semconv.AttributeDBSystemHive:      spanTypeDB,
-	semconv.AttributeDBSystemHBase:     spanTypeDB,
-	semconv.AttributeDBSystemNeo4j:     spanTypeDB,
-	semconv.AttributeDBSystemCouchbase: spanTypeDB,
-	semconv.AttributeDBSystemCouchDB:   spanTypeDB,
-	semconv.AttributeDBSystemCosmosDB:  spanTypeDB,
-	semconv.AttributeDBSystemDynamoDB:  spanTypeDB,
-	semconv.AttributeDBSystemGeode:     spanTypeDB,
-}
+// DefaultOTLPServiceName is the default service name for OTel spans when no service name is found in the resource attributes.
+const DefaultOTLPServiceName = "otlpresourcenoservicename"
 
 // checkDBType checks if the dbType is a known db type and returns the corresponding span.Type
 func checkDBType(dbType string) string {
-	spanType, ok := dbTypes[dbType]
+	spanType, ok := attributes.DBTypes[dbType]
 	if ok {
 		return spanType
 	}
 	// span type not found, return generic db type
-	return spanTypeDB
+	return attributes.SpanTypeDB
 }
 
 // IndexOTelSpans iterates over the input OTel spans and returns 3 maps:
@@ -179,8 +101,8 @@ func GetTopLevelOTelSpans(spanByID map[pcommon.SpanID]ptrace.Span, resByID map[p
 			continue
 		}
 
-		svc := GetOTelService(resByID[spanID], true)
-		parentSvc := GetOTelService(resByID[parentSpan.SpanID()], true)
+		svc := GetOTelService(span, resByID[spanID], true)
+		parentSvc := GetOTelService(span, resByID[parentSpan.SpanID()], true)
 		if svc != parentSvc {
 			// case 3: parent is not in the same service
 			topLevelSpans[spanID] = struct{}{}
@@ -203,12 +125,23 @@ func GetOTelAttrVal(attrs pcommon.Map, normalize bool, keys ...string) string {
 	}
 
 	if normalize {
-		val = NormalizeTagValue(val)
+		val = normalizeutil.NormalizeTagValue(val)
 	}
 
 	return val
 }
 
+// GetOTelAttrFromEitherMap returns the matched value as a string in either attribute map with the given keys.
+// If there are multiple keys present, the first matched one is returned.
+// If the key is present in both maps, map1 takes precedence.
+// If normalize is true, normalize the return value with NormalizeTagValue.
+func GetOTelAttrFromEitherMap(map1 pcommon.Map, map2 pcommon.Map, normalize bool, keys ...string) string {
+	if val := GetOTelAttrVal(map1, normalize, keys...); val != "" {
+		return val
+	}
+	return GetOTelAttrVal(map2, normalize, keys...)
+}
+
 // GetOTelAttrValInResAndSpanAttrs returns the matched value as a string in the OTel resource attributes and span attributes with the given keys.
 // If there are multiple keys present, the first matched one is returned.
 // If the key is present in both resource attributes and span attributes, resource attributes take precedence.
@@ -229,7 +162,7 @@ func SpanKind2Type(span ptrace.Span, res pcommon.Resource) string {
 		typ = "web"
 	case ptrace.SpanKindClient:
 		typ = "http"
-		db := GetOTelAttrValInResAndSpanAttrs(span, res, true, semconv.AttributeDBSystem)
+		db := GetOTelAttrValInResAndSpanAttrs(span, res, true, string(semconv.DBSystemKey))
 		if db == "" {
 			break
 		}
@@ -248,7 +181,10 @@ func SpanKind2Type(span ptrace.Span, res pcommon.Resource) string {
 // GetOTelSpanType returns the DD span type based on OTel span kind and attributes.
 // This logic is used in ReceiveResourceSpansV2 logic
 func GetOTelSpanType(span ptrace.Span, res pcommon.Resource) string {
-	typ := GetOTelAttrValInResAndSpanAttrs(span, res, false, "span.type")
+	sattr := span.Attributes()
+	rattr := res.Attributes()
+
+	typ := GetOTelAttrFromEitherMap(sattr, rattr, false, "span.type")
 	if typ != "" {
 		return typ
 	}
@@ -256,7 +192,7 @@ func GetOTelSpanType(span ptrace.Span, res pcommon.Resource) string {
 	case ptrace.SpanKindServer:
 		typ = "web"
 	case ptrace.SpanKindClient:
-		db := GetOTelAttrValInResAndSpanAttrs(span, res, true, semconv.AttributeDBSystem)
+		db := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.DBSystemKey))
 		if db == "" {
 			typ = "http"
 		} else {
@@ -269,18 +205,18 @@ func GetOTelSpanType(span ptrace.Span, res pcommon.Resource) string {
 }
 
 // GetOTelService returns the DD service name based on OTel span and resource attributes.
-func GetOTelService(res pcommon.Resource, normalize bool) string {
+func GetOTelService(span ptrace.Span, res pcommon.Resource, normalize bool) string {
 	// No need to normalize with NormalizeTagValue since we will do NormalizeService later
-	svc := GetOTelAttrVal(res.Attributes(), false, semconv.AttributeServiceName)
+	svc := GetOTelAttrFromEitherMap(span.Attributes(), res.Attributes(), false, string(semconv.ServiceNameKey))
 	if svc == "" {
-		svc = "otlpresourcenoservicename"
+		svc = DefaultOTLPServiceName
 	}
 	if normalize {
-		newsvc, err := NormalizeService(svc, "")
+		newsvc, err := normalizeutil.NormalizeService(svc, "")
 		switch err {
-		case ErrTooLong:
-			log.Debugf("Fixing malformed trace. Service is too long (reason:service_truncate), truncating span.service to length=%d: %s", MaxServiceLen, svc)
-		case ErrInvalid:
+		case normalizeutil.ErrTooLong:
+			log.Debugf("Fixing malformed trace. Service is too long (reason:service_truncate), truncating span.service to length=%d: %s", normalizeutil.MaxServiceLen, svc)
+		case normalizeutil.ErrInvalid:
 			log.Debugf("Fixing malformed trace. Service is invalid (reason:service_invalid), replacing invalid span.service=%s with fallback span.service=%s", svc, newsvc)
 		}
 		svc = newsvc
@@ -292,38 +228,38 @@ func GetOTelService(res pcommon.Resource, normalize bool) string {
 func GetOTelResourceV1(span ptrace.Span, res pcommon.Resource) (resName string) {
 	resName = GetOTelAttrValInResAndSpanAttrs(span, res, false, "resource.name")
 	if resName == "" {
-		if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, "http.request.method", semconv.AttributeHTTPMethod); m != "" {
+		if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, "http.request.method", string(semconv.HTTPMethodKey)); m != "" {
 			// use the HTTP method + route (if available)
 			resName = m
-			if route := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeHTTPRoute); route != "" {
+			if route := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv.HTTPRouteKey)); route != "" {
 				resName = resName + " " + route
 			}
-		} else if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeMessagingOperation); m != "" {
+		} else if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv.MessagingOperationKey)); m != "" {
 			resName = m
 			// use the messaging operation
-			if dest := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeMessagingDestination, semconv117.AttributeMessagingDestinationName); dest != "" {
+			if dest := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv.MessagingDestinationKey), string(semconv117.MessagingDestinationNameKey)); dest != "" {
 				resName = resName + " " + dest
 			}
-		} else if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeRPCMethod); m != "" {
+		} else if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv.RPCMethodKey)); m != "" {
 			resName = m
 			// use the RPC method
-			if svc := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeRPCService); m != "" {
+			if svc := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv.RPCServiceKey)); m != "" {
 				// ...and service if available
 				resName = resName + " " + svc
 			}
-		} else if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv117.AttributeGraphqlOperationType); m != "" {
+		} else if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv117.GraphqlOperationTypeKey)); m != "" {
 			// Enrich GraphQL query resource names.
 			// See https://github.com/open-telemetry/semantic-conventions/blob/v1.29.0/docs/graphql/graphql-spans.md
 			resName = m
-			if name := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv117.AttributeGraphqlOperationName); name != "" {
+			if name := GetOTelAttrValInResAndSpanAttrs(span, res, false, string(semconv117.GraphqlOperationNameKey)); name != "" {
 				resName = resName + " " + name
 			}
 		} else {
 			resName = span.Name()
 		}
 	}
-	if len(resName) > MaxResourceLen {
-		resName = resName[:MaxResourceLen]
+	if len(resName) > normalizeutil.MaxResourceLen {
+		resName = resName[:normalizeutil.MaxResourceLen]
 	}
 	return
 }
@@ -331,81 +267,88 @@ func GetOTelResourceV1(span ptrace.Span, res pcommon.Resource) (resName string)
 // GetOTelResourceV2 returns the DD resource name based on OTel span and resource attributes.
 func GetOTelResourceV2(span ptrace.Span, res pcommon.Resource) (resName string) {
 	defer func() {
-		if len(resName) > MaxResourceLen {
-			resName = resName[:MaxResourceLen]
+		if len(resName) > normalizeutil.MaxResourceLen {
+			resName = resName[:normalizeutil.MaxResourceLen]
 		}
 	}()
-	if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, "resource.name"); m != "" {
+	// Use span and resource attributes for lookups
+	sattr := span.Attributes()
+	rattr := res.Attributes()
+
+	if m := GetOTelAttrFromEitherMap(sattr, rattr, false, "resource.name"); m != "" {
 		resName = m
 		return
 	}
 
-	if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, "http.request.method", semconv.AttributeHTTPMethod); m != "" {
+	if m := GetOTelAttrFromEitherMap(sattr, rattr, false, "http.request.method", string(semconv.HTTPMethodKey)); m != "" {
 		if m == "_OTHER" {
 			m = "HTTP"
 		}
 		// use the HTTP method + route (if available)
 		resName = m
 		if span.Kind() == ptrace.SpanKindServer {
-			if route := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeHTTPRoute); route != "" {
+			if route := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.HTTPRouteKey)); route != "" {
 				resName = resName + " " + route
 			}
 		}
 		return
 	}
 
-	if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeMessagingOperation); m != "" {
+	if m := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.MessagingOperationKey)); m != "" {
 		resName = m
 		// use the messaging operation
-		if dest := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeMessagingDestination, semconv117.AttributeMessagingDestinationName); dest != "" {
+		if dest := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.MessagingDestinationKey), string(semconv117.MessagingDestinationNameKey)); dest != "" {
 			resName = resName + " " + dest
 		}
 		return
 	}
 
-	if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeRPCMethod); m != "" {
+	if m := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.RPCMethodKey)); m != "" {
 		resName = m
 		// use the RPC method
-		if svc := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeRPCService); m != "" {
+		if svc := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.RPCServiceKey)); svc != "" {
 			// ...and service if available
 			resName = resName + " " + svc
 		}
 		return
 	}
 
-	if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv117.AttributeGraphqlOperationType); m != "" {
-		// Enrich GraphQL query resource names.
-		// See https://github.com/open-telemetry/semantic-conventions/blob/v1.29.0/docs/graphql/graphql-spans.md
+	// Enrich GraphQL query resource names.
+	// See https://github.com/open-telemetry/semantic-conventions/blob/v1.29.0/docs/graphql/graphql-spans.md
+	if m := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv117.GraphqlOperationTypeKey)); m != "" {
 		resName = m
-		if name := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv117.AttributeGraphqlOperationName); name != "" {
+		if name := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv117.GraphqlOperationNameKey)); name != "" {
 			resName = resName + " " + name
 		}
 		return
 	}
 
-	if m := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeDBSystem); m != "" {
+	if m := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.DBSystemKey)); m != "" {
 		// Since traces are obfuscated by span.Resource in pkg/trace/agent/obfuscate.go, we should use span.Resource as the resource name.
 		// https://github.com/DataDog/datadog-agent/blob/62619a69cff9863f5b17215847b853681e36ff15/pkg/trace/agent/obfuscate.go#L32
-		if dbStatement := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv.AttributeDBStatement); dbStatement != "" {
+		if dbStatement := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv.DBStatementKey)); dbStatement != "" {
 			resName = dbStatement
 			return
 		}
-		if dbQuery := GetOTelAttrValInResAndSpanAttrs(span, res, false, semconv126.AttributeDBQueryText); dbQuery != "" {
+		if dbQuery := GetOTelAttrFromEitherMap(sattr, rattr, false, string(semconv126.DBQueryTextKey)); dbQuery != "" {
 			resName = dbQuery
 			return
 		}
 	}
 
 	resName = span.Name()
-
 	return
 }
 
 // GetOTelOperationNameV2 returns the DD operation name based on OTel span and resource attributes and given configs.
 func GetOTelOperationNameV2(
 	span ptrace.Span,
+	res pcommon.Resource,
 ) string {
-	if operationName := GetOTelAttrVal(span.Attributes(), true, "operation.name"); operationName != "" {
+	sattr := span.Attributes()
+	rattr := res.Attributes()
+
+	if operationName := GetOTelAttrFromEitherMap(sattr, rattr, true, "operation.name"); operationName != "" {
 		return operationName
 	}
 
@@ -413,7 +356,7 @@ func GetOTelOperationNameV2(
 	isServer := span.Kind() == ptrace.SpanKindServer
 
 	// http
-	if method := GetOTelAttrVal(span.Attributes(), false, "http.request.method", semconv.AttributeHTTPMethod); method != "" {
+	if method := GetOTelAttrFromEitherMap(sattr, rattr, false, "http.request.method", string(semconv.HTTPMethodKey)); method != "" {
 		if isServer {
 			return "http.server.request"
 		}
@@ -423,13 +366,13 @@ func GetOTelOperationNameV2(
 	}
 
 	// database
-	if v := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeDBSystem); v != "" && isClient {
+	if v := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.DBSystemKey)); v != "" && isClient {
 		return v + ".query"
 	}
 
 	// messaging
-	system := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeMessagingSystem)
-	op := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeMessagingOperation)
+	system := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.MessagingSystemKey))
+	op := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.MessagingOperationKey))
 	if system != "" && op != "" {
 		switch span.Kind() {
 		case ptrace.SpanKindClient, ptrace.SpanKindServer, ptrace.SpanKindConsumer, ptrace.SpanKindProducer:
@@ -438,16 +381,17 @@ func GetOTelOperationNameV2(
 	}
 
 	// RPC & AWS
-	rpcValue := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeRPCSystem)
+	rpcValue := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.RPCSystemKey))
 	isRPC := rpcValue != ""
 	isAws := isRPC && (rpcValue == "aws-api")
 	// AWS client
 	if isAws && isClient {
-		if service := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeRPCService); service != "" {
+		if service := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.RPCServiceKey)); service != "" {
 			return "aws." + service + ".request"
 		}
 		return "aws.client.request"
 	}
+
 	// RPC client
 	if isRPC && isClient {
 		return rpcValue + ".client.request"
@@ -458,25 +402,25 @@ func GetOTelOperationNameV2(
 	}
 
 	// FAAS client
-	provider := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeFaaSInvokedProvider)
-	invokedName := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeFaaSInvokedName)
+	provider := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.FaaSInvokedProviderKey))
+	invokedName := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.FaaSInvokedNameKey))
 	if provider != "" && invokedName != "" && isClient {
 		return provider + "." + invokedName + ".invoke"
 	}
 
 	// FAAS server
-	trigger := GetOTelAttrVal(span.Attributes(), true, semconv.AttributeFaaSTrigger)
+	trigger := GetOTelAttrFromEitherMap(sattr, rattr, true, string(semconv.FaaSTriggerKey))
 	if trigger != "" && isServer {
 		return trigger + ".invoke"
 	}
 
 	// GraphQL
-	if GetOTelAttrVal(span.Attributes(), true, "graphql.operation.type") != "" {
+	if GetOTelAttrFromEitherMap(sattr, rattr, true, "graphql.operation.type") != "" {
 		return "graphql.server.request"
 	}
 
 	// if nothing matches, checking for generic http server/client
-	protocol := GetOTelAttrVal(span.Attributes(), true, "network.protocol.name")
+	protocol := GetOTelAttrFromEitherMap(sattr, rattr, true, "network.protocol.name")
 	if isServer {
 		if protocol != "" {
 			return protocol + ".server.request"
@@ -522,13 +466,13 @@ func GetOTelOperationNameV1(
 	}
 
 	if normalize {
-		normalizeName, err := NormalizeName(name)
+		normalizeName, err := normalizeutil.NormalizeName(name)
 		switch err {
-		case ErrEmpty:
+		case normalizeutil.ErrEmpty:
 			log.Debugf("Fixing malformed trace. Name is empty (reason:span_name_empty), setting span.name=%s", normalizeName)
-		case ErrTooLong:
-			log.Debugf("Fixing malformed trace. Name is too long (reason:span_name_truncate), truncating span.name to length=%d", MaxServiceLen)
-		case ErrInvalid:
+		case normalizeutil.ErrTooLong:
+			log.Debugf("Fixing malformed trace. Name is too long (reason:span_name_truncate), truncating span.name to length=%d", normalizeutil.MaxServiceLen)
+		case normalizeutil.ErrInvalid:
 			log.Debugf("Fixing malformed trace. Name is invalid (reason:span_name_invalid), setting span.name=%s", normalizeName)
 		}
 		name = normalizeName
@@ -537,47 +481,6 @@ func GetOTelOperationNameV1(
 	return name
 }
 
-// GetOtelSource returns the source based on OTel span and resource attributes.
-func GetOtelSource(span ptrace.Span, res pcommon.Resource, tr *attributes.Translator) (source.Source, bool) {
-	ctx := context.Background()
-	src, srcok := tr.ResourceToSource(ctx, res, SignalTypeSet, nil)
-	if !srcok {
-		if v := GetOTelAttrValInResAndSpanAttrs(span, res, false, "_dd.hostname"); v != "" {
-			src = source.Source{Kind: source.HostnameKind, Identifier: v}
-			srcok = true
-		}
-	}
-	return src, srcok
-}
-
-// GetOTelHostname returns the DD hostname based on OTel span and resource attributes.
-func GetOTelHostname(span ptrace.Span, res pcommon.Resource, tr *attributes.Translator, fallbackHost string) string {
-	src, srcok := GetOtelSource(span, res, tr)
-	if srcok {
-		switch src.Kind {
-		case source.HostnameKind:
-			return src.Identifier
-		default:
-			// We are not on a hostname (serverless), hence the hostname is empty
-			return ""
-		}
-	} else {
-		// fallback hostname from Agent conf.Hostname
-		return fallbackHost
-	}
-}
-
-// GetOTelStatusCode returns the DD status code of the OTel span.
-func GetOTelStatusCode(span ptrace.Span) uint32 {
-	if code, ok := span.Attributes().Get("http.response.status_code"); ok {
-		return uint32(code.Int())
-	}
-	if code, ok := span.Attributes().Get(semconv.AttributeHTTPStatusCode); ok {
-		return uint32(code.Int())
-	}
-	return 0
-}
-
 // GetOTelContainerTags returns a list of DD container tags in the OTel resource attributes.
 // Tags are always normalized.
 func GetOTelContainerTags(rattrs pcommon.Map, tagKeys []string) []string {
@@ -587,13 +490,13 @@ func GetOTelContainerTags(rattrs pcommon.Map, tagKeys []string) []string {
 		if mappedKey, ok := attributes.ContainerMappings[key]; ok {
 			// If the key has a mapping in ContainerMappings, use the mapped key
 			if val, ok := containerTagsMap[mappedKey]; ok {
-				t := NormalizeTag(mappedKey + ":" + val)
+				t := normalizeutil.NormalizeTag(mappedKey + ":" + val)
 				containerTags = append(containerTags, t)
 			}
 		} else {
 			// Otherwise populate as additional container tags
 			if val := GetOTelAttrVal(rattrs, false, key); val != "" {
-				t := NormalizeTag(key + ":" + val)
+				t := normalizeutil.NormalizeTag(key + ":" + val)
 				containerTags = append(containerTags, t)
 			}
 		}
@@ -601,12 +504,6 @@ func GetOTelContainerTags(rattrs pcommon.Map, tagKeys []string) []string {
 	return containerTags
 }
 
-// GetOTelEnv returns the environment based on OTel resource attributes.
-func GetOTelEnv(res pcommon.Resource) string {
-	// TODO(songy23): use AttributeDeploymentEnvironmentName once collector version upgrade is unblocked
-	return GetOTelAttrVal(res.Attributes(), true, "deployment.environment.name", semconv.AttributeDeploymentEnvironment)
-}
-
 // OTelTraceIDToUint64 converts an OTel trace ID to an uint64
 func OTelTraceIDToUint64(b [16]byte) uint64 {
 	return binary.BigEndian.Uint64(b[len(b)-8:])
