@@ -600,29 +600,45 @@ func NewConfiguration() *Configuration {
 			},
 		},
 		unstableOperations: map[string]bool{
+			"v2.CancelFleetDeployment":                   false,
+			"v2.CreateFleetDeploymentConfigure":          false,
+			"v2.CreateFleetDeploymentUpgrade":            false,
+			"v2.CreateFleetSchedule":                     false,
+			"v2.DeleteFleetSchedule":                     false,
+			"v2.GetFleetAgentInfo":                       false,
+			"v2.GetFleetDeployment":                      false,
+			"v2.GetFleetSchedule":                        false,
+			"v2.ListFleetAgents":                         false,
+			"v2.ListFleetAgentVersions":                  false,
+			"v2.ListFleetDeployments":                    false,
+			"v2.ListFleetSchedules":                      false,
+			"v2.TriggerFleetSchedule":                    false,
+			"v2.UpdateFleetSchedule":                     false,
 			"v2.CreateOpenAPI":                           false,
 			"v2.DeleteOpenAPI":                           false,
 			"v2.GetOpenAPI":                              false,
 			"v2.ListAPIs":                                false,
 			"v2.UpdateOpenAPI":                           false,
-			"v2.CancelHistoricalJob":                     false,
+			"v2.CancelThreatHuntingJob":                  false,
 			"v2.ConvertJobResultToSignal":                false,
-			"v2.DeleteHistoricalJob":                     false,
+			"v2.DeleteThreatHuntingJob":                  false,
 			"v2.GetFinding":                              false,
-			"v2.GetHistoricalJob":                        false,
 			"v2.GetRuleVersionHistory":                   false,
 			"v2.GetSBOM":                                 false,
+			"v2.GetSecretsRules":                         false,
 			"v2.GetSecurityMonitoringHistsignal":         false,
 			"v2.GetSecurityMonitoringHistsignalsByJobId": false,
+			"v2.GetThreatHuntingJob":                     false,
 			"v2.ListAssetsSBOMs":                         false,
 			"v2.ListFindings":                            false,
-			"v2.ListHistoricalJobs":                      false,
+			"v2.ListMultipleRulesets":                    false,
 			"v2.ListScannedAssetsMetadata":               false,
 			"v2.ListSecurityMonitoringHistsignals":       false,
+			"v2.ListThreatHuntingJobs":                   false,
 			"v2.ListVulnerabilities":                     false,
 			"v2.ListVulnerableAssets":                    false,
 			"v2.MuteFindings":                            false,
-			"v2.RunHistoricalJob":                        false,
+			"v2.RunThreatHuntingJob":                     false,
 			"v2.SearchSecurityMonitoringHistsignals":     false,
 			"v2.CreateDataset":                           false,
 			"v2.DeleteDataset":                           false,
@@ -632,6 +648,14 @@ func NewConfiguration() *Configuration {
 			"v2.CancelDataDeletionRequest":               false,
 			"v2.CreateDataDeletionRequest":               false,
 			"v2.GetDataDeletionRequests":                 false,
+			"v2.CreateDeploymentGate":                    false,
+			"v2.CreateDeploymentRule":                    false,
+			"v2.DeleteDeploymentGate":                    false,
+			"v2.DeleteDeploymentRule":                    false,
+			"v2.GetDeploymentGate":                       false,
+			"v2.GetDeploymentRule":                       false,
+			"v2.UpdateDeploymentGate":                    false,
+			"v2.UpdateDeploymentRule":                    false,
 			"v2.CreateIncident":                          false,
 			"v2.CreateIncidentImpact":                    false,
 			"v2.CreateIncidentIntegration":               false,
@@ -668,6 +692,17 @@ func NewConfiguration() *Configuration {
 			"v2.UpdateIncidentNotificationTemplate":      false,
 			"v2.UpdateIncidentTodo":                      false,
 			"v2.UpdateIncidentType":                      false,
+			"v2.AddRoleToRestrictionQuery":               false,
+			"v2.CreateRestrictionQuery":                  false,
+			"v2.DeleteRestrictionQuery":                  false,
+			"v2.GetRestrictionQuery":                     false,
+			"v2.GetRoleRestrictionQuery":                 false,
+			"v2.ListRestrictionQueries":                  false,
+			"v2.ListRestrictionQueryRoles":               false,
+			"v2.ListUserRestrictionQueries":              false,
+			"v2.RemoveRoleFromRestrictionQuery":          false,
+			"v2.ReplaceRestrictionQuery":                 false,
+			"v2.UpdateRestrictionQuery":                  false,
 			"v2.CreateMonitorUserTemplate":               false,
 			"v2.DeleteMonitorUserTemplate":               false,
 			"v2.GetMonitorUserTemplate":                  false,
@@ -676,6 +711,16 @@ func NewConfiguration() *Configuration {
 			"v2.ValidateExistingMonitorUserTemplate":     false,
 			"v2.ValidateMonitorUserTemplate":             false,
 			"v2.ListRoleTemplates":                       false,
+			"v2.CreateConnection":                        false,
+			"v2.DeleteConnection":                        false,
+			"v2.GetAccountFacetInfo":                     false,
+			"v2.GetMapping":                              false,
+			"v2.GetUserFacetInfo":                        false,
+			"v2.ListConnections":                         false,
+			"v2.QueryAccounts":                           false,
+			"v2.QueryEventFilteredUsers":                 false,
+			"v2.QueryUsers":                              false,
+			"v2.UpdateConnection":                        false,
 			"v2.CreatePipeline":                          false,
 			"v2.DeletePipeline":                          false,
 			"v2.GetPipeline":                             false,
@@ -698,8 +743,14 @@ func NewConfiguration() *Configuration {
 			"v2.GetSLOReport":                            false,
 			"v2.GetSLOReportJobStatus":                   false,
 			"v2.GetSPARecommendations":                   false,
+			"v2.CreateSCAResolveVulnerableSymbols":       false,
+			"v2.CreateSCAResult":                         false,
 			"v2.AddMemberTeam":                           false,
+			"v2.CreateTeamConnections":                   false,
+			"v2.DeleteTeamConnections":                   false,
+			"v2.GetTeamSync":                             false,
 			"v2.ListMemberTeams":                         false,
+			"v2.ListTeamConnections":                     false,
 			"v2.RemoveMemberTeam":                        false,
 			"v2.SyncTeams":                               false,
 			"v2.CreateIncidentTeam":                      false,
