@@ -27,6 +27,9 @@ type LogsProcessor struct {
 	ReferenceTableLogsLookupProcessor *ReferenceTableLogsLookupProcessor
 	LogsTraceRemapper                 *LogsTraceRemapper
 	LogsSpanRemapper                  *LogsSpanRemapper
+	LogsArrayProcessor                *LogsArrayProcessor
+	LogsDecoderProcessor              *LogsDecoderProcessor
+	LogsSchemaProcessor               *LogsSchemaProcessor
 
 	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
 	UnparsedObject interface{}
@@ -117,6 +120,21 @@ func LogsSpanRemapperAsLogsProcessor(v *LogsSpanRemapper) LogsProcessor {
 	return LogsProcessor{LogsSpanRemapper: v}
 }
 
+// LogsArrayProcessorAsLogsProcessor is a convenience function that returns LogsArrayProcessor wrapped in LogsProcessor.
+func LogsArrayProcessorAsLogsProcessor(v *LogsArrayProcessor) LogsProcessor {
+	return LogsProcessor{LogsArrayProcessor: v}
+}
+
+// LogsDecoderProcessorAsLogsProcessor is a convenience function that returns LogsDecoderProcessor wrapped in LogsProcessor.
+func LogsDecoderProcessorAsLogsProcessor(v *LogsDecoderProcessor) LogsProcessor {
+	return LogsProcessor{LogsDecoderProcessor: v}
+}
+
+// LogsSchemaProcessorAsLogsProcessor is a convenience function that returns LogsSchemaProcessor wrapped in LogsProcessor.
+func LogsSchemaProcessorAsLogsProcessor(v *LogsSchemaProcessor) LogsProcessor {
+	return LogsProcessor{LogsSchemaProcessor: v}
+}
+
 // UnmarshalJSON turns data into one of the pointers in the struct.
 func (obj *LogsProcessor) UnmarshalJSON(data []byte) error {
 	var err error
@@ -410,6 +428,57 @@ func (obj *LogsProcessor) UnmarshalJSON(data []byte) error {
 		obj.LogsSpanRemapper = nil
 	}
 
+	// try to unmarshal data into LogsArrayProcessor
+	err = datadog.Unmarshal(data, &obj.LogsArrayProcessor)
+	if err == nil {
+		if obj.LogsArrayProcessor != nil && obj.LogsArrayProcessor.UnparsedObject == nil {
+			jsonLogsArrayProcessor, _ := datadog.Marshal(obj.LogsArrayProcessor)
+			if string(jsonLogsArrayProcessor) == "{}" { // empty struct
+				obj.LogsArrayProcessor = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.LogsArrayProcessor = nil
+		}
+	} else {
+		obj.LogsArrayProcessor = nil
+	}
+
+	// try to unmarshal data into LogsDecoderProcessor
+	err = datadog.Unmarshal(data, &obj.LogsDecoderProcessor)
+	if err == nil {
+		if obj.LogsDecoderProcessor != nil && obj.LogsDecoderProcessor.UnparsedObject == nil {
+			jsonLogsDecoderProcessor, _ := datadog.Marshal(obj.LogsDecoderProcessor)
+			if string(jsonLogsDecoderProcessor) == "{}" { // empty struct
+				obj.LogsDecoderProcessor = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.LogsDecoderProcessor = nil
+		}
+	} else {
+		obj.LogsDecoderProcessor = nil
+	}
+
+	// try to unmarshal data into LogsSchemaProcessor
+	err = datadog.Unmarshal(data, &obj.LogsSchemaProcessor)
+	if err == nil {
+		if obj.LogsSchemaProcessor != nil && obj.LogsSchemaProcessor.UnparsedObject == nil {
+			jsonLogsSchemaProcessor, _ := datadog.Marshal(obj.LogsSchemaProcessor)
+			if string(jsonLogsSchemaProcessor) == "{}" { // empty struct
+				obj.LogsSchemaProcessor = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.LogsSchemaProcessor = nil
+		}
+	} else {
+		obj.LogsSchemaProcessor = nil
+	}
+
 	if match != 1 { // more than 1 match
 		// reset to nil
 		obj.LogsGrokParser = nil
@@ -429,6 +498,9 @@ func (obj *LogsProcessor) UnmarshalJSON(data []byte) error {
 		obj.ReferenceTableLogsLookupProcessor = nil
 		obj.LogsTraceRemapper = nil
 		obj.LogsSpanRemapper = nil
+		obj.LogsArrayProcessor = nil
+		obj.LogsDecoderProcessor = nil
+		obj.LogsSchemaProcessor = nil
 		return datadog.Unmarshal(data, &obj.UnparsedObject)
 	}
 	return nil // exactly one match
@@ -504,6 +576,18 @@ func (obj LogsProcessor) MarshalJSON() ([]byte, error) {
 		return datadog.Marshal(&obj.LogsSpanRemapper)
 	}
 
+	if obj.LogsArrayProcessor != nil {
+		return datadog.Marshal(&obj.LogsArrayProcessor)
+	}
+
+	if obj.LogsDecoderProcessor != nil {
+		return datadog.Marshal(&obj.LogsDecoderProcessor)
+	}
+
+	if obj.LogsSchemaProcessor != nil {
+		return datadog.Marshal(&obj.LogsSchemaProcessor)
+	}
+
 	if obj.UnparsedObject != nil {
 		return datadog.Marshal(obj.UnparsedObject)
 	}
@@ -580,6 +664,18 @@ func (obj *LogsProcessor) GetActualInstance() interface{} {
 		return obj.LogsSpanRemapper
 	}
 
+	if obj.LogsArrayProcessor != nil {
+		return obj.LogsArrayProcessor
+	}
+
+	if obj.LogsDecoderProcessor != nil {
+		return obj.LogsDecoderProcessor
+	}
+
+	if obj.LogsSchemaProcessor != nil {
+		return obj.LogsSchemaProcessor
+	}
+
 	// all schemas are nil
 	return nil
 }
