@@ -12,6 +12,8 @@ import (
 
 // MonitorUpdateRequest Object describing a monitor update request.
 type MonitorUpdateRequest struct {
+	// The list of monitor assets tied to a monitor, which represents key links for users to take action on monitor alerts (for example, runbooks).
+	Assets []MonitorAsset `json:"assets,omitempty"`
 	// Timestamp of the monitor creation.
 	Created *time.Time `json:"created,omitempty"`
 	// Object describing the creator of the shared element.
@@ -77,6 +79,35 @@ func NewMonitorUpdateRequestWithDefaults() *MonitorUpdateRequest {
 	return &this
 }
 
+// GetAssets returns the Assets field value if set, zero value otherwise (both if not set or set to explicit null).
+func (o *MonitorUpdateRequest) GetAssets() []MonitorAsset {
+	if o == nil {
+		var ret []MonitorAsset
+		return ret
+	}
+	return o.Assets
+}
+
+// GetAssetsOk returns a tuple with the Assets field value if set, nil otherwise
+// and a boolean to check if the value has been set.
+// NOTE: If the value is an explicit nil, `nil, true` will be returned.
+func (o *MonitorUpdateRequest) GetAssetsOk() (*[]MonitorAsset, bool) {
+	if o == nil || o.Assets == nil {
+		return nil, false
+	}
+	return &o.Assets, true
+}
+
+// HasAssets returns a boolean if a field has been set.
+func (o *MonitorUpdateRequest) HasAssets() bool {
+	return o != nil && o.Assets != nil
+}
+
+// SetAssets gets a reference to the given []MonitorAsset and assigns it to the Assets field.
+func (o *MonitorUpdateRequest) SetAssets(v []MonitorAsset) {
+	o.Assets = v
+}
+
 // GetCreated returns the Created field value if set, zero value otherwise.
 func (o *MonitorUpdateRequest) GetCreated() time.Time {
 	if o == nil || o.Created == nil {
@@ -592,6 +623,9 @@ func (o MonitorUpdateRequest) MarshalJSON() ([]byte, error) {
 	if o.UnparsedObject != nil {
 		return datadog.Marshal(o.UnparsedObject)
 	}
+	if o.Assets != nil {
+		toSerialize["assets"] = o.Assets
+	}
 	if o.Created != nil {
 		if o.Created.Nanosecond() == 0 {
 			toSerialize["created"] = o.Created.Format("2006-01-02T15:04:05Z07:00")
@@ -661,6 +695,7 @@ func (o MonitorUpdateRequest) MarshalJSON() ([]byte, error) {
 // UnmarshalJSON deserializes the given payload.
 func (o *MonitorUpdateRequest) UnmarshalJSON(bytes []byte) (err error) {
 	all := struct {
+		Assets          []MonitorAsset               `json:"assets,omitempty"`
 		Created         *time.Time                   `json:"created,omitempty"`
 		Creator         *Creator                     `json:"creator,omitempty"`
 		Deleted         datadog.NullableTime         `json:"deleted,omitempty"`
@@ -684,12 +719,13 @@ func (o *MonitorUpdateRequest) UnmarshalJSON(bytes []byte) (err error) {
 	}
 	additionalProperties := make(map[string]interface{})
 	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
-		datadog.DeleteKeys(additionalProperties, &[]string{"created", "creator", "deleted", "draft_status", "id", "message", "modified", "multi", "name", "options", "overall_state", "priority", "query", "restricted_roles", "state", "tags", "type"})
+		datadog.DeleteKeys(additionalProperties, &[]string{"assets", "created", "creator", "deleted", "draft_status", "id", "message", "modified", "multi", "name", "options", "overall_state", "priority", "query", "restricted_roles", "state", "tags", "type"})
 	} else {
 		return err
 	}
 
 	hasInvalidField := false
+	o.Assets = all.Assets
 	o.Created = all.Created
 	if all.Creator != nil && all.Creator.UnparsedObject != nil && o.UnparsedObject == nil {
 		hasInvalidField = true
