@@ -20,6 +20,8 @@ type CaseAttributes struct {
 	ClosedAt datadog.NullableTime `json:"closed_at,omitempty"`
 	// Timestamp of when the case was created
 	CreatedAt *time.Time `json:"created_at,omitempty"`
+	// Case custom attributes
+	CustomAttributes map[string]CustomAttributeValue `json:"custom_attributes,omitempty"`
 	// Description
 	Description *string `json:"description,omitempty"`
 	// Jira issue attached to case
@@ -37,7 +39,10 @@ type CaseAttributes struct {
 	// Title
 	Title *string `json:"title,omitempty"`
 	// Case type
+	// Deprecated
 	Type *CaseType `json:"type,omitempty"`
+	// Case type UUID
+	TypeId *string `json:"type_id,omitempty"`
 	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
 	UnparsedObject       map[string]interface{} `json:"-"`
 	AdditionalProperties map[string]interface{} `json:"-"`
@@ -198,6 +203,34 @@ func (o *CaseAttributes) SetCreatedAt(v time.Time) {
 	o.CreatedAt = &v
 }
 
+// GetCustomAttributes returns the CustomAttributes field value if set, zero value otherwise.
+func (o *CaseAttributes) GetCustomAttributes() map[string]CustomAttributeValue {
+	if o == nil || o.CustomAttributes == nil {
+		var ret map[string]CustomAttributeValue
+		return ret
+	}
+	return o.CustomAttributes
+}
+
+// GetCustomAttributesOk returns a tuple with the CustomAttributes field value if set, nil otherwise
+// and a boolean to check if the value has been set.
+func (o *CaseAttributes) GetCustomAttributesOk() (*map[string]CustomAttributeValue, bool) {
+	if o == nil || o.CustomAttributes == nil {
+		return nil, false
+	}
+	return &o.CustomAttributes, true
+}
+
+// HasCustomAttributes returns a boolean if a field has been set.
+func (o *CaseAttributes) HasCustomAttributes() bool {
+	return o != nil && o.CustomAttributes != nil
+}
+
+// SetCustomAttributes gets a reference to the given map[string]CustomAttributeValue and assigns it to the CustomAttributes field.
+func (o *CaseAttributes) SetCustomAttributes(v map[string]CustomAttributeValue) {
+	o.CustomAttributes = v
+}
+
 // GetDescription returns the Description field value if set, zero value otherwise.
 func (o *CaseAttributes) GetDescription() string {
 	if o == nil || o.Description == nil {
@@ -456,6 +489,7 @@ func (o *CaseAttributes) SetTitle(v string) {
 }
 
 // GetType returns the Type field value if set, zero value otherwise.
+// Deprecated
 func (o *CaseAttributes) GetType() CaseType {
 	if o == nil || o.Type == nil {
 		var ret CaseType
@@ -466,6 +500,7 @@ func (o *CaseAttributes) GetType() CaseType {
 
 // GetTypeOk returns a tuple with the Type field value if set, nil otherwise
 // and a boolean to check if the value has been set.
+// Deprecated
 func (o *CaseAttributes) GetTypeOk() (*CaseType, bool) {
 	if o == nil || o.Type == nil {
 		return nil, false
@@ -479,10 +514,39 @@ func (o *CaseAttributes) HasType() bool {
 }
 
 // SetType gets a reference to the given CaseType and assigns it to the Type field.
+// Deprecated
 func (o *CaseAttributes) SetType(v CaseType) {
 	o.Type = &v
 }
 
+// GetTypeId returns the TypeId field value if set, zero value otherwise.
+func (o *CaseAttributes) GetTypeId() string {
+	if o == nil || o.TypeId == nil {
+		var ret string
+		return ret
+	}
+	return *o.TypeId
+}
+
+// GetTypeIdOk returns a tuple with the TypeId field value if set, nil otherwise
+// and a boolean to check if the value has been set.
+func (o *CaseAttributes) GetTypeIdOk() (*string, bool) {
+	if o == nil || o.TypeId == nil {
+		return nil, false
+	}
+	return o.TypeId, true
+}
+
+// HasTypeId returns a boolean if a field has been set.
+func (o *CaseAttributes) HasTypeId() bool {
+	return o != nil && o.TypeId != nil
+}
+
+// SetTypeId gets a reference to the given string and assigns it to the TypeId field.
+func (o *CaseAttributes) SetTypeId(v string) {
+	o.TypeId = &v
+}
+
 // MarshalJSON serializes the struct using spec logic.
 func (o CaseAttributes) MarshalJSON() ([]byte, error) {
 	toSerialize := map[string]interface{}{}
@@ -505,6 +569,9 @@ func (o CaseAttributes) MarshalJSON() ([]byte, error) {
 			toSerialize["created_at"] = o.CreatedAt.Format("2006-01-02T15:04:05.000Z07:00")
 		}
 	}
+	if o.CustomAttributes != nil {
+		toSerialize["custom_attributes"] = o.CustomAttributes
+	}
 	if o.Description != nil {
 		toSerialize["description"] = o.Description
 	}
@@ -532,6 +599,9 @@ func (o CaseAttributes) MarshalJSON() ([]byte, error) {
 	if o.Type != nil {
 		toSerialize["type"] = o.Type
 	}
+	if o.TypeId != nil {
+		toSerialize["type_id"] = o.TypeId
+	}
 
 	for key, value := range o.AdditionalProperties {
 		toSerialize[key] = value
@@ -542,26 +612,28 @@ func (o CaseAttributes) MarshalJSON() ([]byte, error) {
 // UnmarshalJSON deserializes the given payload.
 func (o *CaseAttributes) UnmarshalJSON(bytes []byte) (err error) {
 	all := struct {
-		ArchivedAt       datadog.NullableTime     `json:"archived_at,omitempty"`
-		Attributes       map[string][]string      `json:"attributes,omitempty"`
-		ClosedAt         datadog.NullableTime     `json:"closed_at,omitempty"`
-		CreatedAt        *time.Time               `json:"created_at,omitempty"`
-		Description      *string                  `json:"description,omitempty"`
-		JiraIssue        NullableJiraIssue        `json:"jira_issue,omitempty"`
-		Key              *string                  `json:"key,omitempty"`
-		ModifiedAt       datadog.NullableTime     `json:"modified_at,omitempty"`
-		Priority         *CasePriority            `json:"priority,omitempty"`
-		ServiceNowTicket NullableServiceNowTicket `json:"service_now_ticket,omitempty"`
-		Status           *CaseStatus              `json:"status,omitempty"`
-		Title            *string                  `json:"title,omitempty"`
-		Type             *CaseType                `json:"type,omitempty"`
+		ArchivedAt       datadog.NullableTime            `json:"archived_at,omitempty"`
+		Attributes       map[string][]string             `json:"attributes,omitempty"`
+		ClosedAt         datadog.NullableTime            `json:"closed_at,omitempty"`
+		CreatedAt        *time.Time                      `json:"created_at,omitempty"`
+		CustomAttributes map[string]CustomAttributeValue `json:"custom_attributes,omitempty"`
+		Description      *string                         `json:"description,omitempty"`
+		JiraIssue        NullableJiraIssue               `json:"jira_issue,omitempty"`
+		Key              *string                         `json:"key,omitempty"`
+		ModifiedAt       datadog.NullableTime            `json:"modified_at,omitempty"`
+		Priority         *CasePriority                   `json:"priority,omitempty"`
+		ServiceNowTicket NullableServiceNowTicket        `json:"service_now_ticket,omitempty"`
+		Status           *CaseStatus                     `json:"status,omitempty"`
+		Title            *string                         `json:"title,omitempty"`
+		Type             *CaseType                       `json:"type,omitempty"`
+		TypeId           *string                         `json:"type_id,omitempty"`
 	}{}
 	if err = datadog.Unmarshal(bytes, &all); err != nil {
 		return datadog.Unmarshal(bytes, &o.UnparsedObject)
 	}
 	additionalProperties := make(map[string]interface{})
 	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
-		datadog.DeleteKeys(additionalProperties, &[]string{"archived_at", "attributes", "closed_at", "created_at", "description", "jira_issue", "key", "modified_at", "priority", "service_now_ticket", "status", "title", "type"})
+		datadog.DeleteKeys(additionalProperties, &[]string{"archived_at", "attributes", "closed_at", "created_at", "custom_attributes", "description", "jira_issue", "key", "modified_at", "priority", "service_now_ticket", "status", "title", "type", "type_id"})
 	} else {
 		return err
 	}
@@ -571,6 +643,7 @@ func (o *CaseAttributes) UnmarshalJSON(bytes []byte) (err error) {
 	o.Attributes = all.Attributes
 	o.ClosedAt = all.ClosedAt
 	o.CreatedAt = all.CreatedAt
+	o.CustomAttributes = all.CustomAttributes
 	o.Description = all.Description
 	o.JiraIssue = all.JiraIssue
 	o.Key = all.Key
@@ -592,6 +665,7 @@ func (o *CaseAttributes) UnmarshalJSON(bytes []byte) (err error) {
 	} else {
 		o.Type = all.Type
 	}
+	o.TypeId = all.TypeId
 
 	if len(additionalProperties) > 0 {
 		o.AdditionalProperties = additionalProperties
