@@ -14,9 +14,9 @@ import (
 // It requires a bucket name, GCP authentication, and metadata fields.
 type ObservabilityPipelineGoogleCloudStorageDestination struct {
 	// Access control list setting for objects written to the bucket.
-	Acl ObservabilityPipelineGoogleCloudStorageDestinationAcl `json:"acl"`
+	Acl *ObservabilityPipelineGoogleCloudStorageDestinationAcl `json:"acl,omitempty"`
 	// GCP credentials used to authenticate with Google Cloud Storage.
-	Auth ObservabilityPipelineGcpAuth `json:"auth"`
+	Auth *ObservabilityPipelineGcpAuth `json:"auth,omitempty"`
 	// Name of the GCS bucket.
 	Bucket string `json:"bucket"`
 	// Unique identifier for the destination component.
@@ -40,10 +40,8 @@ type ObservabilityPipelineGoogleCloudStorageDestination struct {
 // This constructor will assign default values to properties that have it defined,
 // and makes sure properties required by API are set, but the set of arguments
 // will change when the set of required properties is changed.
-func NewObservabilityPipelineGoogleCloudStorageDestination(acl ObservabilityPipelineGoogleCloudStorageDestinationAcl, auth ObservabilityPipelineGcpAuth, bucket string, id string, inputs []string, storageClass ObservabilityPipelineGoogleCloudStorageDestinationStorageClass, typeVar ObservabilityPipelineGoogleCloudStorageDestinationType) *ObservabilityPipelineGoogleCloudStorageDestination {
+func NewObservabilityPipelineGoogleCloudStorageDestination(bucket string, id string, inputs []string, storageClass ObservabilityPipelineGoogleCloudStorageDestinationStorageClass, typeVar ObservabilityPipelineGoogleCloudStorageDestinationType) *ObservabilityPipelineGoogleCloudStorageDestination {
 	this := ObservabilityPipelineGoogleCloudStorageDestination{}
-	this.Acl = acl
-	this.Auth = auth
 	this.Bucket = bucket
 	this.Id = id
 	this.Inputs = inputs
@@ -62,50 +60,60 @@ func NewObservabilityPipelineGoogleCloudStorageDestinationWithDefaults() *Observ
 	return &this
 }
 
-// GetAcl returns the Acl field value.
+// GetAcl returns the Acl field value if set, zero value otherwise.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) GetAcl() ObservabilityPipelineGoogleCloudStorageDestinationAcl {
-	if o == nil {
+	if o == nil || o.Acl == nil {
 		var ret ObservabilityPipelineGoogleCloudStorageDestinationAcl
 		return ret
 	}
-	return o.Acl
+	return *o.Acl
 }
 
-// GetAclOk returns a tuple with the Acl field value
+// GetAclOk returns a tuple with the Acl field value if set, nil otherwise
 // and a boolean to check if the value has been set.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) GetAclOk() (*ObservabilityPipelineGoogleCloudStorageDestinationAcl, bool) {
-	if o == nil {
+	if o == nil || o.Acl == nil {
 		return nil, false
 	}
-	return &o.Acl, true
+	return o.Acl, true
 }
 
-// SetAcl sets field value.
+// HasAcl returns a boolean if a field has been set.
+func (o *ObservabilityPipelineGoogleCloudStorageDestination) HasAcl() bool {
+	return o != nil && o.Acl != nil
+}
+
+// SetAcl gets a reference to the given ObservabilityPipelineGoogleCloudStorageDestinationAcl and assigns it to the Acl field.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) SetAcl(v ObservabilityPipelineGoogleCloudStorageDestinationAcl) {
-	o.Acl = v
+	o.Acl = &v
 }
 
-// GetAuth returns the Auth field value.
+// GetAuth returns the Auth field value if set, zero value otherwise.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) GetAuth() ObservabilityPipelineGcpAuth {
-	if o == nil {
+	if o == nil || o.Auth == nil {
 		var ret ObservabilityPipelineGcpAuth
 		return ret
 	}
-	return o.Auth
+	return *o.Auth
 }
 
-// GetAuthOk returns a tuple with the Auth field value
+// GetAuthOk returns a tuple with the Auth field value if set, nil otherwise
 // and a boolean to check if the value has been set.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) GetAuthOk() (*ObservabilityPipelineGcpAuth, bool) {
-	if o == nil {
+	if o == nil || o.Auth == nil {
 		return nil, false
 	}
-	return &o.Auth, true
+	return o.Auth, true
 }
 
-// SetAuth sets field value.
+// HasAuth returns a boolean if a field has been set.
+func (o *ObservabilityPipelineGoogleCloudStorageDestination) HasAuth() bool {
+	return o != nil && o.Auth != nil
+}
+
+// SetAuth gets a reference to the given ObservabilityPipelineGcpAuth and assigns it to the Auth field.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) SetAuth(v ObservabilityPipelineGcpAuth) {
-	o.Auth = v
+	o.Auth = &v
 }
 
 // GetBucket returns the Bucket field value.
@@ -285,8 +293,12 @@ func (o ObservabilityPipelineGoogleCloudStorageDestination) MarshalJSON() ([]byt
 	if o.UnparsedObject != nil {
 		return datadog.Marshal(o.UnparsedObject)
 	}
-	toSerialize["acl"] = o.Acl
-	toSerialize["auth"] = o.Auth
+	if o.Acl != nil {
+		toSerialize["acl"] = o.Acl
+	}
+	if o.Auth != nil {
+		toSerialize["auth"] = o.Auth
+	}
 	toSerialize["bucket"] = o.Bucket
 	toSerialize["id"] = o.Id
 	toSerialize["inputs"] = o.Inputs
@@ -308,8 +320,8 @@ func (o ObservabilityPipelineGoogleCloudStorageDestination) MarshalJSON() ([]byt
 // UnmarshalJSON deserializes the given payload.
 func (o *ObservabilityPipelineGoogleCloudStorageDestination) UnmarshalJSON(bytes []byte) (err error) {
 	all := struct {
-		Acl          *ObservabilityPipelineGoogleCloudStorageDestinationAcl          `json:"acl"`
-		Auth         *ObservabilityPipelineGcpAuth                                   `json:"auth"`
+		Acl          *ObservabilityPipelineGoogleCloudStorageDestinationAcl          `json:"acl,omitempty"`
+		Auth         *ObservabilityPipelineGcpAuth                                   `json:"auth,omitempty"`
 		Bucket       *string                                                         `json:"bucket"`
 		Id           *string                                                         `json:"id"`
 		Inputs       *[]string                                                       `json:"inputs"`
@@ -321,12 +333,6 @@ func (o *ObservabilityPipelineGoogleCloudStorageDestination) UnmarshalJSON(bytes
 	if err = datadog.Unmarshal(bytes, &all); err != nil {
 		return datadog.Unmarshal(bytes, &o.UnparsedObject)
 	}
-	if all.Acl == nil {
-		return fmt.Errorf("required field acl missing")
-	}
-	if all.Auth == nil {
-		return fmt.Errorf("required field auth missing")
-	}
 	if all.Bucket == nil {
 		return fmt.Errorf("required field bucket missing")
 	}
@@ -350,15 +356,15 @@ func (o *ObservabilityPipelineGoogleCloudStorageDestination) UnmarshalJSON(bytes
 	}
 
 	hasInvalidField := false
-	if !all.Acl.IsValid() {
+	if all.Acl != nil && !all.Acl.IsValid() {
 		hasInvalidField = true
 	} else {
-		o.Acl = *all.Acl
+		o.Acl = all.Acl
 	}
-	if all.Auth.UnparsedObject != nil && o.UnparsedObject == nil {
+	if all.Auth != nil && all.Auth.UnparsedObject != nil && o.UnparsedObject == nil {
 		hasInvalidField = true
 	}
-	o.Auth = *all.Auth
+	o.Auth = all.Auth
 	o.Bucket = *all.Bucket
 	o.Id = *all.Id
 	o.Inputs = *all.Inputs
