@@ -27,6 +27,8 @@ type ScheduleCreateRequestDataAttributesLayersItems struct {
 	Restrictions []TimeRestriction `json:"restrictions,omitempty"`
 	// The date/time when the rotation for this layer starts (in ISO 8601).
 	RotationStart time.Time `json:"rotation_start"`
+	// The time zone for this layer.
+	TimeZone *string `json:"time_zone,omitempty"`
 	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
 	UnparsedObject       map[string]interface{} `json:"-"`
 	AdditionalProperties map[string]interface{} `json:"-"`
@@ -225,6 +227,34 @@ func (o *ScheduleCreateRequestDataAttributesLayersItems) SetRotationStart(v time
 	o.RotationStart = v
 }
 
+// GetTimeZone returns the TimeZone field value if set, zero value otherwise.
+func (o *ScheduleCreateRequestDataAttributesLayersItems) GetTimeZone() string {
+	if o == nil || o.TimeZone == nil {
+		var ret string
+		return ret
+	}
+	return *o.TimeZone
+}
+
+// GetTimeZoneOk returns a tuple with the TimeZone field value if set, nil otherwise
+// and a boolean to check if the value has been set.
+func (o *ScheduleCreateRequestDataAttributesLayersItems) GetTimeZoneOk() (*string, bool) {
+	if o == nil || o.TimeZone == nil {
+		return nil, false
+	}
+	return o.TimeZone, true
+}
+
+// HasTimeZone returns a boolean if a field has been set.
+func (o *ScheduleCreateRequestDataAttributesLayersItems) HasTimeZone() bool {
+	return o != nil && o.TimeZone != nil
+}
+
+// SetTimeZone gets a reference to the given string and assigns it to the TimeZone field.
+func (o *ScheduleCreateRequestDataAttributesLayersItems) SetTimeZone(v string) {
+	o.TimeZone = &v
+}
+
 // MarshalJSON serializes the struct using spec logic.
 func (o ScheduleCreateRequestDataAttributesLayersItems) MarshalJSON() ([]byte, error) {
 	toSerialize := map[string]interface{}{}
@@ -254,6 +284,9 @@ func (o ScheduleCreateRequestDataAttributesLayersItems) MarshalJSON() ([]byte, e
 	} else {
 		toSerialize["rotation_start"] = o.RotationStart.Format("2006-01-02T15:04:05.000Z07:00")
 	}
+	if o.TimeZone != nil {
+		toSerialize["time_zone"] = o.TimeZone
+	}
 
 	for key, value := range o.AdditionalProperties {
 		toSerialize[key] = value
@@ -271,6 +304,7 @@ func (o *ScheduleCreateRequestDataAttributesLayersItems) UnmarshalJSON(bytes []b
 		Name          *string                                                 `json:"name"`
 		Restrictions  []TimeRestriction                                       `json:"restrictions,omitempty"`
 		RotationStart *time.Time                                              `json:"rotation_start"`
+		TimeZone      *string                                                 `json:"time_zone,omitempty"`
 	}{}
 	if err = datadog.Unmarshal(bytes, &all); err != nil {
 		return datadog.Unmarshal(bytes, &o.UnparsedObject)
@@ -292,7 +326,7 @@ func (o *ScheduleCreateRequestDataAttributesLayersItems) UnmarshalJSON(bytes []b
 	}
 	additionalProperties := make(map[string]interface{})
 	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
-		datadog.DeleteKeys(additionalProperties, &[]string{"effective_date", "end_date", "interval", "members", "name", "restrictions", "rotation_start"})
+		datadog.DeleteKeys(additionalProperties, &[]string{"effective_date", "end_date", "interval", "members", "name", "restrictions", "rotation_start", "time_zone"})
 	} else {
 		return err
 	}
@@ -308,6 +342,7 @@ func (o *ScheduleCreateRequestDataAttributesLayersItems) UnmarshalJSON(bytes []b
 	o.Name = *all.Name
 	o.Restrictions = all.Restrictions
 	o.RotationStart = *all.RotationStart
+	o.TimeZone = all.TimeZone
 
 	if len(additionalProperties) > 0 {
 		o.AdditionalProperties = additionalProperties
