@@ -4,7 +4,7 @@ import (
 	"reflect"
 	"time"
 
-	"go.opentelemetry.io/obi/pkg/services"
+	"go.opentelemetry.io/obi/pkg/appolly/services"
 )
 
 const (
@@ -22,6 +22,7 @@ var K8sDefaultNamespacesGlob = services.NewGlob("{kube-system,kube-node-lease,lo
 
 var K8sDefaultNamespacesWithSurveyRegex = services.NewRegexp("^kube-system$|^kube-node-lease$|^local-path-storage$|^cert-manager$" + k8sGKEDefaultNamespacesRegex + k8sAKSDefaultNamespacesRegex)
 var K8sDefaultNamespacesWithSurveyGlob = services.NewGlob("{kube-system,kube-node-lease,local-path-storage,cert-manager" + k8sGKEDefaultNamespacesGlob + k8sAKSDefaultNamespacesGlob + "}")
+var K8sDefaultExcludeContainerNamesGlob = services.NewGlob("{beyla,ebpf-instrument,alloy,prometheus-config-reloader,otelcol,otelcol-contrib}")
 
 var DefaultExcludeServices = services.RegexDefinitionCriteria{
 	services.RegexSelector{
@@ -47,6 +48,9 @@ var DefaultExcludeInstrument = services.GlobDefinitionCriteria{
 	services.GlobAttributes{
 		Metadata: map[string]*services.GlobAttr{"k8s_namespace": &K8sDefaultNamespacesGlob},
 	},
+	services.GlobAttributes{
+		Metadata: map[string]*services.GlobAttr{"k8s_container_name": &K8sDefaultExcludeContainerNamesGlob},
+	},
 }
 var DefaultExcludeInstrumentWithSurvey = services.GlobDefinitionCriteria{
 	services.GlobAttributes{
@@ -55,6 +59,9 @@ var DefaultExcludeInstrumentWithSurvey = services.GlobDefinitionCriteria{
 	services.GlobAttributes{
 		Metadata: map[string]*services.GlobAttr{"k8s_namespace": &K8sDefaultNamespacesWithSurveyGlob},
 	},
+	services.GlobAttributes{
+		Metadata: map[string]*services.GlobAttr{"k8s_container_name": &K8sDefaultExcludeContainerNamesGlob},
+	},
 }
 
 // DiscoveryConfig for the discover.ProcessFinder pipeline
@@ -126,6 +133,14 @@ type BeylaDiscoveryConfig struct {
 
 	// nolint:undoc
 	DisabledRouteHarvesters []string `yaml:"disabled_route_harvesters"`
+
+	// nolint:undoc
+	RouteHarvestConfig RouteHarvestingConfig `yaml:"route_harvester_advanced"`
+}
+
+type RouteHarvestingConfig struct {
+	// nolint:undoc
+	JavaHarvestDelay time.Duration `yaml:"java_harvest_delay" env:"OTEL_EBPF_JAVA_ROUTE_HARVEST_DELAY"`
 }
 
 func (d *BeylaDiscoveryConfig) SurveyEnabled() bool {
