@@ -95,6 +95,7 @@ func getDefinitions(
 			attr.ClientPort:     false,
 			attr.SrcZone:        false,
 			attr.DstZone:        false,
+			attr.NetworkType:    false,
 			attr.IfaceDirection: Default(ifaceDirEnabled),
 			attr.Iface:          Default(ifaceDirEnabled),
 		},
@@ -229,6 +230,7 @@ func getDefinitions(
 		map[attr.Name]Default{
 			attr.MessagingSystem:      true,
 			attr.MessagingDestination: true,
+			attr.ServerAddr:           true,
 		},
 		extraGroupAttributes[GroupMessaging],
 	)
@@ -277,6 +279,7 @@ func getDefinitions(
 		DBClientDuration.Section: {
 			SubGroups: []*AttrReportGroup{&appAttributes, &appKubeAttributes},
 			Attributes: map[attr.Name]Default{
+				attr.ServerAddr:   true,
 				attr.DBOperation:  true,
 				attr.DBSystemName: true,
 				attr.ErrorType:    true,
@@ -321,6 +324,13 @@ func getDefinitions(
 				attr.CudaMemcpyKind: true,
 			},
 		},
+		DNSLookupDuration.Section: {
+			SubGroups: []*AttrReportGroup{&appAttributes, &appKubeAttributes},
+			Attributes: map[attr.Name]Default{
+				attr.DNSQuestionName: true,
+				attr.ErrorType:       true,
+			},
+		},
 		// span and service graph metrics don't yet implement attribute selection,
 		// but their values can still be filtered, so we list them here just to
 		// make the filter recognize its attributes
