@@ -16,17 +16,17 @@ import (
 	semconv "go.opentelemetry.io/otel/semconv/v1.19.0"
 	"go.opentelemetry.io/otel/trace"
 
-	"go.opentelemetry.io/obi/pkg/app/request"
-	"go.opentelemetry.io/obi/pkg/components/exec"
-	"go.opentelemetry.io/obi/pkg/components/imetrics"
-	"go.opentelemetry.io/obi/pkg/components/pipe/global"
-	"go.opentelemetry.io/obi/pkg/components/svc"
+	"go.opentelemetry.io/obi/pkg/appolly/app/request"
+	"go.opentelemetry.io/obi/pkg/appolly/app/svc"
+	"go.opentelemetry.io/obi/pkg/appolly/discover/exec"
 	"go.opentelemetry.io/obi/pkg/export/attributes"
 	attr "go.opentelemetry.io/obi/pkg/export/attributes/names"
+	"go.opentelemetry.io/obi/pkg/export/imetrics"
 	"go.opentelemetry.io/obi/pkg/export/instrumentations"
 	"go.opentelemetry.io/obi/pkg/export/otel/metric"
 	instrument "go.opentelemetry.io/obi/pkg/export/otel/metric/api/metric"
 	"go.opentelemetry.io/obi/pkg/export/otel/otelcfg"
+	"go.opentelemetry.io/obi/pkg/pipe/global"
 	"go.opentelemetry.io/obi/pkg/pipe/msg"
 	"go.opentelemetry.io/obi/pkg/pipe/swarm"
 )
@@ -101,6 +101,7 @@ type MetricsReporter struct {
 	attrGPUKernelBlockSize     []attributes.Field[*request.Span, attribute.KeyValue]
 	attrGPUMemoryAllocations   []attributes.Field[*request.Span, attribute.KeyValue]
 	attrGPUMemoryCopies        []attributes.Field[*request.Span, attribute.KeyValue]
+	attrDNSLookupDuration      []attributes.Field[*request.Span, attribute.KeyValue]
 	userAttribSelection        attributes.Selection
 	input                      <-chan []request.Span
 	processEvents              <-chan exec.ProcessEvent
@@ -136,11 +137,14 @@ type Metrics struct {
 	spanMetricsCallsTotal        *Expirer[*request.Span, instrument.Int64Counter, int64]
 	spanMetricsRequestSizeTotal  *Expirer[*request.Span, instrument.Float64Counter, float64]
 	spanMetricsResponseSizeTotal *Expirer[*request.Span, instrument.Float64Counter, float64]
-	gpuKernelCallsTotal          *Expirer[*request.Span, instrument.Int64Counter, int64]
-	gpuMemoryAllocsTotal         *Expirer[*request.Span, instrument.Int64Counter, int64]
-	gpuKernelGridSize            *Expirer[*request.Span, instrument.Float64Histogram, float64]
-	gpuKernelBlockSize           *Expirer[*request.Span, instrument.Float64Histogram, float64]
-	gpuMemoryCopySize            *Expirer[*request.Span, instrument.Float64Histogram, float64]
+	// cuda/gpu
+	gpuKernelCallsTotal  *Expirer[*request.Span, instrument.Int64Counter, int64]
+	gpuMemoryAllocsTotal *Expirer[*request.Span, instrument.Int64Counter, int64]
+	gpuKernelGridSize    *Expirer[*request.Span, instrument.Float64Histogram, float64]
+	gpuKernelBlockSize   *Expirer[*request.Span, instrument.Float64Histogram, float64]
+	gpuMemoryCopySize    *Expirer[*request.Span, instrument.Float64Histogram, float64]
+	// dns
+	dnsLookupDuration *Expirer[*request.Span, instrument.Float64Histogram, float64]
 }
 
 type TargetMetrics struct {
@@ -267,6 +271,11 @@ func newMetricsReporter(
 			mr.attrGetters, mr.attributes.For(attributes.GPUMemoryCopies))
 	}
 
+	if is.DNSEnabled() {
+		mr.attrDNSLookupDuration = attributes.OpenTelemetryGetters(
+			mr.attrGetters, mr.attributes.For(attributes.DNSLookupDuration))
+	}
+
 	mr.reporters = otelcfg.NewReporterPool[*svc.Attrs, *Metrics](cfg.ReportersCacheLen, cfg.TTL, timeNow,
 		func(id svc.UID, v *Metrics) {
 			llog := log.With("service", id)
@@ -517,6 +526,15 @@ func (mr *MetricsReporter) setupOtelMeters(m *Metrics, meter instrument.Meter) e
 			m.ctx, gpuMemoryCopySize, mr.attrGPUMemoryCopies, timeNow, mr.cfg.TTL)
 	}
 
+	if mr.is.DNSEnabled() {
+		dnsLookupDuration, err := meter.Float64Histogram(attributes.DNSLookupDuration.OTEL, instrument.WithUnit("s"))
+		if err != nil {
+			return fmt.Errorf("creating dns lookup duration histogram: %w", err)
+		}
+		m.dnsLookupDuration = NewExpirer[*request.Span, instrument.Float64Histogram, float64](
+			m.ctx, dnsLookupDuration, mr.attrDNSLookupDuration, timeNow, mr.cfg.TTL)
+	}
+
 	return nil
 }
 
@@ -794,7 +812,7 @@ func otelMetricsAccepted(span *request.Span, mr *MetricsReporter) bool {
 }
 
 func otelSpanMetricsAccepted(span *request.Span, mr *MetricsReporter) bool {
-	return mr.cfg.AnySpanMetricsEnabled() && !span.Service.ExportsOTelMetricsSpan()
+	return mr.cfg.AnySpanMetricsEnabled() && !span.Service.ExportsOTelMetricsSpan() && !span.IsDNSSpan()
 }
 
 //nolint:cyclop
@@ -874,6 +892,11 @@ func (r *Metrics) record(span *request.Span, mr *MetricsReporter) {
 				gmem, attrs := r.gpuMemoryCopySize.ForRecord(span)
 				gmem.Record(r.ctx, float64(span.ContentLength), instrument.WithAttributeSet(attrs))
 			}
+		case request.EventTypeDNS:
+			if mr.is.DNSEnabled() {
+				dnsDuration, attrs := r.dnsLookupDuration.ForRecord(span)
+				dnsDuration.Record(ctx, duration, instrument.WithAttributeSet(attrs))
+			}
 		}
 	}
 
@@ -887,18 +910,18 @@ func (r *Metrics) record(span *request.Span, mr *MetricsReporter) {
 		}
 
 		if mr.cfg.SpanMetricsEnabled() {
-			sml, attrs := r.spanMetricsLatency.ForRecord(span, extraAttrs...)
+			sml, attrs := r.spanMetricsLatency.ForRecord(span)
 			sml.Record(ctx, duration, instrument.WithAttributeSet(attrs))
 
-			smct, attrs := r.spanMetricsCallsTotal.ForRecord(span, extraAttrs...)
+			smct, attrs := r.spanMetricsCallsTotal.ForRecord(span)
 			smct.Add(ctx, 1, instrument.WithAttributeSet(attrs))
 		}
 
 		if mr.cfg.SpanMetricsSizesEnabled() {
-			smst, attrs := r.spanMetricsRequestSizeTotal.ForRecord(span, extraAttrs...)
+			smst, attrs := r.spanMetricsRequestSizeTotal.ForRecord(span)
 			smst.Add(ctx, float64(span.RequestBodyLength()), instrument.WithAttributeSet(attrs))
 
-			smst, attr := r.spanMetricsResponseSizeTotal.ForRecord(span, extraAttrs...)
+			smst, attr := r.spanMetricsResponseSizeTotal.ForRecord(span)
 			smst.Add(ctx, float64(span.ResponseBodyLength()), instrument.WithAttributeSet(attr))
 		}
 	}
