@@ -11,6 +11,7 @@ import (
 
 	expirable2 "github.com/hashicorp/golang-lru/v2/expirable"
 	"go.uber.org/zap"
+	"go.uber.org/zap/zapcore"
 
 	"go.opentelemetry.io/collector/component"
 	"go.opentelemetry.io/collector/config/configgrpc"
@@ -18,9 +19,11 @@ import (
 	"go.opentelemetry.io/collector/config/configopaque"
 	"go.opentelemetry.io/collector/config/configoptional"
 	"go.opentelemetry.io/collector/config/configretry"
+	"go.opentelemetry.io/collector/config/configtelemetry"
 	"go.opentelemetry.io/collector/config/configtls"
 	"go.opentelemetry.io/collector/consumer"
 	"go.opentelemetry.io/collector/exporter"
+	"go.opentelemetry.io/collector/exporter/debugexporter"
 	"go.opentelemetry.io/collector/exporter/exporterhelper"
 	"go.opentelemetry.io/collector/exporter/otlpexporter"
 	"go.opentelemetry.io/collector/exporter/otlphttpexporter"
@@ -30,15 +33,15 @@ import (
 	"go.opentelemetry.io/otel/sdk/trace"
 	tracenoop "go.opentelemetry.io/otel/trace/noop"
 
-	"go.opentelemetry.io/obi/pkg/app/request"
-	"go.opentelemetry.io/obi/pkg/components/imetrics"
-	"go.opentelemetry.io/obi/pkg/components/pipe/global"
-	"go.opentelemetry.io/obi/pkg/components/svc"
+	"go.opentelemetry.io/obi/pkg/appolly/app/request"
+	"go.opentelemetry.io/obi/pkg/appolly/app/svc"
 	"go.opentelemetry.io/obi/pkg/export/attributes"
 	attr "go.opentelemetry.io/obi/pkg/export/attributes/names"
+	"go.opentelemetry.io/obi/pkg/export/imetrics"
 	"go.opentelemetry.io/obi/pkg/export/instrumentations"
 	"go.opentelemetry.io/obi/pkg/export/otel/otelcfg"
 	"go.opentelemetry.io/obi/pkg/export/otel/tracesgen"
+	"go.opentelemetry.io/obi/pkg/pipe/global"
 	"go.opentelemetry.io/obi/pkg/pipe/msg"
 	"go.opentelemetry.io/obi/pkg/pipe/swarm"
 	"go.opentelemetry.io/obi/pkg/pipe/swarm/swarms"
@@ -122,16 +125,29 @@ func (tr *tracesOTELReceiver) processSpans(ctx context.Context, exp exporter.Tra
 			if tr.spanMetricsEnabled {
 				envResourceAttrs = append(envResourceAttrs, attribute.Bool(string(attr.SkipSpanMetrics.OTEL()), true))
 			}
-
 			traces := tracesgen.GenerateTracesWithAttributes(tr.attributeCache, &sample.Span.Service, envResourceAttrs, tr.ctxInfo.HostID, spanGroup, reporterName, tr.ctxInfo.ExtraResourceAttributes...)
 			err := exp.ConsumeTraces(ctx, traces)
 			if err != nil {
-				slog.Error("error sending trace to consumer", "error", err)
+				// We can't do if errors.Is(err, queue.ErrQueueIsFull), since the queue package is internal
+				if err.Error() == "sending queue is full" {
+					// TODO: set this condition case to Warn once we make sure that
+					// queueConfig.BlockOnOverflow = true works as expected
+					slog.Debug("error sending trace to consumer", "error", err)
+				} else {
+					slog.Warn("error sending trace to consumer", "error", err)
+				}
 			}
 		}
 	}
 }
 
+// emptyHost prevents nil pointer dereference after invoking exp.Start below
+type emptyHost struct{}
+
+func (emptyHost) GetExtensions() map[component.ID]component.Component {
+	return nil
+}
+
 func (tr *tracesOTELReceiver) provideLoop(ctx context.Context) {
 	exp, err := getTracesExporter(ctx, tr.cfg, tr.ctxInfo.Metrics)
 	if err != nil {
@@ -144,7 +160,7 @@ func (tr *tracesOTELReceiver) provideLoop(ctx context.Context) {
 			slog.Error("error shutting down traces exporter", "error", err)
 		}
 	}()
-	err = exp.Start(ctx, nil)
+	err = exp.Start(ctx, emptyHost{})
 	if err != nil {
 		slog.Error("error starting traces exporter", "error", err)
 		return
@@ -190,23 +206,7 @@ func getTracesExporter(ctx context.Context, cfg otelcfg.TracesConfig, im imetric
 		}
 		factory := otlphttpexporter.NewFactory()
 		config := factory.CreateDefaultConfig().(*otlphttpexporter.Config)
-		queueConfig := exporterhelper.NewDefaultQueueConfig()
-		queueConfig.Sizer = exporterhelper.RequestSizerTypeItems
-		batchCfg := exporterhelper.BatchConfig{
-			Sizer: queueConfig.Sizer,
-		}
-		if cfg.MaxQueueSize > 0 || cfg.BatchTimeout > 0 {
-			queueConfig.Enabled = true
-		}
-		if cfg.MaxQueueSize > 0 {
-			batchCfg.MaxSize = int64(cfg.MaxQueueSize)
-		}
-		if cfg.BatchTimeout > 0 {
-			batchCfg.FlushTimeout = cfg.BatchTimeout
-			batchCfg.MinSize = int64(cfg.MaxQueueSize)
-		}
-		queueConfig.Batch = configoptional.Some(batchCfg)
-		config.QueueConfig = queueConfig
+		config.QueueConfig = getQueueSettings(cfg)
 		config.RetryConfig = getRetrySettings(cfg)
 		config.ClientConfig = confighttp.ClientConfig{
 			Endpoint: opts.Scheme + "://" + opts.Endpoint + opts.BaseURLPath,
@@ -217,7 +217,7 @@ func getTracesExporter(ctx context.Context, cfg otelcfg.TracesConfig, im imetric
 			Headers: convertHeaders(opts.Headers),
 		}
 		slog.Debug("getTracesExporter: confighttp.ClientConfig created", "endpoint", config.ClientConfig.Endpoint)
-		set := getTraceSettings(factory.Type())
+		set := getTraceSettings(factory.Type(), cfg.SDKLogLevel)
 		exp, err := factory.CreateTraces(ctx, set, config)
 		if err != nil {
 			slog.Error("can't create OTLP HTTP traces exporter", "error", err)
@@ -247,23 +247,7 @@ func getTracesExporter(ctx context.Context, cfg otelcfg.TracesConfig, im imetric
 		}
 		factory := otlpexporter.NewFactory()
 		config := factory.CreateDefaultConfig().(*otlpexporter.Config)
-		queueConfig := exporterhelper.NewDefaultQueueConfig()
-		queueConfig.Sizer = exporterhelper.RequestSizerTypeItems
-		batchCfg := exporterhelper.BatchConfig{
-			Sizer: queueConfig.Sizer,
-		}
-		if cfg.MaxQueueSize > 0 || cfg.BatchTimeout > 0 {
-			queueConfig.Enabled = true
-		}
-		if cfg.MaxQueueSize > 0 {
-			batchCfg.MaxSize = int64(cfg.MaxQueueSize)
-		}
-		if cfg.BatchTimeout > 0 {
-			batchCfg.FlushTimeout = cfg.BatchTimeout
-			batchCfg.MinSize = int64(cfg.MaxQueueSize)
-		}
-		queueConfig.Batch = configoptional.Some(batchCfg)
-		config.QueueConfig = queueConfig
+		config.QueueConfig = getQueueSettings(cfg)
 		config.RetryConfig = getRetrySettings(cfg)
 		config.ClientConfig = configgrpc.ClientConfig{
 			Endpoint: endpoint.String(),
@@ -273,13 +257,25 @@ func getTracesExporter(ctx context.Context, cfg otelcfg.TracesConfig, im imetric
 			},
 			Headers: convertHeaders(opts.Headers),
 		}
-		set := getTraceSettings(factory.Type())
+		set := getTraceSettings(factory.Type(), cfg.SDKLogLevel)
 		exp, err := factory.CreateTraces(ctx, set, config)
 		if err != nil {
 			return nil, err
 		}
 		exp = instrumentTracesExporter(im, exp)
 		return exp, nil
+	case otelcfg.ProtocolDebug:
+		slog.Debug("instantiating Debug TracesReporter", "protocol", proto)
+		factory := debugexporter.NewFactory()
+		config := factory.CreateDefaultConfig().(*debugexporter.Config)
+		config.UseInternalLogger = false
+		config.Verbosity = configtelemetry.LevelDetailed
+		set := getTraceSettings(factory.Type(), cfg.SDKLogLevel)
+		exp, err := factory.CreateTraces(ctx, set, config)
+		if err != nil {
+			return nil, err
+		}
+		return exp, nil
 	default:
 		slog.Error(fmt.Sprintf("invalid protocol value: %q. Accepted values are: %s, %s, %s",
 			proto, otelcfg.ProtocolGRPC, otelcfg.ProtocolHTTPJSON, otelcfg.ProtocolHTTPProtobuf))
@@ -287,11 +283,34 @@ func getTracesExporter(ctx context.Context, cfg otelcfg.TracesConfig, im imetric
 	}
 }
 
-func getTraceSettings(dataTypeMetrics component.Type) exporter.Settings {
+func createZapLoggerDev(sdkLogLevel string) *zap.Logger {
+	if sdkLogLevel == "" {
+		return zap.NewNop()
+	}
+
+	var level zapcore.Level
+	if err := level.UnmarshalText([]byte(sdkLogLevel)); err != nil {
+		slog.Error("unsupported trace exporter logger level", "error", err, "level", sdkLogLevel)
+		return zap.NewNop()
+	}
+
+	config := zap.NewDevelopmentConfig()
+	config.Level = zap.NewAtomicLevelAt(level)
+
+	logger, err := config.Build()
+	if err != nil {
+		slog.Error("unable to create trace exporter logger", "error", err)
+		return zap.NewNop()
+	}
+
+	return logger
+}
+
+func getTraceSettings(dataTypeMetrics component.Type, sdkLogLevel string) exporter.Settings {
 	traceProvider := tracenoop.NewTracerProvider()
 	meterProvider := metric.NewMeterProvider()
 	telemetrySettings := component.TelemetrySettings{
-		Logger:         zap.NewNop(),
+		Logger:         createZapLoggerDev(sdkLogLevel),
 		MeterProvider:  meterProvider,
 		TracerProvider: traceProvider,
 		Resource:       pcommon.NewResource(),
@@ -303,6 +322,29 @@ func getTraceSettings(dataTypeMetrics component.Type) exporter.Settings {
 	}
 }
 
+func getQueueSettings(cfg otelcfg.TracesConfig) configoptional.Optional[exporterhelper.QueueBatchConfig] {
+	if cfg.MaxQueueSize <= 0 && cfg.BatchTimeout <= 0 {
+		return configoptional.None[exporterhelper.QueueBatchConfig]()
+	}
+
+	queueConfig := exporterhelper.NewDefaultQueueConfig()
+	queueConfig.Sizer = exporterhelper.RequestSizerTypeItems
+	// Avoid continuously seeing "sending queue is full" errors in the standard output
+	queueConfig.BlockOnOverflow = true
+	batchCfg := exporterhelper.BatchConfig{
+		Sizer: queueConfig.Sizer,
+	}
+	if cfg.MaxQueueSize > 0 {
+		batchCfg.MaxSize = int64(cfg.MaxQueueSize)
+	}
+	if cfg.BatchTimeout > 0 {
+		batchCfg.FlushTimeout = cfg.BatchTimeout
+		batchCfg.MinSize = int64(cfg.MaxQueueSize)
+	}
+	queueConfig.Batch = configoptional.Some(batchCfg)
+	return configoptional.Some(queueConfig)
+}
+
 func getRetrySettings(cfg otelcfg.TracesConfig) configretry.BackOffConfig {
 	backOffCfg := configretry.NewDefaultBackOffConfig()
 	if cfg.BackOffInitialInterval > 0 {
@@ -318,9 +360,9 @@ func getRetrySettings(cfg otelcfg.TracesConfig) configretry.BackOffConfig {
 }
 
 func convertHeaders(headers map[string]string) configopaque.MapList {
-	opaqueHeaders := configopaque.MapList{}
+	opaqueHeaders := make(configopaque.MapList, 0, len(headers))
 	for key, value := range headers {
-		opaqueHeaders.Set(key, configopaque.String(value))
+		opaqueHeaders = append(opaqueHeaders, configopaque.Pair{Name: key, Value: configopaque.String(value)})
 	}
 	return opaqueHeaders
 }
