@@ -15,18 +15,18 @@ import (
 
 	"github.com/prometheus/client_golang/prometheus"
 
-	"go.opentelemetry.io/obi/pkg/app/request"
+	"go.opentelemetry.io/obi/pkg/appolly/app/request"
+	"go.opentelemetry.io/obi/pkg/appolly/app/svc"
+	"go.opentelemetry.io/obi/pkg/appolly/discover/exec"
 	"go.opentelemetry.io/obi/pkg/buildinfo"
-	"go.opentelemetry.io/obi/pkg/components/connector"
-	"go.opentelemetry.io/obi/pkg/components/exec"
-	"go.opentelemetry.io/obi/pkg/components/pipe/global"
-	"go.opentelemetry.io/obi/pkg/components/svc"
 	"go.opentelemetry.io/obi/pkg/export/attributes"
 	attr "go.opentelemetry.io/obi/pkg/export/attributes/names"
+	"go.opentelemetry.io/obi/pkg/export/connector"
 	"go.opentelemetry.io/obi/pkg/export/expire"
 	"go.opentelemetry.io/obi/pkg/export/instrumentations"
 	"go.opentelemetry.io/obi/pkg/export/otel"
 	"go.opentelemetry.io/obi/pkg/export/otel/otelcfg"
+	"go.opentelemetry.io/obi/pkg/pipe/global"
 	"go.opentelemetry.io/obi/pkg/pipe/msg"
 	"go.opentelemetry.io/obi/pkg/pipe/swarm"
 	"go.opentelemetry.io/obi/pkg/pipe/swarm/swarms"
@@ -114,7 +114,8 @@ type PrometheusConfig struct {
 
 	DisableBuildInfo bool `yaml:"disable_build_info" env:"OTEL_EBPF_PROMETHEUS_DISABLE_BUILD_INFO"`
 
-	// Features of metrics that are can be exported. Accepted values are "application" and "network".
+	// Features of metrics that can be exported. Accepted values: application, network, application_process,
+	// application_span, application_service_graph, ...
 	Features []string `yaml:"features" env:"OTEL_EBPF_PROMETHEUS_FEATURES" envSeparator:","`
 	// Allows configuration of which instrumentations should be enabled, e.g. http, grpc, sql...
 	Instrumentations []string `yaml:"instrumentations" env:"OTEL_EBPF_PROMETHEUS_INSTRUMENTATIONS" envSeparator:","`
@@ -204,8 +205,9 @@ type metricsReporter struct {
 	cfg                     *PrometheusConfig
 	extraMetadataLabels     []attr.Name
 	extraSpanMetadataLabels []attr.Name
-	input                   <-chan []request.Span
-	processEvents           <-chan exec.ProcessEvent
+
+	input         <-chan []request.Span
+	processEvents <-chan exec.ProcessEvent
 
 	beylaInfo              *Expirer[prometheus.Gauge]
 	httpDuration           *Expirer[prometheus.Histogram]
@@ -239,6 +241,7 @@ type metricsReporter struct {
 	attrGPUKernelBlockSize     []attributes.Field[*request.Span, string]
 	attrGPUMemoryCopies        []attributes.Field[*request.Span, string]
 	attrSvcGraph               []attributes.Field[*request.Span, string]
+	attrDNSLookupDuration      []attributes.Field[*request.Span, string]
 
 	// trace span metrics
 	spanMetricsLatency           *Expirer[prometheus.Histogram]
@@ -261,6 +264,9 @@ type metricsReporter struct {
 	gpuKernelBlockSize   *Expirer[prometheus.Histogram]
 	gpuMemoryCopySize    *Expirer[prometheus.Histogram]
 
+	// dns related metrics
+	dnsLookupDuration *Expirer[prometheus.Histogram]
+
 	promConnect *connector.PrometheusManager
 
 	clock   *expire.CachedClock
@@ -400,6 +406,13 @@ func newReporter(
 			attrsProvider.For(attributes.GPUMemoryCopies))
 	}
 
+	var attrDNSLookupDuration []attributes.Field[*request.Span, string]
+
+	if is.DNSEnabled() {
+		attrDNSLookupDuration = attributes.PrometheusGetters(attributeGetters,
+			attrsProvider.For(attributes.DNSLookupDuration))
+	}
+
 	if cfg.ServiceGraphMetricsEnabled() {
 		attrSvcGraph = attributes.PrometheusGetters(attributeGetters, []attr.Name{attr.Client, attr.ClientNamespace, attr.Server, attr.ServerNamespace, attr.Source})
 	}
@@ -440,6 +453,7 @@ func newReporter(
 		attrGPUKernelGridSize:      attrGPUKernelGridSize,
 		attrGPUKernelBlockSize:     attrGPUKernelBlockSize,
 		attrGPUMemoryCopies:        attrGPUMemoryCopies,
+		attrDNSLookupDuration:      attrDNSLookupDuration,
 		attrSvcGraph:               attrSvcGraph,
 		beylaInfo: NewExpirer[prometheus.Gauge](prometheus.NewGaugeVec(prometheus.GaugeOpts{
 			Name: attr.VendorPrefix + buildInfoSuffix,
@@ -682,6 +696,16 @@ func newReporter(
 				NativeHistogramMinResetDuration: defaultHistogramMinResetDuration,
 			}, labelNames(attrGPUMemoryCopies)).MetricVec, clock.Time, cfg.TTL)
 		}),
+		dnsLookupDuration: optionalHistogramProvider(is.DNSEnabled(), func() *Expirer[prometheus.Histogram] {
+			return NewExpirer[prometheus.Histogram](prometheus.NewHistogramVec(prometheus.HistogramOpts{
+				Name:                            attributes.DNSLookupDuration.Prom,
+				Help:                            "measures the time taken to perform a DNS lookup",
+				Buckets:                         cfg.Buckets.DurationHistogram,
+				NativeHistogramBucketFactor:     defaultHistogramBucketFactor,
+				NativeHistogramMaxBucketNumber:  defaultHistogramMaxBucketNumber,
+				NativeHistogramMinResetDuration: defaultHistogramMinResetDuration,
+			}, labelNames(attrDNSLookupDuration)).MetricVec, clock.Time, cfg.TTL)
+		}),
 	}
 
 	// testing aid
@@ -725,6 +749,10 @@ func newReporter(
 				mr.msgPublishDuration,
 			)
 		}
+
+		if is.DNSEnabled() {
+			registeredMetrics = append(registeredMetrics, mr.dnsLookupDuration)
+		}
 	}
 
 	if cfg.SpanMetricsEnabled() {
@@ -841,7 +869,7 @@ func (r *metricsReporter) otelMetricsObserved(span *request.Span) bool {
 }
 
 func (r *metricsReporter) otelSpanMetricsObserved(span *request.Span) bool {
-	return r.cfg.AnySpanMetricsEnabled() && !span.Service.ExportsOTelMetricsSpan()
+	return r.cfg.AnySpanMetricsEnabled() && !span.Service.ExportsOTelMetricsSpan() && !span.IsDNSSpan()
 }
 
 func (r *metricsReporter) otelSpanFiltered(span *request.Span) bool {
@@ -944,6 +972,12 @@ func (r *metricsReporter) observe(span *request.Span) {
 					labelValues(span, r.attrGPUMemoryCopies)...,
 				).Metric.Observe(float64(span.ContentLength))
 			}
+		case request.EventTypeDNS:
+			if r.is.DNSEnabled() {
+				r.dnsLookupDuration.WithLabelValues(
+					labelValues(span, r.attrDNSLookupDuration)...,
+				).Metric.Observe(duration)
+			}
 		}
 	}
 
