@@ -10,29 +10,36 @@ import (
 	"time"
 
 	"github.com/caarlos0/env/v9"
+	"github.com/go-playground/validator/v10"
 	"gopkg.in/yaml.v3"
 
-	"go.opentelemetry.io/obi/pkg/components/ebpf/tcmanager"
-	"go.opentelemetry.io/obi/pkg/components/imetrics"
-	"go.opentelemetry.io/obi/pkg/components/kube"
-	"go.opentelemetry.io/obi/pkg/components/traces"
+	"go.opentelemetry.io/obi/pkg/appolly/services"
 	"go.opentelemetry.io/obi/pkg/config"
+	"go.opentelemetry.io/obi/pkg/ebpf/tcmanager"
 	"go.opentelemetry.io/obi/pkg/export/attributes"
 	attr "go.opentelemetry.io/obi/pkg/export/attributes/names"
 	"go.opentelemetry.io/obi/pkg/export/debug"
+	"go.opentelemetry.io/obi/pkg/export/imetrics"
 	"go.opentelemetry.io/obi/pkg/export/instrumentations"
 	"go.opentelemetry.io/obi/pkg/export/otel"
 	"go.opentelemetry.io/obi/pkg/export/otel/otelcfg"
 	"go.opentelemetry.io/obi/pkg/export/prom"
 	"go.opentelemetry.io/obi/pkg/filter"
-	"go.opentelemetry.io/obi/pkg/kubeflags"
-	"go.opentelemetry.io/obi/pkg/services"
+	"go.opentelemetry.io/obi/pkg/kube"
+	"go.opentelemetry.io/obi/pkg/kube/kubeflags"
 	"go.opentelemetry.io/obi/pkg/transform"
 )
 
+// CustomValidations is a map of tag:function for custom validations
+type CustomValidations map[string]validator.Func
+
+const (
+	validationTagAgentIPIface = "agentIPIface"
+)
+
 const ReporterLRUSize = 256
 
-// Features that can be enabled in Beyla (can be at the same time): App O11y and/or Net O11y
+// Features that can be enabled in OBI (can be at the same time): App O11y and/or Net O11y
 type Feature uint
 
 const (
@@ -68,7 +75,8 @@ var DefaultConfig = Config{
 		BatchLength:               100,
 		BatchTimeout:              time.Second,
 		HTTPRequestTimeout:        0,
-		TCBackend:                 tcmanager.TCBackendAuto,
+		TCBackend:                 config.TCBackendAuto,
+		DNSRequestTimeout:         5 * time.Second,
 		ContextPropagationEnabled: false,
 		ContextPropagation:        config.ContextPropagationDisabled,
 		RedisDBCache: config.RedisDBCacheConfig{
@@ -85,6 +93,20 @@ var DefaultConfig = Config{
 		MongoRequestsCacheSize:              1024,
 		KafkaTopicUUIDCacheSize:             1024,
 		OverrideBPFLoopEnabled:              false,
+		PayloadExtraction: config.PayloadExtraction{
+			HTTP: config.HTTPConfig{
+				GraphQL: config.GraphQLConfig{
+					Enabled: false,
+				},
+				Elasticsearch: config.ElasticsearchConfig{
+					Enabled: false,
+				},
+				AWS: config.AWSConfig{
+					Enabled: false,
+				},
+			},
+		},
+		MaxTransactionTime: 5 * time.Minute,
 	},
 	NameResolver: &transform.NameResolverConfig{
 		Sources:  []string{"k8s"},
@@ -112,7 +134,13 @@ var DefaultConfig = Config{
 		BatchTimeout:      15 * time.Second,
 		ReportersCacheLen: ReporterLRUSize,
 		Instrumentations: []string{
-			instrumentations.InstrumentationALL,
+			instrumentations.InstrumentationHTTP,
+			instrumentations.InstrumentationGRPC,
+			instrumentations.InstrumentationSQL,
+			instrumentations.InstrumentationRedis,
+			instrumentations.InstrumentationKafka,
+			instrumentations.InstrumentationMongo,
+			// no traces for DNS and GPU by default
 		},
 	},
 	Prometheus: prom.PrometheusConfig{
@@ -135,7 +163,7 @@ var DefaultConfig = Config{
 		BpfMetricScrapeInterval: 15 * time.Second,
 	},
 	Attributes: Attributes{
-		InstanceID: traces.InstanceIDConfig{
+		InstanceID: config.InstanceIDConfig{
 			HostnameDNSResolution: true,
 		},
 		Kubernetes: transform.KubernetesDecorator{
@@ -153,10 +181,11 @@ var DefaultConfig = Config{
 		MetricSpanNameAggregationLimit: 100,
 	},
 	Routes: &transform.RoutesConfig{
-		Unmatch:      transform.UnmatchDefault,
-		WildcardChar: "*",
+		Unmatch:                   transform.UnmatchDefault,
+		WildcardChar:              "*",
+		MaxPathSegmentCardinality: 10,
 	},
-	NetworkFlows: defaultNetworkConfig,
+	NetworkFlows: DefaultNetworkConfig,
 	Discovery: services.DiscoveryConfig{
 		ExcludeOTelInstrumentedServices: true,
 		DefaultExcludeServices: services.RegexDefinitionCriteria{
@@ -178,6 +207,9 @@ var DefaultConfig = Config{
 		MinProcessAge:         5 * time.Second,
 		DefaultOtlpGRPCPort:   4317,
 		RouteHarvesterTimeout: 10 * time.Second,
+		RouteHarvestConfig: services.RouteHarvestingConfig{
+			JavaHarvestDelay: 60 * time.Second,
+		},
 	},
 	NodeJS: NodeJSConfig{
 		Enabled: true,
@@ -234,7 +266,7 @@ type Config struct {
 	ShutdownTimeout time.Duration `yaml:"shutdown_timeout" env:"OTEL_EBPF_SHUTDOWN_TIMEOUT"`
 
 	// Check for required system capabilities and bail if they are not
-	// present. If set to 'false', Beyla will still print a list of missing
+	// present. If set to 'false', OBI will still print a list of missing
 	// capabilities, but the execution will continue
 	EnforceSysCaps bool `yaml:"enforce_sys_caps" env:"OTEL_EBPF_ENFORCE_SYS_CAPS"`
 
@@ -262,7 +294,7 @@ const (
 // added to each span
 type Attributes struct {
 	Kubernetes           transform.KubernetesDecorator `yaml:"kubernetes"`
-	InstanceID           traces.InstanceIDConfig       `yaml:"instance_id"`
+	InstanceID           config.InstanceIDConfig       `yaml:"instance_id"`
 	Select               attributes.Selection          `yaml:"select"`
 	HostID               HostIDConfig                  `yaml:"host_id"`
 	ExtraGroupAttributes map[string][]attr.Name        `yaml:"extra_group_attributes"`
@@ -281,7 +313,7 @@ type Attributes struct {
 }
 
 type HostIDConfig struct {
-	// Override allows overriding the reported host.id in Beyla
+	// Override allows overriding the reported host.id in OBI
 	Override string `yaml:"override" env:"OTEL_EBPF_HOST_ID"`
 	// FetchTimeout specifies the timeout for trying to fetch the HostID from diverse Cloud Providers
 	FetchTimeout time.Duration `yaml:"fetch_timeout" env:"OTEL_EBPF_HOST_ID_FETCH_TIMEOUT"`
@@ -301,6 +333,21 @@ func (e ConfigError) Error() string {
 //
 //nolint:cyclop
 func (c *Config) Validate() error {
+	validate := validator.New(validator.WithRequiredStructEnabled())
+
+	// for future custom validations
+	customValidations := CustomValidations{
+		validationTagAgentIPIface: ValidateAgentIPIface,
+	}
+
+	if err := registerCustomValidations(validate, customValidations); err != nil {
+		return ConfigError("error registering custom validations: " + err.Error())
+	}
+
+	if err := validate.Struct(c); err != nil {
+		return ConfigError(err.Error())
+	}
+
 	if err := c.Discovery.Validate(); err != nil {
 		return ConfigError(err.Error())
 	}
@@ -312,25 +359,6 @@ func (c *Config) Validate() error {
 			"Enable Prometheus export features using the 'OTEL_EBPF_PROMETHEUS_FEATURES=network,application' environment variable " +
 			"or 'prometheus_export: { features: [network,application] }' in the YAML configuration file.")
 	}
-	if c.EBPF.BatchLength == 0 {
-		return ConfigError("OTEL_EBPF_BPF_BATCH_LENGTH must be at least 1")
-	}
-	if !c.EBPF.TCBackend.Valid() {
-		return ConfigError("Invalid OTEL_EBPF_BPF_TC_BACKEND value")
-	}
-
-	// remove after deleting ContextPropagationEnabled
-	if c.EBPF.ContextPropagationEnabled && c.EBPF.ContextPropagation != config.ContextPropagationDisabled {
-		return ConfigError("context_propagation_enabled and context_propagation are mutually exclusive")
-	}
-
-	// TODO deprecated (REMOVE)
-	// remove after deleting ContextPropagationEnabled
-	if c.EBPF.ContextPropagationEnabled {
-		slog.Warn("DEPRECATION NOTICE: 'context_propagation_enabled' configuration option has been " +
-			"deprecated and will be removed in the future - use 'context_propagation' instead")
-		c.EBPF.ContextPropagation = config.ContextPropagationAll
-	}
 
 	if c.willUseTC() {
 		if err := tcmanager.EnsureCiliumCompatibility(c.EBPF.TCBackend); err != nil {
@@ -379,9 +407,8 @@ func (c *Config) Validate() error {
 		return ConfigError("you can't enable OTEL internal metrics without enabling OTEL metrics")
 	}
 
-	if err := c.EBPF.Validate(); err != nil {
-		return ConfigError(err.Error())
-	}
+	// TODO deprecated (REMOVE)
+	c.EBPF.IsContextPropagationEnabled()
 
 	return nil
 }
@@ -402,7 +429,7 @@ func (c *Config) willUseTC() bool {
 		(c.Enabled(FeatureNetO11y) && c.NetworkFlows.Source == EbpfSourceTC)
 }
 
-// Enabled checks if a given Beyla feature is enabled according to the global configuration
+// Enabled checks if a given OBI feature is enabled according to the global configuration
 func (c *Config) Enabled(feature Feature) bool {
 	switch feature {
 	case FeatureNetO11y:
@@ -422,7 +449,7 @@ func (c *Config) SpanMetricsEnabledForTraces() bool {
 }
 
 // ExternalLogger sets the logging capabilities of OBI.
-// Used for integrating Beyla with an external logging system (for example Alloy)
+// Used for integrating OBI with an external logging system (for example Alloy)
 // TODO: maybe this method has too many responsibilities, as it affects the global logger.
 func (c *Config) ExternalLogger(handler slog.Handler, debugMode bool) {
 	slog.SetDefault(slog.New(handler))
@@ -459,3 +486,12 @@ func LoadConfig(file io.Reader) (*Config, error) {
 
 	return &cfg, nil
 }
+
+func registerCustomValidations(validate *validator.Validate, customValidations CustomValidations) error {
+	for k, v := range customValidations {
+		if err := validate.RegisterValidation(k, v); err != nil {
+			return fmt.Errorf("cannot add validation with the given tag %q: %w", k, err)
+		}
+	}
+	return nil
+}
