@@ -20,7 +20,7 @@ import (
 	"go.opentelemetry.io/collector/pdata/pmetric"
 	"go.opentelemetry.io/collector/pdata/ptrace"
 	"go.opentelemetry.io/collector/processor"
-	semconv "go.opentelemetry.io/otel/semconv/v1.25.0"
+	conventions "go.opentelemetry.io/otel/semconv/v1.25.0"
 	"go.uber.org/zap"
 
 	"github.com/open-telemetry/opentelemetry-collector-contrib/connector/servicegraphconnector/internal/metadata"
@@ -46,10 +46,10 @@ var (
 	}
 
 	defaultPeerAttributes = []string{
-		string(semconv.PeerServiceKey), string(semconv.DBNameKey), string(semconv.DBSystemKey),
+		string(conventions.PeerServiceKey), string(conventions.DBNameKey), string(conventions.DBSystemKey),
 	}
 
-	defaultDatabaseNameAttributes = []string{string(semconv.DBNameKey)}
+	defaultDatabaseNameAttributes = []string{string(conventions.DBNameKey)}
 
 	defaultMetricsFlushInterval = 60 * time.Second // 1 DPM
 )
