@@ -5,13 +5,13 @@ package servicegraphconnector // import "github.com/open-telemetry/opentelemetry
 
 import (
 	"go.opentelemetry.io/collector/pdata/pcommon"
-	semconv "go.opentelemetry.io/otel/semconv/v1.25.0"
+	conventions "go.opentelemetry.io/otel/semconv/v1.37.0"
 
 	"github.com/open-telemetry/opentelemetry-collector-contrib/internal/pdatautil"
 )
 
 func findServiceName(attributes pcommon.Map) (string, bool) {
-	return pdatautil.GetAttributeValue(string(semconv.ServiceNameKey), attributes)
+	return pdatautil.GetAttributeValue(string(conventions.ServiceNameKey), attributes)
 }
 
 func getFirstMatchingValue(keys []string, attributes ...pcommon.Map) (string, bool) {
