@@ -6,11 +6,11 @@ package metrics // import "github.com/open-telemetry/opentelemetry-collector-con
 import (
 	"context"
 
+	"github.com/DataDog/datadog-agent/pkg/opentelemetry-mapping-go/otlp/attributes"
+	"github.com/DataDog/datadog-agent/pkg/opentelemetry-mapping-go/otlp/metrics"
+	"github.com/DataDog/datadog-agent/pkg/util/quantile"
 	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
 	"github.com/DataDog/datadog-api-client-go/v2/api/datadogV2"
-	"github.com/DataDog/opentelemetry-mapping-go/pkg/otlp/attributes"
-	"github.com/DataDog/opentelemetry-mapping-go/pkg/otlp/metrics"
-	"github.com/DataDog/opentelemetry-mapping-go/pkg/quantile"
 	"go.opentelemetry.io/collector/component"
 
 	"github.com/open-telemetry/opentelemetry-collector-contrib/exporter/datadogexporter/internal/metrics/sketches"
@@ -52,7 +52,7 @@ func (*Consumer) toDataType(dt metrics.DataType) (out datadogV2.MetricIntakeType
 		out = datadogV2.METRICINTAKETYPE_GAUGE
 	}
 
-	return
+	return out
 }
 
 // runningMetrics gets the running metrics for the exporter.
@@ -81,7 +81,7 @@ func (c *Consumer) runningMetrics(timestamp uint64, buildInfo component.BuildInf
 		series = append(series, runningMetric...)
 	}
 
-	return
+	return series
 }
 
 // All gets all metrics (consumed metrics and running metrics).
@@ -106,10 +106,11 @@ func (c *Consumer) ConsumeTimeSeries(
 	dims *metrics.Dimensions,
 	typ metrics.DataType,
 	timestamp uint64,
+	interval int64,
 	value float64,
 ) {
 	dt := c.toDataType(typ)
-	met := NewMetric(dims.Name(), dt, timestamp, value, dims.Tags())
+	met := NewMetric(dims.Name(), dt, timestamp, interval, value, dims.Tags())
 	met.SetResources([]datadogV2.MetricResource{
 		{
 			Name: datadog.PtrString(dims.Host()),
@@ -124,13 +125,14 @@ func (c *Consumer) ConsumeSketch(
 	_ context.Context,
 	dims *metrics.Dimensions,
 	timestamp uint64,
+	interval int64,
 	sketch *quantile.Sketch,
 ) {
 	c.sl = append(c.sl, sketches.SketchSeries{
 		Name:     dims.Name(),
 		Tags:     dims.Tags(),
 		Host:     dims.Host(),
-		Interval: 1,
+		Interval: interval,
 		Points: []sketches.SketchPoint{{
 			Ts:     int64(timestamp / 1e9),
 			Sketch: sketch,
