@@ -8,6 +8,7 @@ import (
 
 	"go.opentelemetry.io/collector/component"
 	"go.opentelemetry.io/collector/config/confighttp"
+	"go.opentelemetry.io/collector/config/configoptional"
 	"go.opentelemetry.io/collector/config/configretry"
 	"go.opentelemetry.io/collector/confmap"
 	"go.opentelemetry.io/collector/exporter/exporterhelper"
@@ -17,8 +18,8 @@ import (
 // Config defines configuration settings for the Faro exporter.
 type Config struct {
 	confighttp.ClientConfig `mapstructure:",squash"`
-	QueueConfig             exporterhelper.QueueBatchConfig `mapstructure:"sending_queue"`
-	RetryConfig             configretry.BackOffConfig       `mapstructure:"retry_on_failure"`
+	QueueConfig             configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
+	RetryConfig             configretry.BackOffConfig                                `mapstructure:"retry_on_failure"`
 }
 
 var (
