@@ -7,11 +7,13 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"maps"
 	"net/http"
 
 	"go.opentelemetry.io/collector/component"
 	"go.opentelemetry.io/collector/extension"
 	"go.opentelemetry.io/collector/extension/extensionauth"
+	"go.opentelemetry.io/collector/extension/extensioncapabilities"
 	"go.uber.org/zap"
 	"google.golang.org/grpc/credentials"
 
@@ -25,27 +27,98 @@ type header struct {
 }
 
 var (
-	_ extension.Extension      = (*headerSetterExtension)(nil)
-	_ extensionauth.HTTPClient = (*headerSetterExtension)(nil)
-	_ extensionauth.GRPCClient = (*headerSetterExtension)(nil)
+	_ extension.Extension             = (*headerSetterExtension)(nil)
+	_ extensionauth.HTTPClient        = (*headerSetterExtension)(nil)
+	_ extensionauth.GRPCClient        = (*headerSetterExtension)(nil)
+	_ extensioncapabilities.Dependent = (*headerSetterExtension)(nil)
 )
 
 type headerSetterExtension struct {
 	component.StartFunc
 	component.ShutdownFunc
 
-	headers []header
+	headers        []header
+	additionalAuth *component.ID
+	host           component.Host
+}
+
+// Dependencies implements extensioncapabilities.Dependent.
+func (h *headerSetterExtension) Dependencies() []component.ID {
+	if h.additionalAuth == nil {
+		return nil
+	}
+	return []component.ID{*h.additionalAuth}
+}
+
+// Start stores the host for later use in getting the additional auth extension.
+func (h *headerSetterExtension) Start(_ context.Context, host component.Host) error {
+	h.host = host
+	return nil
+}
+
+// getAdditionalAuthExtension retrieves the configured additional auth extension if present.
+// Returns nil if no additional auth is configured.
+func (h *headerSetterExtension) getAdditionalAuthExtension() (component.Component, error) {
+	if h.additionalAuth == nil || h.host == nil {
+		return nil, nil
+	}
+
+	ext := h.host.GetExtensions()[*h.additionalAuth]
+	if ext == nil {
+		return nil, fmt.Errorf("auth extension %v not found", h.additionalAuth)
+	}
+
+	return ext, nil
 }
 
 // PerRPCCredentials implements extensionauth.GRPCClient.
 func (h *headerSetterExtension) PerRPCCredentials() (credentials.PerRPCCredentials, error) {
-	return &headersPerRPC{headers: h.headers}, nil
+	var baseCredentials credentials.PerRPCCredentials
+
+	// If additional_auth is configured, chain with it first
+	ext, err := h.getAdditionalAuthExtension()
+	if err != nil {
+		return nil, err
+	}
+
+	if ext != nil {
+		if grpcClient, ok := ext.(extensionauth.GRPCClient); ok {
+			baseCredentials, err = grpcClient.PerRPCCredentials()
+			if err != nil {
+				return nil, fmt.Errorf("failed to get PerRPCCredentials from %v: %w", h.additionalAuth, err)
+			}
+		}
+	}
+
+	return &headersPerRPC{
+		headers:         h.headers,
+		baseCredentials: baseCredentials,
+	}, nil
 }
 
 // RoundTripper implements extensionauth.HTTPClient.
 func (h *headerSetterExtension) RoundTripper(base http.RoundTripper) (http.RoundTripper, error) {
+	// If additional_auth is configured, chain with it first
+	baseRT := base
+
+	ext, err := h.getAdditionalAuthExtension()
+	if err != nil {
+		return nil, err
+	}
+
+	if ext != nil {
+		// Check if it implements HTTPClient
+		if httpClient, ok := ext.(extensionauth.HTTPClient); ok {
+			baseRT, err = httpClient.RoundTripper(base)
+			if err != nil {
+				return nil, fmt.Errorf("failed to get RoundTripper from %v: %w", h.additionalAuth, err)
+			}
+		}
+	}
+
+	// Now wrap with our headers
 	return &headersRoundTripper{
-		base:    base,
+		base:    baseRT,
 		headers: h.headers,
 	}, nil
 }
@@ -101,21 +174,44 @@ func newHeadersSetterExtension(cfg *Config, logger *zap.Logger) (*headerSetterEx
 		headers = append(headers, header{action: a, source: s})
 	}
 
-	return &headerSetterExtension{headers: headers}, nil
+	ext := &headerSetterExtension{
+		headers:        headers,
+		additionalAuth: cfg.AdditionalAuth,
+	}
+
+	// Enable Start method if additional_auth is configured
+	if cfg.AdditionalAuth != nil {
+		ext.StartFunc = ext.Start
+	}
+
+	return ext, nil
 }
 
 // headersPerRPC is a gRPC credentials.PerRPCCredentials implementation sets
 // headers with values extracted from provided sources.
 type headersPerRPC struct {
-	headers []header
+	headers         []header
+	baseCredentials credentials.PerRPCCredentials
 }
 
 // GetRequestMetadata returns the request metadata to be used with the RPC.
 func (h *headersPerRPC) GetRequestMetadata(
 	ctx context.Context,
-	_ ...string,
+	uri ...string,
 ) (map[string]string, error) {
-	metadata := make(map[string]string, len(h.headers))
+	// Start with base credentials if available
+	metadata := make(map[string]string)
+
+	if h.baseCredentials != nil {
+		baseMetadata, err := h.baseCredentials.GetRequestMetadata(ctx, uri...)
+		if err != nil {
+			return nil, err
+		}
+		// Copy base metadata
+		maps.Copy(metadata, baseMetadata)
+	}
+
+	// Now apply our headers on top
 	for _, header := range h.headers {
 		value, err := header.source.Get(ctx)
 		if err != nil {
@@ -126,10 +222,12 @@ func (h *headersPerRPC) GetRequestMetadata(
 	return metadata, nil
 }
 
-// RequireTransportSecurity always returns false for this implementation.
-// The header setter is not sending auth data, so it should not require
-// a transport security.
-func (*headersPerRPC) RequireTransportSecurity() bool {
+// RequireTransportSecurity returns whether transport security is required.
+// If chained with another auth extension, delegate to it.
+func (h *headersPerRPC) RequireTransportSecurity() bool {
+	if h.baseCredentials != nil {
+		return h.baseCredentials.RequireTransportSecurity()
+	}
 	return false
 }
 
