@@ -56,7 +56,7 @@ func NewHTTP(telemetry component.TelemetrySettings, settings confighttp.ServerCo
 
 func (h *SamplingHTTPServer) Start(ctx context.Context, host component.Host) error {
 	var err error
-	h.srv, err = h.settings.ToServer(ctx, host, h.telemetry, h.mux)
+	h.srv, err = h.settings.ToServer(ctx, host.GetExtensions(), h.telemetry, h.mux)
 	if err != nil {
 		return err
 	}
