@@ -3,10 +3,10 @@
 
 package ottlfuncs // import "github.com/open-telemetry/opentelemetry-collector-contrib/pkg/ottl/ottlfuncs"
 import (
+	"context"
 	"errors"
 
 	"go.opentelemetry.io/collector/pdata/pcommon"
-	"golang.org/x/net/context"
 
 	"github.com/open-telemetry/opentelemetry-collector-contrib/pkg/ottl"
 )
