@@ -20,7 +20,7 @@ import (
 	"go.opentelemetry.io/collector/pdata/ptrace"
 	"go.opentelemetry.io/otel"
 	"go.opentelemetry.io/otel/attribute"
-	semconv "go.opentelemetry.io/otel/semconv/v1.21.0"
+	conventions "go.opentelemetry.io/otel/semconv/v1.21.0"
 	"go.uber.org/multierr"
 )
 
@@ -373,16 +373,16 @@ func parseIntegrationsFromString(integrationsString string) []faroTypes.SDKInteg
 func extractAppFromKeyVal(kv map[string]string, rl pcommon.Resource) faroTypes.App {
 	var app faroTypes.App
 	rl.Attributes().Range(func(key string, val pcommon.Value) bool {
-		if key == string(semconv.ServiceNameKey) {
+		if key == string(conventions.ServiceNameKey) {
 			app.Name = val.Str()
 		}
-		if key == string(semconv.ServiceNamespaceKey) {
+		if key == string(conventions.ServiceNamespaceKey) {
 			app.Namespace = val.Str()
 		}
-		if key == string(semconv.ServiceVersionKey) {
+		if key == string(conventions.ServiceVersionKey) {
 			app.Version = val.Str()
 		}
-		if key == string(semconv.DeploymentEnvironmentKey) {
+		if key == string(conventions.DeploymentEnvironmentKey) {
 			app.Environment = val.Str()
 		}
 		// force the app name stored in resource attribute service.name
