@@ -7,7 +7,6 @@ import (
 	"context"
 	"fmt"
 
-	"go.opentelemetry.io/collector/pdata/pcommon"
 	"go.opentelemetry.io/collector/pdata/pmetric"
 	"go.opentelemetry.io/collector/pipeline"
 	"go.opentelemetry.io/collector/processor"
@@ -27,9 +26,9 @@ import (
 )
 
 type filterMetricProcessor struct {
-	skipResourceExpr  expr.BoolExpr[ottlresource.TransformContext]
-	skipMetricExpr    expr.BoolExpr[ottlmetric.TransformContext]
-	skipDataPointExpr expr.BoolExpr[ottldatapoint.TransformContext]
+	skipResourceExpr  expr.BoolExpr[*ottlresource.TransformContext]
+	skipMetricExpr    expr.BoolExpr[*ottlmetric.TransformContext]
+	skipDataPointExpr expr.BoolExpr[*ottldatapoint.TransformContext]
 	telemetry         *filterTelemetry
 	logger            *zap.Logger
 }
@@ -128,9 +127,10 @@ func (fmp *filterMetricProcessor) processMetrics(ctx context.Context, md pmetric
 
 	var errors error
 	md.ResourceMetrics().RemoveIf(func(rm pmetric.ResourceMetrics) bool {
-		resource := rm.Resource()
 		if fmp.skipResourceExpr != nil {
-			skip, err := fmp.skipResourceExpr.Eval(ctx, ottlresource.NewTransformContext(resource, rm))
+			tCtx := ottlresource.NewTransformContextPtr(rm.Resource(), rm)
+			skip, err := fmp.skipResourceExpr.Eval(ctx, tCtx)
+			tCtx.Close()
 			if err != nil {
 				errors = multierr.Append(errors, err)
 				return false
@@ -143,10 +143,11 @@ func (fmp *filterMetricProcessor) processMetrics(ctx context.Context, md pmetric
 			return rm.ScopeMetrics().Len() == 0
 		}
 		rm.ScopeMetrics().RemoveIf(func(smetrics pmetric.ScopeMetrics) bool {
-			scope := smetrics.Scope()
 			smetrics.Metrics().RemoveIf(func(metric pmetric.Metric) bool {
 				if fmp.skipMetricExpr != nil {
-					skip, err := fmp.skipMetricExpr.Eval(ctx, ottlmetric.NewTransformContext(metric, smetrics.Metrics(), scope, resource, smetrics, rm))
+					tCtx := ottlmetric.NewTransformContextPtr(rm, smetrics, metric)
+					skip, err := fmp.skipMetricExpr.Eval(ctx, tCtx)
+					tCtx.Close()
 					if err != nil {
 						errors = multierr.Append(errors, err)
 						return false
@@ -159,19 +160,19 @@ func (fmp *filterMetricProcessor) processMetrics(ctx context.Context, md pmetric
 					//exhaustive:enforce
 					switch metric.Type() {
 					case pmetric.MetricTypeSum:
-						errors = multierr.Append(errors, fmp.handleNumberDataPoints(ctx, metric.Sum().DataPoints(), metric, smetrics.Metrics(), scope, resource))
+						errors = multierr.Append(errors, fmp.handleNumberDataPoints(ctx, rm, smetrics, metric, metric.Sum().DataPoints()))
 						return metric.Sum().DataPoints().Len() == 0
 					case pmetric.MetricTypeGauge:
-						errors = multierr.Append(errors, fmp.handleNumberDataPoints(ctx, metric.Gauge().DataPoints(), metric, smetrics.Metrics(), scope, resource))
+						errors = multierr.Append(errors, fmp.handleNumberDataPoints(ctx, rm, smetrics, metric, metric.Gauge().DataPoints()))
 						return metric.Gauge().DataPoints().Len() == 0
 					case pmetric.MetricTypeHistogram:
-						errors = multierr.Append(errors, fmp.handleHistogramDataPoints(ctx, metric.Histogram().DataPoints(), metric, smetrics.Metrics(), scope, resource))
+						errors = multierr.Append(errors, fmp.handleHistogramDataPoints(ctx, rm, smetrics, metric, metric.Histogram().DataPoints()))
 						return metric.Histogram().DataPoints().Len() == 0
 					case pmetric.MetricTypeExponentialHistogram:
-						errors = multierr.Append(errors, fmp.handleExponentialHistogramDataPoints(ctx, metric.ExponentialHistogram().DataPoints(), metric, smetrics.Metrics(), scope, resource))
+						errors = multierr.Append(errors, fmp.handleExponentialHistogramDataPoints(ctx, rm, smetrics, metric, metric.ExponentialHistogram().DataPoints()))
 						return metric.ExponentialHistogram().DataPoints().Len() == 0
 					case pmetric.MetricTypeSummary:
-						errors = multierr.Append(errors, fmp.handleSummaryDataPoints(ctx, metric.Summary().DataPoints(), metric, smetrics.Metrics(), scope, resource))
+						errors = multierr.Append(errors, fmp.handleSummaryDataPoints(ctx, rm, smetrics, metric, metric.Summary().DataPoints()))
 						return metric.Summary().DataPoints().Len() == 0
 					default:
 						return false
@@ -197,7 +198,7 @@ func (fmp *filterMetricProcessor) processMetrics(ctx context.Context, md pmetric
 	return md, nil
 }
 
-func newSkipResExpr(include, exclude *filterconfig.MetricMatchProperties) (expr.BoolExpr[ottlresource.TransformContext], error) {
+func newSkipResExpr(include, exclude *filterconfig.MetricMatchProperties) (expr.BoolExpr[*ottlresource.TransformContext], error) {
 	if filtermetric.UseOTTLBridge.IsEnabled() {
 		mp := filterconfig.MatchConfig{}
 
@@ -224,7 +225,7 @@ func newSkipResExpr(include, exclude *filterconfig.MetricMatchProperties) (expr.
 		return filterottl.NewResourceSkipExprBridge(&mp)
 	}
 
-	var matchers []expr.BoolExpr[ottlresource.TransformContext]
+	var matchers []expr.BoolExpr[*ottlresource.TransformContext]
 	inclExpr, err := newResExpr(include)
 	if err != nil {
 		return nil, err
@@ -244,11 +245,11 @@ func newSkipResExpr(include, exclude *filterconfig.MetricMatchProperties) (expr.
 
 type resExpr filtermatcher.AttributesMatcher
 
-func (r resExpr) Eval(_ context.Context, tCtx ottlresource.TransformContext) (bool, error) {
+func (r resExpr) Eval(_ context.Context, tCtx *ottlresource.TransformContext) (bool, error) {
 	return filtermatcher.AttributesMatcher(r).Match(tCtx.GetResource().Attributes()), nil
 }
 
-func newResExpr(mp *filterconfig.MetricMatchProperties) (expr.BoolExpr[ottlresource.TransformContext], error) {
+func newResExpr(mp *filterconfig.MetricMatchProperties) (expr.BoolExpr[*ottlresource.TransformContext], error) {
 	if mp == nil {
 		return nil, nil
 	}
@@ -268,10 +269,12 @@ func newResExpr(mp *filterconfig.MetricMatchProperties) (expr.BoolExpr[ottlresou
 	return resExpr(attributeMatcher), nil
 }
 
-func (fmp *filterMetricProcessor) handleNumberDataPoints(ctx context.Context, dps pmetric.NumberDataPointSlice, metric pmetric.Metric, metrics pmetric.MetricSlice, is pcommon.InstrumentationScope, resource pcommon.Resource) error {
+func (fmp *filterMetricProcessor) handleNumberDataPoints(ctx context.Context, rm pmetric.ResourceMetrics, sm pmetric.ScopeMetrics, m pmetric.Metric, dps pmetric.NumberDataPointSlice) error {
 	var errors error
-	dps.RemoveIf(func(datapoint pmetric.NumberDataPoint) bool {
-		skip, err := fmp.skipDataPointExpr.Eval(ctx, ottldatapoint.NewTransformContext(datapoint, metric, metrics, is, resource, pmetric.NewScopeMetrics(), pmetric.NewResourceMetrics()))
+	dps.RemoveIf(func(dp pmetric.NumberDataPoint) bool {
+		tCtx := ottldatapoint.NewTransformContextPtr(rm, sm, m, dp)
+		defer tCtx.Close()
+		skip, err := fmp.skipDataPointExpr.Eval(ctx, tCtx)
 		if err != nil {
 			errors = multierr.Append(errors, err)
 			return false
@@ -281,10 +284,12 @@ func (fmp *filterMetricProcessor) handleNumberDataPoints(ctx context.Context, dp
 	return errors
 }
 
-func (fmp *filterMetricProcessor) handleHistogramDataPoints(ctx context.Context, dps pmetric.HistogramDataPointSlice, metric pmetric.Metric, metrics pmetric.MetricSlice, is pcommon.InstrumentationScope, resource pcommon.Resource) error {
+func (fmp *filterMetricProcessor) handleHistogramDataPoints(ctx context.Context, rm pmetric.ResourceMetrics, sm pmetric.ScopeMetrics, m pmetric.Metric, dps pmetric.HistogramDataPointSlice) error {
 	var errors error
-	dps.RemoveIf(func(datapoint pmetric.HistogramDataPoint) bool {
-		skip, err := fmp.skipDataPointExpr.Eval(ctx, ottldatapoint.NewTransformContext(datapoint, metric, metrics, is, resource, pmetric.NewScopeMetrics(), pmetric.NewResourceMetrics()))
+	dps.RemoveIf(func(dp pmetric.HistogramDataPoint) bool {
+		tCtx := ottldatapoint.NewTransformContextPtr(rm, sm, m, dp)
+		defer tCtx.Close()
+		skip, err := fmp.skipDataPointExpr.Eval(ctx, tCtx)
 		if err != nil {
 			errors = multierr.Append(errors, err)
 			return false
@@ -294,10 +299,12 @@ func (fmp *filterMetricProcessor) handleHistogramDataPoints(ctx context.Context,
 	return errors
 }
 
-func (fmp *filterMetricProcessor) handleExponentialHistogramDataPoints(ctx context.Context, dps pmetric.ExponentialHistogramDataPointSlice, metric pmetric.Metric, metrics pmetric.MetricSlice, is pcommon.InstrumentationScope, resource pcommon.Resource) error {
+func (fmp *filterMetricProcessor) handleExponentialHistogramDataPoints(ctx context.Context, rm pmetric.ResourceMetrics, sm pmetric.ScopeMetrics, m pmetric.Metric, dps pmetric.ExponentialHistogramDataPointSlice) error {
 	var errors error
-	dps.RemoveIf(func(datapoint pmetric.ExponentialHistogramDataPoint) bool {
-		skip, err := fmp.skipDataPointExpr.Eval(ctx, ottldatapoint.NewTransformContext(datapoint, metric, metrics, is, resource, pmetric.NewScopeMetrics(), pmetric.NewResourceMetrics()))
+	dps.RemoveIf(func(dp pmetric.ExponentialHistogramDataPoint) bool {
+		tCtx := ottldatapoint.NewTransformContextPtr(rm, sm, m, dp)
+		defer tCtx.Close()
+		skip, err := fmp.skipDataPointExpr.Eval(ctx, tCtx)
 		if err != nil {
 			errors = multierr.Append(errors, err)
 			return false
@@ -307,10 +314,12 @@ func (fmp *filterMetricProcessor) handleExponentialHistogramDataPoints(ctx conte
 	return errors
 }
 
-func (fmp *filterMetricProcessor) handleSummaryDataPoints(ctx context.Context, dps pmetric.SummaryDataPointSlice, metric pmetric.Metric, metrics pmetric.MetricSlice, is pcommon.InstrumentationScope, resource pcommon.Resource) error {
+func (fmp *filterMetricProcessor) handleSummaryDataPoints(ctx context.Context, rm pmetric.ResourceMetrics, sm pmetric.ScopeMetrics, m pmetric.Metric, dps pmetric.SummaryDataPointSlice) error {
 	var errors error
-	dps.RemoveIf(func(datapoint pmetric.SummaryDataPoint) bool {
-		skip, err := fmp.skipDataPointExpr.Eval(ctx, ottldatapoint.NewTransformContext(datapoint, metric, metrics, is, resource, pmetric.NewScopeMetrics(), pmetric.NewResourceMetrics()))
+	dps.RemoveIf(func(dp pmetric.SummaryDataPoint) bool {
+		tCtx := ottldatapoint.NewTransformContextPtr(rm, sm, m, dp)
+		defer tCtx.Close()
+		skip, err := fmp.skipDataPointExpr.Eval(ctx, tCtx)
 		if err != nil {
 			errors = multierr.Append(errors, err)
 			return false
