@@ -4,6 +4,7 @@
 package kube // import "github.com/open-telemetry/opentelemetry-collector-contrib/processor/k8sattributesprocessor/internal/kube"
 
 import (
+	"context"
 	"sync"
 	"time"
 
@@ -43,6 +44,10 @@ func (f *FakeInformer) AddEventHandlerWithResyncPeriod(_ cache.ResourceEventHand
 	return f, nil
 }
 
+func (f *FakeInformer) AddEventHandlerWithOptions(cache.ResourceEventHandler, cache.HandlerOptions) (cache.ResourceEventHandlerRegistration, error) {
+	return f, nil
+}
+
 func (*FakeInformer) RemoveEventHandler(cache.ResourceEventHandlerRegistration) error {
 	return nil
 }
@@ -134,6 +139,10 @@ func (c *FakeController) Run(stopCh <-chan struct{}) {
 	c.Unlock()
 }
 
+func (c *FakeController) RunWithContext(ctx context.Context) {
+	c.Run(ctx.Done())
+}
+
 func (c *FakeController) HasStopped() bool {
 	c.Lock()
 	defer c.Unlock()
@@ -148,6 +157,10 @@ func (*FakeInformer) SetWatchErrorHandler(cache.WatchErrorHandler) error {
 	return nil
 }
 
+func (*FakeInformer) SetWatchErrorHandlerWithContext(cache.WatchErrorHandlerWithContext) error {
+	return nil
+}
+
 type NoOpInformer struct {
 	*NoOpController
 }
@@ -160,15 +173,6 @@ func NewNoOpInformer(
 	}
 }
 
-func NewNoOpWorkloadInformer(
-	_ kubernetes.Interface,
-	_ string,
-) cache.SharedInformer {
-	return &NoOpInformer{
-		NoOpController: &NoOpController{},
-	}
-}
-
 func (f *NoOpInformer) AddEventHandler(handler cache.ResourceEventHandler) (cache.ResourceEventHandlerRegistration, error) {
 	return f.AddEventHandlerWithResyncPeriod(handler, time.Second)
 }
@@ -177,6 +181,10 @@ func (f *NoOpInformer) AddEventHandlerWithResyncPeriod(cache.ResourceEventHandle
 	return f, nil
 }
 
+func (f *NoOpInformer) AddEventHandlerWithOptions(cache.ResourceEventHandler, cache.HandlerOptions) (cache.ResourceEventHandlerRegistration, error) {
+	return f, nil
+}
+
 func (*NoOpInformer) RemoveEventHandler(cache.ResourceEventHandlerRegistration) error {
 	return nil
 }
@@ -204,6 +212,10 @@ func (c *NoOpController) Run(stopCh <-chan struct{}) {
 	}()
 }
 
+func (c *NoOpController) RunWithContext(ctx context.Context) {
+	c.Run(ctx.Done())
+}
+
 func (c *NoOpController) IsStopped() bool {
 	return c.hasStopped
 }
@@ -219,3 +231,7 @@ func (*NoOpController) LastSyncResourceVersion() string {
 func (*NoOpController) SetWatchErrorHandler(cache.WatchErrorHandler) error {
 	return nil
 }
+
+func (*NoOpController) SetWatchErrorHandlerWithContext(cache.WatchErrorHandlerWithContext) error {
+	return nil
+}
