@@ -35,8 +35,6 @@ func NewLatency(settings component.TelemetrySettings, thresholdMs, upperThreshol
 func (l *latency) Evaluate(_ context.Context, _ pcommon.TraceID, traceData *samplingpolicy.TraceData) (samplingpolicy.Decision, error) {
 	l.logger.Debug("Evaluating spans in latency filter")
 
-	traceData.Lock()
-	defer traceData.Unlock()
 	batches := traceData.ReceivedBatches
 
 	var minTime pcommon.Timestamp
