@@ -19,8 +19,8 @@ import (
 )
 
 type ottlConditionFilter struct {
-	sampleSpanExpr      *ottl.ConditionSequence[ottlspan.TransformContext]
-	sampleSpanEventExpr *ottl.ConditionSequence[ottlspanevent.TransformContext]
+	sampleSpanExpr      *ottl.ConditionSequence[*ottlspan.TransformContext]
+	sampleSpanEventExpr *ottl.ConditionSequence[*ottlspanevent.TransformContext]
 	errorMode           ottl.ErrorMode
 	logger              *zap.Logger
 }
@@ -64,16 +64,12 @@ func (ocf *ottlConditionFilter) Evaluate(ctx context.Context, traceID pcommon.Tr
 		return samplingpolicy.NotSampled, nil
 	}
 
-	trace.Lock()
-	defer trace.Unlock()
 	batches := trace.ReceivedBatches
 
 	for i := 0; i < batches.ResourceSpans().Len(); i++ {
 		rs := batches.ResourceSpans().At(i)
-		resource := rs.Resource()
 		for j := 0; j < rs.ScopeSpans().Len(); j++ {
 			ss := rs.ScopeSpans().At(j)
-			scope := ss.Scope()
 			for k := 0; k < ss.Spans().Len(); k++ {
 				span := ss.Spans().At(k)
 
@@ -90,7 +86,9 @@ func (ocf *ottlConditionFilter) Evaluate(ctx context.Context, traceID pcommon.Tr
 
 				// Span evaluation
 				if ocf.sampleSpanExpr != nil {
-					ok, err = ocf.sampleSpanExpr.Eval(ctx, ottlspan.NewTransformContext(span, scope, resource, ss, rs))
+					tCtx := ottlspan.NewTransformContextPtr(rs, ss, span)
+					ok, err = ocf.sampleSpanExpr.Eval(ctx, tCtx)
+					tCtx.Close()
 					if err != nil {
 						return samplingpolicy.Error, err
 					}
@@ -103,7 +101,9 @@ func (ocf *ottlConditionFilter) Evaluate(ctx context.Context, traceID pcommon.Tr
 				if ocf.sampleSpanEventExpr != nil {
 					spanEvents := span.Events()
 					for l := 0; l < spanEvents.Len(); l++ {
-						ok, err = ocf.sampleSpanEventExpr.Eval(ctx, ottlspanevent.NewTransformContext(spanEvents.At(l), span, scope, resource, ss, rs))
+						tCtx := ottlspanevent.NewTransformContextPtr(rs, ss, span, spanEvents.At(l))
+						ok, err = ocf.sampleSpanEventExpr.Eval(ctx, tCtx)
+						tCtx.Close()
 						if err != nil {
 							return samplingpolicy.Error, err
 						}
