@@ -56,8 +56,6 @@ func NewStatusCodeFilter(settings component.TelemetrySettings, statusCodeString
 func (r *statusCodeFilter) Evaluate(_ context.Context, _ pcommon.TraceID, trace *samplingpolicy.TraceData) (samplingpolicy.Decision, error) {
 	r.logger.Debug("Evaluating spans in status code filter")
 
-	trace.Lock()
-	defer trace.Unlock()
 	batches := trace.ReceivedBatches
 
 	return hasSpanWithCondition(batches, func(span ptrace.Span) bool {
