@@ -34,11 +34,11 @@ import (
 var processorCapabilities = consumer.Capabilities{MutatesData: true}
 
 type transformProcessorFactory struct {
-	dataPointFunctions                  map[string]ottl.Factory[ottldatapoint.TransformContext]
-	logFunctions                        map[string]ottl.Factory[ottllog.TransformContext]
-	metricFunctions                     map[string]ottl.Factory[ottlmetric.TransformContext]
-	spanEventFunctions                  map[string]ottl.Factory[ottlspanevent.TransformContext]
-	spanFunctions                       map[string]ottl.Factory[ottlspan.TransformContext]
+	dataPointFunctions                  map[string]ottl.Factory[*ottldatapoint.TransformContext]
+	logFunctions                        map[string]ottl.Factory[*ottllog.TransformContext]
+	metricFunctions                     map[string]ottl.Factory[*ottlmetric.TransformContext]
+	spanEventFunctions                  map[string]ottl.Factory[*ottlspanevent.TransformContext]
+	spanFunctions                       map[string]ottl.Factory[*ottlspan.TransformContext]
 	profileFunctions                    map[string]ottl.Factory[ottlprofile.TransformContext]
 	defaultDataPointFunctionsOverridden bool
 	defaultLogFunctionsOverridden       bool
@@ -51,60 +51,105 @@ type transformProcessorFactory struct {
 // FactoryOption applies changes to transformProcessorFactory.
 type FactoryOption func(factory *transformProcessorFactory)
 
-// WithDataPointFunctions will override the default OTTL datapoint context functions with the provided dataPointFunctions in resulting processor.
-// Subsequent uses of WithDataPointFunctions will merge the provided dataPointFunctions with the previously registered functions.
+// Deprecated: [v0.142.0] Use WithDataPointFunctionsNew.
 func WithDataPointFunctions(dataPointFunctions []ottl.Factory[ottldatapoint.TransformContext]) FactoryOption {
+	newDataPointFunctions := make([]ottl.Factory[*ottldatapoint.TransformContext], 0, len(dataPointFunctions))
+	for _, dataPointFunction := range dataPointFunctions {
+		newDataPointFunctions = append(newDataPointFunctions, ottl.NewFactory[*ottldatapoint.TransformContext](dataPointFunction.Name(), dataPointFunction.CreateDefaultArguments(), fromNonPointerFunction(dataPointFunction.CreateFunction)))
+	}
+	return WithDataPointFunctionsNew(newDataPointFunctions)
+}
+
+// WithDataPointFunctionsNew will override the default OTTL datapoint context functions with the provided dataPointFunctions in resulting processor.
+// Subsequent uses of WithDataPointFunctionsNew will merge the provided dataPointFunctions with the previously registered functions.
+func WithDataPointFunctionsNew(dataPointFunctions []ottl.Factory[*ottldatapoint.TransformContext]) FactoryOption {
 	return func(factory *transformProcessorFactory) {
 		if !factory.defaultDataPointFunctionsOverridden {
-			factory.dataPointFunctions = map[string]ottl.Factory[ottldatapoint.TransformContext]{}
+			factory.dataPointFunctions = map[string]ottl.Factory[*ottldatapoint.TransformContext]{}
 			factory.defaultDataPointFunctionsOverridden = true
 		}
 		factory.dataPointFunctions = mergeFunctionsToMap(factory.dataPointFunctions, dataPointFunctions)
 	}
 }
 
-// WithLogFunctions will override the default OTTL log context functions with the provided logFunctions in the resulting processor.
-// Subsequent uses of WithLogFunctions will merge the provided logFunctions with the previously registered functions.
+// Deprecated: [v0.142.0] Use WithLogFunctionsNew.
 func WithLogFunctions(logFunctions []ottl.Factory[ottllog.TransformContext]) FactoryOption {
+	newLogFunctions := make([]ottl.Factory[*ottllog.TransformContext], 0, len(logFunctions))
+	for _, logFunction := range logFunctions {
+		newLogFunctions = append(newLogFunctions, ottl.NewFactory[*ottllog.TransformContext](logFunction.Name(), logFunction.CreateDefaultArguments(), fromNonPointerFunction(logFunction.CreateFunction)))
+	}
+	return WithLogFunctionsNew(newLogFunctions)
+}
+
+// WithLogFunctionsNew will override the default OTTL log context functions with the provided logFunctions in the resulting processor.
+// Subsequent uses of WithLogFunctionsNew will merge the provided logFunctions with the previously registered functions.
+func WithLogFunctionsNew(logFunctions []ottl.Factory[*ottllog.TransformContext]) FactoryOption {
 	return func(factory *transformProcessorFactory) {
 		if !factory.defaultLogFunctionsOverridden {
-			factory.logFunctions = map[string]ottl.Factory[ottllog.TransformContext]{}
+			factory.logFunctions = map[string]ottl.Factory[*ottllog.TransformContext]{}
 			factory.defaultLogFunctionsOverridden = true
 		}
 		factory.logFunctions = mergeFunctionsToMap(factory.logFunctions, logFunctions)
 	}
 }
 
-// WithMetricFunctions will override the default OTTL metric context functions with the provided metricFunctions in the resulting processor.
-// Subsequent uses of WithMetricFunctions will merge the provided metricFunctions with the previously registered functions.
+// Deprecated: [v0.142.0] Use WithMetricFunctionsNew.
 func WithMetricFunctions(metricFunctions []ottl.Factory[ottlmetric.TransformContext]) FactoryOption {
+	newMetricFunctions := make([]ottl.Factory[*ottlmetric.TransformContext], 0, len(metricFunctions))
+	for _, metricFunction := range metricFunctions {
+		newMetricFunctions = append(newMetricFunctions, ottl.NewFactory[*ottlmetric.TransformContext](metricFunction.Name(), metricFunction.CreateDefaultArguments(), fromNonPointerFunction(metricFunction.CreateFunction)))
+	}
+	return WithMetricFunctionsNew(newMetricFunctions)
+}
+
+// WithMetricFunctionsNew will override the default OTTL metric context functions with the provided metricFunctions in the resulting processor.
+// Subsequent uses of WithMetricFunctionsNew will merge the provided metricFunctions with the previously registered functions.
+func WithMetricFunctionsNew(metricFunctions []ottl.Factory[*ottlmetric.TransformContext]) FactoryOption {
 	return func(factory *transformProcessorFactory) {
 		if !factory.defaultMetricFunctionsOverridden {
-			factory.metricFunctions = map[string]ottl.Factory[ottlmetric.TransformContext]{}
+			factory.metricFunctions = map[string]ottl.Factory[*ottlmetric.TransformContext]{}
 			factory.defaultMetricFunctionsOverridden = true
 		}
 		factory.metricFunctions = mergeFunctionsToMap(factory.metricFunctions, metricFunctions)
 	}
 }
 
-// WithSpanEventFunctions will override the default OTTL spanevent context functions with the provided spanEventFunctions in the resulting processor.
-// Subsequent uses of WithSpanEventFunctions will merge the provided spanEventFunctions with the previously registered functions.
+// Deprecated: [v0.142.0] Use WithSpanEventFunctionsNew.
 func WithSpanEventFunctions(spanEventFunctions []ottl.Factory[ottlspanevent.TransformContext]) FactoryOption {
+	newSpanFunctions := make([]ottl.Factory[*ottlspanevent.TransformContext], 0, len(spanEventFunctions))
+	for _, spanEventFunction := range spanEventFunctions {
+		newSpanFunctions = append(newSpanFunctions, ottl.NewFactory[*ottlspanevent.TransformContext](spanEventFunction.Name(), spanEventFunction.CreateDefaultArguments(), fromNonPointerFunction(spanEventFunction.CreateFunction)))
+	}
+	return WithSpanEventFunctionsNew(newSpanFunctions)
+}
+
+// WithSpanEventFunctionsNew will override the default OTTL spanevent context functions with the provided spanEventFunctions in the resulting processor.
+// Subsequent uses of WithSpanEventFunctionsNew will merge the provided spanEventFunctions with the previously registered functions.
+func WithSpanEventFunctionsNew(spanEventFunctions []ottl.Factory[*ottlspanevent.TransformContext]) FactoryOption {
 	return func(factory *transformProcessorFactory) {
 		if !factory.defaultSpanEventFunctionsOverridden {
-			factory.spanEventFunctions = map[string]ottl.Factory[ottlspanevent.TransformContext]{}
+			factory.spanEventFunctions = map[string]ottl.Factory[*ottlspanevent.TransformContext]{}
 			factory.defaultSpanEventFunctionsOverridden = true
 		}
 		factory.spanEventFunctions = mergeFunctionsToMap(factory.spanEventFunctions, spanEventFunctions)
 	}
 }
 
-// WithSpanFunctions will override the default OTTL span context functions with the provided spanFunctions in the resulting processor.
-// Subsequent uses of WithSpanFunctions will merge the provided spanFunctions with the previously registered functions.
+// Deprecated: [v0.142.0] use WithSpanFunctionsNew.
 func WithSpanFunctions(spanFunctions []ottl.Factory[ottlspan.TransformContext]) FactoryOption {
+	newSpanFunctions := make([]ottl.Factory[*ottlspan.TransformContext], 0, len(spanFunctions))
+	for _, spanFunction := range spanFunctions {
+		newSpanFunctions = append(newSpanFunctions, ottl.NewFactory[*ottlspan.TransformContext](spanFunction.Name(), spanFunction.CreateDefaultArguments(), fromNonPointerFunction(spanFunction.CreateFunction)))
+	}
+	return WithSpanFunctionsNew(newSpanFunctions)
+}
+
+// WithSpanFunctionsNew will override the default OTTL span context functions with the provided spanFunctions in the resulting processor.
+// Subsequent uses of WithSpanFunctionsNew will merge the provided spanFunctions with the previously registered functions.
+func WithSpanFunctionsNew(spanFunctions []ottl.Factory[*ottlspan.TransformContext]) FactoryOption {
 	return func(factory *transformProcessorFactory) {
 		if !factory.defaultSpanFunctionsOverridden {
-			factory.spanFunctions = map[string]ottl.Factory[ottlspan.TransformContext]{}
+			factory.spanFunctions = map[string]ottl.Factory[*ottlspan.TransformContext]{}
 			factory.defaultSpanFunctionsOverridden = true
 		}
 		factory.spanFunctions = mergeFunctionsToMap(factory.spanFunctions, spanFunctions)
@@ -267,3 +312,15 @@ func (f *transformProcessorFactory) createProfilesProcessor(
 		proc.ProcessProfiles,
 		xprocessorhelper.WithCapabilities(processorCapabilities))
 }
+
+func fromNonPointerFunction[K any](legacy func(fCtx ottl.FunctionContext, args ottl.Arguments) (ottl.ExprFunc[K], error)) func(fCtx ottl.FunctionContext, args ottl.Arguments) (ottl.ExprFunc[*K], error) {
+	return func(fCtx ottl.FunctionContext, args ottl.Arguments) (ottl.ExprFunc[*K], error) {
+		legacyExpr, err := legacy(fCtx, args)
+		if err != nil {
+			return nil, err
+		}
+		return func(ctx context.Context, tCtx *K) (any, error) {
+			return legacyExpr(ctx, *tCtx)
+		}, nil
+	}
+}
