@@ -5,7 +5,7 @@ package unmarshaler // import "github.com/open-telemetry/opentelemetry-collector
 import (
 	"time"
 
-	jsoniter "github.com/json-iterator/go"
+	json "github.com/goccy/go-json"
 	"go.opentelemetry.io/collector/pdata/pcommon"
 	"go.opentelemetry.io/collector/pdata/plog"
 )
@@ -20,7 +20,7 @@ func (JSONLogsUnmarshaler) UnmarshalLogs(buf []byte) (plog.Logs, error) {
 
 	// get json logs from the buffer
 	jsonVal := map[string]any{}
-	if err := jsoniter.Unmarshal(buf, &jsonVal); err != nil {
+	if err := json.Unmarshal(buf, &jsonVal); err != nil {
 		return p, err
 	}
 
