@@ -162,33 +162,41 @@ type broker struct {
 	// reqs manages incoming message requests.
 	reqs ring[promisedReq]
 	// dead is an atomic so a backed up reqs cannot block broker stoppage.
-	dead atomicBool
+	dead atomic.Bool
 }
 
 // brokerVersions is loaded once (and potentially a few times concurrently if
 // multiple connections are opening at once) and then forever stored for a
 // broker.
 type brokerVersions struct {
-	maxVers  [kmsg.MaxKey + 1]int16
-	minVers  [kmsg.MaxKey + 1]int16
+	maxVers  map[int16]int16
+	minVers  map[int16]int16
 	features map[string]int16
 }
 
-func newBrokerVersions() *brokerVersions {
+func (v *brokerVersions) maxVersion(key int16) int16 {
+	if version, ok := v.maxVers[key]; ok {
+		return version
+	}
+	return -1
+}
+
+func (v *brokerVersions) minVersion(key int16) int16 {
+	if version, ok := v.minVers[key]; ok {
+		return version
+	}
+	return -1
+}
+
+func newBrokerVersions(capacity int) *brokerVersions {
 	v := &brokerVersions{
+		maxVers:  make(map[int16]int16, capacity),
+		minVers:  make(map[int16]int16, capacity),
 		features: make(map[string]int16),
 	}
-	for i := range &v.maxVers {
-		v.maxVers[i] = -1
-	}
-	for i := range &v.minVers {
-		v.minVers[i] = -1
-	}
 	return v
 }
 
-func (*brokerVersions) len() int { return kmsg.MaxKey + 1 }
-
 func (b *broker) loadVersions() *brokerVersions {
 	loaded := b.versions.Load()
 	if loaded == nil {
@@ -315,15 +323,15 @@ start:
 
 	v := b.loadVersions()
 
-	if int(req.Key()) > v.len() || b.cl.cfg.maxVersions != nil && !b.cl.cfg.maxVersions.HasKey(req.Key()) {
+	if b.cl.cfg.maxVersions != nil && !b.cl.cfg.maxVersions.HasKey(req.Key()) {
 		pr.promise(nil, errUnknownRequestKey)
 		return
 	}
 
-	// If v.maxVers[0] is non-negative, then we loaded API
+	// If v.maxVersion(0) is non-negative, then we loaded API
 	// versions. If the version for this request is negative, we
 	// know the broker cannot handle this request.
-	if v.maxVers[0] >= 0 && v.maxVers[req.Key()] < 0 {
+	if v.maxVersion(0) >= 0 && v.maxVersion(req.Key()) < 0 {
 		pr.promise(nil, errBrokerTooOld)
 		return
 	}
@@ -341,10 +349,10 @@ start:
 
 	// If we have no broker versions, we are pinned pre 0.10.0 and did not
 	// issue ApiVersions.
-	if brokerMax := v.maxVers[req.Key()]; brokerMax >= 0 && brokerMax < ourMax {
+	if brokerMax := v.maxVersion(req.Key()); brokerMax >= 0 && brokerMax < ourMax {
 		ourMax = brokerMax
 	}
-	if brokerMin := v.minVers[req.Key()]; brokerMin >= 0 && brokerMin > ourMin {
+	if brokerMin := v.minVersion(req.Key()); brokerMin >= 0 && brokerMin > ourMin {
 		ourMin = brokerMin
 	}
 
@@ -701,7 +709,7 @@ func (b *broker) connect(ctx context.Context) (net.Conn, error) {
 // brokerCxn manages an actual connection to a Kafka broker. This is separate
 // the broker struct to allow lazy connection (re)creation.
 type brokerCxn struct {
-	throttleUntil atomicI64 // atomic nanosec
+	throttleUntil atomic.Int64 // atomic nanosec
 
 	conn net.Conn
 
@@ -718,17 +726,17 @@ type brokerCxn struct {
 	// The following four fields are used for connection reaping.
 	// Write is only updated in one location; read is updated in three
 	// due to readConn, readConnAsync, and discard.
-	lastWrite atomicI64
-	lastRead  atomicI64
-	writing   atomicBool
-	reading   atomicBool
+	lastWrite atomic.Int64
+	lastRead  atomic.Int64
+	writing   atomic.Bool
+	reading   atomic.Bool
 
 	successes uint64
 
 	// resps manages reading kafka responses.
 	resps ring[promisedResp]
 	// dead is an atomic so that a backed up resps cannot block cxn death.
-	dead atomicBool
+	dead atomic.Bool
 	// closed in cloneConn; allows throttle waiting to quit
 	deadCh chan struct{}
 }
@@ -745,8 +753,8 @@ func (cxn *brokerCxn) init(isProduceCxn bool, tries int) error {
 			}
 		} else {
 			// We have a max versions, and it indicates no support
-			// for ApiVersions. We just store a default -1 set.
-			cxn.b.storeVersions(newBrokerVersions())
+			// for ApiVersions. We just store a default empty map.
+			cxn.b.storeVersions(newBrokerVersions(0))
 		}
 	}
 
@@ -846,11 +854,8 @@ start:
 		return errors.New("ApiVersions response invalidly contained no ApiKeys")
 	}
 
-	v := newBrokerVersions()
+	v := newBrokerVersions(len(resp.ApiKeys))
 	for _, key := range resp.ApiKeys {
-		if key.ApiKey > kmsg.MaxKey || key.ApiKey < 0 {
-			continue
-		}
 		v.maxVers[key.ApiKey] = key.MaxVersion
 		v.minVers[key.ApiKey] = key.MinVersion
 	}
@@ -876,9 +881,9 @@ func (cxn *brokerCxn) sasl() error {
 	req := kmsg.NewPtrSASLHandshakeRequest()
 
 start:
-	if mechanism.Name() != "GSSAPI" && v.maxVers[req.Key()] >= 0 {
+	if mechanism.Name() != "GSSAPI" && v.maxVersion(req.Key()) >= 0 {
 		req.Mechanism = mechanism.Name()
-		req.Version = v.maxVers[req.Key()]
+		req.Version = v.maxVersion(req.Key())
 		cxn.cl.cfg.logger.Log(LogLevelDebug, "issuing SASLHandshakeRequest", "broker", logID(cxn.b.meta.NodeID))
 		corrID, bytesWritten, writeWait, timeToWrite, readEnqueue, writeErr := cxn.writeRequest(nil, time.Now(), req)
 		if writeErr != nil {
@@ -965,7 +970,7 @@ func (cxn *brokerCxn) doSasl(authenticate bool) error {
 		} else {
 			req := kmsg.NewPtrSASLAuthenticateRequest()
 			req.SASLAuthBytes = clientWrite
-			req.Version = cxn.b.loadVersions().maxVers[req.Key()]
+			req.Version = cxn.b.loadVersions().maxVersion(req.Key())
 			cxn.cl.cfg.logger.Log(LogLevelDebug, "issuing SASLAuthenticate", "broker", logID(cxn.b.meta.NodeID), "version", req.Version, "step", step)
 
 			// Lifetime: we take the timestamp before we write our
