@@ -13,23 +13,23 @@ import (
 // MarkPipelineOwnedProfiles marks the pprofile.Profiles data as owned by the pipeline, returns true if the data were
 // previously not owned by the pipeline, otherwise false.
 func MarkPipelineOwnedProfiles(pd pprofile.Profiles) bool {
-	return internal.GetProfilesState(internal.Profiles(pd)).MarkPipelineOwned()
+	return internal.GetProfilesState(internal.ProfilesWrapper(pd)).MarkPipelineOwned()
 }
 
 func RefProfiles(pd pprofile.Profiles) {
 	if EnableRefCounting.IsEnabled() {
-		internal.GetProfilesState(internal.Profiles(pd)).Ref()
+		internal.GetProfilesState(internal.ProfilesWrapper(pd)).Ref()
 	}
 }
 
 func UnrefProfiles(pd pprofile.Profiles) {
 	if EnableRefCounting.IsEnabled() {
-		if !internal.GetProfilesState(internal.Profiles(pd)).Unref() {
+		if !internal.GetProfilesState(internal.ProfilesWrapper(pd)).Unref() {
 			return
 		}
-		// Don't call DeleteOrigExportLogsServiceRequest without the gate because we reset the data and that may still cause issues.
+		// Don't call DeleteExportLogsServiceRequest without the gate because we reset the data and that may still cause issues.
 		if internal.UseProtoPooling.IsEnabled() {
-			internal.DeleteOrigExportProfilesServiceRequest(internal.GetOrigProfiles(internal.Profiles(pd)), true)
+			internal.DeleteExportProfilesServiceRequest(internal.GetProfilesOrig(internal.ProfilesWrapper(pd)), true)
 		}
 	}
 }
@@ -37,5 +37,5 @@ func UnrefProfiles(pd pprofile.Profiles) {
 // TODO: Generate this in pdata.
 
 func EqualProfiles(pd1, pd2 pprofile.Profiles) bool {
-	return reflect.DeepEqual(internal.GetOrigProfiles(internal.Profiles(pd1)), internal.GetOrigProfiles(internal.Profiles(pd2)))
+	return reflect.DeepEqual(internal.GetProfilesOrig(internal.ProfilesWrapper(pd1)), internal.GetProfilesOrig(internal.ProfilesWrapper(pd2)))
 }
