@@ -619,7 +619,7 @@ func connectorStability(f connector.Factory, expType, recType pipeline.Signal) c
 var (
 	_ component.Host                   = (*HostWrapper)(nil)
 	_ componentstatus.Reporter         = (*HostWrapper)(nil)
-	_ hostcapabilities.ExposeExporters = (*HostWrapper)(nil)
+	_ hostcapabilities.ExposeExporters = (*HostWrapper)(nil) //nolint:staticcheck // SA1019
 )
 
 type HostWrapper struct {
