@@ -89,8 +89,20 @@ type Settings struct {
 	AsyncErrorChannel chan error
 
 	// LoggingOptions provides a way to change behavior of zap logging.
+	//
+	// These options will be appended to any options passed to BuildZapLogger.
+	//
+	// Deprecated [v0.142.0]: use BuildZapLogger instead. This field will be
+	// removed in the future, and options must be injected through BuildZapLogger.
 	LoggingOptions []zap.Option
 
+	// BuildZapLogger holds an optional function for creating a Zap logger from
+	// a zap.Config and options. If this is unspecified, zap.Config.Build will
+	// be used.
+	//
+	// NOTE: in the future this field will be required.
+	BuildZapLogger func(zap.Config, ...zap.Option) (*zap.Logger, error)
+
 	// TelemetryFactory is the factory for creating internal telemetry providers.
 	TelemetryFactory telemetry.Factory
 }
@@ -124,16 +136,37 @@ func New(ctx context.Context, set Settings, cfg Config) (_ *Service, resultErr e
 		collectorConf: set.CollectorConf,
 	}
 
-	// Create the logger & LoggerProvider first. These may be used
-	// when creating the other telemetry providers.
-	telemetrySettings := telemetry.Settings{BuildInfo: set.BuildInfo}
-	loggerSettings := telemetry.LoggerSettings{
-		Settings:   telemetrySettings,
-		ZapOptions: set.LoggingOptions,
-	}
 	if set.TelemetryFactory == nil {
 		return nil, errors.New("telemetry factory not provided")
 	}
+
+	// Create the resource first. This ensures all telemetry providers
+	// (logger, meter, tracer) use the same resource with a consistent service.instance.id.
+	telemetrySettings := telemetry.Settings{BuildInfo: set.BuildInfo}
+	resource, err := set.TelemetryFactory.CreateResource(ctx, telemetrySettings, cfg.Telemetry)
+	if err != nil {
+		return nil, fmt.Errorf("failed to create resource: %w", err)
+	}
+	telemetrySettings.Resource = &resource
+
+	// Create a function for telemetry providers to build the Zap logger.
+	// This injects any LoggingOptions specified in the Settings.
+	buildZapLogger := set.BuildZapLogger
+	if buildZapLogger == nil {
+		buildZapLogger = zap.Config.Build
+	}
+	if len(set.LoggingOptions) > 0 {
+		origBuildZapLogger := buildZapLogger
+		buildZapLogger = func(cfg zap.Config, opts ...zap.Option) (*zap.Logger, error) {
+			opts = append(opts, set.LoggingOptions...)
+			return origBuildZapLogger(cfg, opts...)
+		}
+	}
+
+	loggerSettings := telemetry.LoggerSettings{
+		Settings:       telemetrySettings,
+		BuildZapLogger: buildZapLogger,
+	}
 	logger, loggerShutdownFunc, err := set.TelemetryFactory.CreateLogger(ctx, loggerSettings, cfg.Telemetry)
 	if err != nil {
 		return nil, fmt.Errorf("failed to create logger: %w", err)
@@ -177,11 +210,6 @@ func New(ctx context.Context, set Settings, cfg Config) (_ *Service, resultErr e
 	}()
 	srv.tracerProvider = tracerProvider
 
-	resource, err := set.TelemetryFactory.CreateResource(ctx, telemetrySettings, cfg.Telemetry)
-	if err != nil {
-		return nil, fmt.Errorf("failed to create resource: %w", err)
-	}
-
 	srv.telemetrySettings = component.TelemetrySettings{
 		Logger:         logger,
 		MeterProvider:  meterProvider,
